// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "krunnersettingsdata.h"

#include "krunnersettingsbase.h"




KRunnerSettingsData::KRunnerSettingsData(QObject *parent)
: KCModuleData(parent)
, m_settings(new KRunnerSettingsBase(this))

{
autoRegisterSkeletons();
}

KRunnerSettingsBase *KRunnerSettingsData::settings() const
{
    return m_settings;
}





#include "moc_krunnersettingsdata.cpp"
