// This file is autogenerated. Changes will be overwritten.
#include "EJRQKI7XPS/moc_workspaceoptions_kdeglobalssettings.cpp"
#include "EJRQKI7XPS/moc_workspaceoptions_kwinsettings.cpp"
#include "EJRQKI7XPS/moc_workspaceoptions_plasmasettings.cpp"
