// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef SMSERVERDATA_H
#define SMSERVERDATA_H

#include <QObject>

#include "kcmoduledata.h"



class SMServerSettings;


class SMServerData : public KCModuleData
{
    Q_OBJECT

public:
    explicit SMServerData(QObject *parent = nullptr);
    SMServerSettings *settings() const;


private:
    SMServerSettings *m_settings;

};



#endif
