/****************************************************************************
** Meta object code from reading C++ file 'workspaceoptions_plasmasettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../workspaceoptions_plasmasettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'workspaceoptions_plasmasettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30WorkspaceOptionsPlasmaSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto WorkspaceOptionsPlasmaSettings::qt_create_metaobjectdata<qt_meta_tag_ZN30WorkspaceOptionsPlasmaSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorkspaceOptionsPlasmaSettings",
        "delayChanged",
        "",
        "osdEnabledChanged",
        "osdKbdLayoutChangedEnabledChanged",
        "delay",
        "isDelayImmutable",
        "defaultDelayValue",
        "osdEnabled",
        "isOsdEnabledImmutable",
        "defaultOsdEnabledValue",
        "osdKbdLayoutChangedEnabled",
        "isOsdKbdLayoutChangedEnabledImmutable",
        "defaultOsdKbdLayoutChangedEnabledValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'delayChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'osdEnabledChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'osdKbdLayoutChangedEnabledChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'delay'
        QtMocHelpers::PropertyData<double>(5, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isDelayImmutable'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDelayValue'
        QtMocHelpers::PropertyData<double>(7, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'osdEnabled'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isOsdEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOsdEnabledValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'osdKbdLayoutChangedEnabled'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOsdKbdLayoutChangedEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOsdKbdLayoutChangedEnabledValue'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WorkspaceOptionsPlasmaSettings, qt_meta_tag_ZN30WorkspaceOptionsPlasmaSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorkspaceOptionsPlasmaSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30WorkspaceOptionsPlasmaSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30WorkspaceOptionsPlasmaSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30WorkspaceOptionsPlasmaSettingsE_t>.metaTypes,
    nullptr
} };

void WorkspaceOptionsPlasmaSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorkspaceOptionsPlasmaSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->delayChanged(); break;
        case 1: _t->osdEnabledChanged(); break;
        case 2: _t->osdKbdLayoutChangedEnabledChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsPlasmaSettings::*)()>(_a, &WorkspaceOptionsPlasmaSettings::delayChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsPlasmaSettings::*)()>(_a, &WorkspaceOptionsPlasmaSettings::osdEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsPlasmaSettings::*)()>(_a, &WorkspaceOptionsPlasmaSettings::osdKbdLayoutChangedEnabledChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->delay(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isDelayImmutable(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->defaultDelayValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->osdEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isOsdEnabledImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultOsdEnabledValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->osdKbdLayoutChangedEnabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOsdKbdLayoutChangedEnabledImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultOsdKbdLayoutChangedEnabledValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDelay(*reinterpret_cast<double*>(_v)); break;
        case 3: _t->setOsdEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setOsdKbdLayoutChangedEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WorkspaceOptionsPlasmaSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorkspaceOptionsPlasmaSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30WorkspaceOptionsPlasmaSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int WorkspaceOptionsPlasmaSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void WorkspaceOptionsPlasmaSettings::delayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WorkspaceOptionsPlasmaSettings::osdEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WorkspaceOptionsPlasmaSettings::osdKbdLayoutChangedEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
