/****************************************************************************
** Meta object code from reading C++ file 'positioner.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../plasma-desktop-6.6.4/containments/desktop/plugins/folder/positioner.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'positioner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PositionerE_t {};
} // unnamed namespace

template <> constexpr inline auto Positioner::qt_create_metaobjectdata<qt_meta_tag_ZN10PositionerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Positioner",
        "QML.Element",
        "auto",
        "enabledChanged",
        "",
        "folderModelChanged",
        "perStripeChanged",
        "appletChanged",
        "sourceStatusChanged",
        "sourceDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "QList<int>",
        "roles",
        "sourceModelAboutToBeReset",
        "sourceModelReset",
        "sourceRowsAboutToBeInserted",
        "parent",
        "start",
        "end",
        "sourceRowsAboutToBeMoved",
        "sourceParent",
        "sourceStart",
        "sourceEnd",
        "destinationParent",
        "destinationRow",
        "sourceRowsAboutToBeRemoved",
        "first",
        "last",
        "sourceLayoutAboutToBeChanged",
        "QList<QPersistentModelIndex>",
        "parents",
        "QAbstractItemModel::LayoutChangeHint",
        "hint",
        "sourceRowsInserted",
        "sourceRowsMoved",
        "sourceRowsRemoved",
        "sourceLayoutChanged",
        "onItemAboutToRename",
        "filename",
        "onItemRenamed",
        "newFilename",
        "onListingCompleted",
        "map",
        "row",
        "nearestItem",
        "currentIndex",
        "Qt::ArrowType",
        "direction",
        "isBlank",
        "indexForUrl",
        "QUrl",
        "url",
        "setRangeSelected",
        "anchor",
        "to",
        "reset",
        "move",
        "QVariantList",
        "moves",
        "save",
        "applet",
        "Plasma::Applet*",
        "enabled",
        "folderModel",
        "FolderModel*",
        "perStripe",
        "optimalStripes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'folderModelChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'perStripeChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appletChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sourceStatusChanged'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QList<int> &)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 10, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'sourceModelAboutToBeReset'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceModelReset'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceRowsAboutToBeInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 18 }, { QMetaType::Int, 19 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'sourceRowsAboutToBeMoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 }, { 0x80000000 | 10, 25 },
            { QMetaType::Int, 26 },
        }}),
        // Slot 'sourceRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 18 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'sourceLayoutAboutToBeChanged'
        QtMocHelpers::SlotData<void(const QList<QPersistentModelIndex> &, QAbstractItemModel::LayoutChangeHint)>(30, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 }, { 0x80000000 | 33, 34 },
        }}),
        // Slot 'sourceRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(35, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 18 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'sourceRowsMoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(36, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 }, { 0x80000000 | 10, 25 },
            { QMetaType::Int, 26 },
        }}),
        // Slot 'sourceRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(37, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 18 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'sourceLayoutChanged'
        QtMocHelpers::SlotData<void(const QList<QPersistentModelIndex> &, QAbstractItemModel::LayoutChangeHint)>(38, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 }, { 0x80000000 | 33, 34 },
        }}),
        // Slot 'onItemAboutToRename'
        QtMocHelpers::SlotData<void(const QString &)>(39, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'onItemRenamed'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(41, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 40 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'onListingCompleted'
        QtMocHelpers::SlotData<void()>(43, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'map'
        QtMocHelpers::MethodData<int(int) const>(44, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 45 },
        }}),
        // Method 'nearestItem'
        QtMocHelpers::MethodData<int(int, Qt::ArrowType)>(46, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 47 }, { 0x80000000 | 48, 49 },
        }}),
        // Method 'isBlank'
        QtMocHelpers::MethodData<bool(int) const>(50, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 45 },
        }}),
        // Method 'indexForUrl'
        QtMocHelpers::MethodData<int(const QUrl &) const>(51, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Method 'setRangeSelected'
        QtMocHelpers::MethodData<void(int, int)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 55 }, { QMetaType::Int, 56 },
        }}),
        // Method 'reset'
        QtMocHelpers::MethodData<void()>(57, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'move'
        QtMocHelpers::MethodData<int(const QVariantList &, bool)>(58, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 59, 60 }, { QMetaType::Bool, 61 },
        }}),
        // Method 'move'
        QtMocHelpers::MethodData<int(const QVariantList &)>(58, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 59, 60 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'applet'
        QtMocHelpers::PropertyData<Plasma::Applet*>(62, 0x80000000 | 63, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'folderModel'
        QtMocHelpers::PropertyData<FolderModel*>(65, 0x80000000 | 66, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'perStripe'
        QtMocHelpers::PropertyData<int>(67, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'optimalStripes'
        QtMocHelpers::PropertyData<int>(68, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Positioner, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Positioner::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PositionerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PositionerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PositionerE_t>.metaTypes,
    nullptr
} };

void Positioner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Positioner *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->folderModelChanged(); break;
        case 2: _t->perStripeChanged(); break;
        case 3: _t->appletChanged(); break;
        case 4: _t->sourceStatusChanged(); break;
        case 5: _t->sourceDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 6: _t->sourceModelAboutToBeReset(); break;
        case 7: _t->sourceModelReset(); break;
        case 8: _t->sourceRowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->sourceRowsAboutToBeMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 10: _t->sourceRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->sourceLayoutAboutToBeChanged((*reinterpret_cast<std::add_pointer_t<QList<QPersistentModelIndex>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractItemModel::LayoutChangeHint>>(_a[2]))); break;
        case 12: _t->sourceRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->sourceRowsMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 14: _t->sourceRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->sourceLayoutChanged((*reinterpret_cast<std::add_pointer_t<QList<QPersistentModelIndex>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractItemModel::LayoutChangeHint>>(_a[2]))); break;
        case 16: _t->onItemAboutToRename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->onItemRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->onListingCompleted(); break;
        case 19: { int _r = _t->map((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { int _r = _t->nearestItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::ArrowType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->isBlank((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { int _r = _t->indexForUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->setRangeSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: _t->reset(); break;
        case 25: { int _r = _t->move((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 26: { int _r = _t->move((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)() const>(_a, &Positioner::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)() const>(_a, &Positioner::folderModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)() const>(_a, &Positioner::perStripeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)() const>(_a, &Positioner::appletChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Plasma::Applet* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Plasma::Applet**>(_v) = _t->applet(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast<FolderModel**>(_v) = _t->folderModel(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->perStripe(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->m_optimalStripes; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setApplet(*reinterpret_cast<Plasma::Applet**>(_v)); break;
        case 1: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setFolderModel(*reinterpret_cast<FolderModel**>(_v)); break;
        case 3: _t->setPerStripe(*reinterpret_cast<int*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_optimalStripes, *reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Positioner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Positioner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PositionerE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Positioner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Positioner::enabledChanged()const
{
    QMetaObject::activate(const_cast< Positioner *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Positioner::folderModelChanged()const
{
    QMetaObject::activate(const_cast< Positioner *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Positioner::perStripeChanged()const
{
    QMetaObject::activate(const_cast< Positioner *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Positioner::appletChanged()const
{
    QMetaObject::activate(const_cast< Positioner *>(this), &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
