// This file is generated by kconfig_compiler_kf6 from AutomounterSettingsBase.kcfg.
// All changes you do to this file will be lost.

#include "AutomounterSettingsBase.h"

AutomounterSettingsBase::AutomounterSettingsBase( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kded_device_automounterrc" ) )
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemBool  *itemAutomountOnLogin;
  itemAutomountOnLogin = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomountOnLogin" ), mAutomountOnLogin, false );
  addItem( itemAutomountOnLogin, QStringLiteral( "AutomountOnLogin" ) );
  KConfigSkeleton::ItemBool  *itemAutomountOnPlugin;
  itemAutomountOnPlugin = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomountOnPlugin" ), mAutomountOnPlugin, false );
  addItem( itemAutomountOnPlugin, QStringLiteral( "AutomountOnPlugin" ) );
  KConfigSkeleton::ItemBool  *itemAutomountUnknownDevices;
  itemAutomountUnknownDevices = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomountUnknownDevices" ), mAutomountUnknownDevices, false );
  addItem( itemAutomountUnknownDevices, QStringLiteral( "AutomountUnknownDevices" ) );
  KConfigSkeleton::ItemBool  *itemAutomountEnabled;
  itemAutomountEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomountEnabled" ), mAutomountEnabled, false );
  addItem( itemAutomountEnabled, QStringLiteral( "AutomountEnabled" ) );
}

AutomounterSettingsBase::~AutomounterSettingsBase()
{
}

