// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "DeviceAutomounterData.h"

#include "AutomounterSettings.h"




DeviceAutomounterData::DeviceAutomounterData(QObject *parent)
: KCModuleData(parent)
, m_settings(new AutomounterSettings(this))

{
autoRegisterSkeletons();
}

AutomounterSettings *DeviceAutomounterData::settings() const
{
    return m_settings;
}





#include "moc_DeviceAutomounterData.cpp"
