// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef KACTIVITIESDATA_H
#define KACTIVITIESDATA_H

#include <QObject>

#include "kcmoduledata.h"



class KActivityManagerdPluginsSettings;


class KActivitiesData : public KCModuleData
{
    Q_OBJECT

public:
    explicit KActivitiesData(QObject *parent = nullptr);
    KActivityManagerdPluginsSettings *settings() const;


private:
    KActivityManagerdPluginsSettings *m_settings;

};



#endif
