/****************************************************************************
** Meta object code from reading C++ file 'InputDevice_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "InputDevice_interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'InputDevice_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30OrgKdeKWinInputDeviceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKWinInputDeviceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN30OrgKdeKWinInputDeviceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKWinInputDeviceInterface",
        "calibrationMatrixChanged",
        "",
        "clickMethodChanged",
        "currentModesChanged",
        "disableEventsOnExternalMouseChanged",
        "disableWhileTypingChanged",
        "enabledChanged",
        "inputAreaChanged",
        "leftHandedChanged",
        "mapToWorkspaceChanged",
        "middleEmulationChanged",
        "naturalScrollChanged",
        "orientationChanged",
        "outputAreaChanged",
        "outputNameChanged",
        "pointerAccelerationChanged",
        "pointerAccelerationProfileChanged",
        "pressureCurveChanged",
        "pressureRangeMaxChanged",
        "pressureRangeMinChanged",
        "rotationChanged",
        "scrollButtonChanged",
        "scrollFactorChanged",
        "scrollMethodChanged",
        "supportsPressureRangeChanged",
        "tabletToolRelativeChanged",
        "tapAndDragChanged",
        "tapButtonMapChanged",
        "tapDragLockChanged",
        "tapToClickChanged",
        "alphaNumericKeyboard",
        "calibrationMatrix",
        "clickMethodAreas",
        "clickMethodClickfinger",
        "currentModes",
        "QList<uint>",
        "defaultCalibrationMatrix",
        "defaultClickMethodAreas",
        "defaultClickMethodClickfinger",
        "defaultInputArea",
        "QRectF",
        "defaultMapToWorkspace",
        "defaultOutputArea",
        "defaultPointerAcceleration",
        "defaultPointerAccelerationProfileAdaptive",
        "defaultPointerAccelerationProfileFlat",
        "defaultPressureCurve",
        "defaultPressureRangeMax",
        "defaultPressureRangeMin",
        "defaultScrollButton",
        "deviceGroupId",
        "disableEventsOnExternalMouse",
        "disableEventsOnExternalMouseEnabledByDefault",
        "disableWhileTyping",
        "disableWhileTypingEnabledByDefault",
        "enabled",
        "enabledByDefault",
        "gestureSupport",
        "inputArea",
        "isVirtual",
        "keyboard",
        "leftHanded",
        "leftHandedEnabledByDefault",
        "lidSwitch",
        "lmrTapButtonMap",
        "lmrTapButtonMapEnabledByDefault",
        "mapToWorkspace",
        "middleEmulation",
        "middleEmulationEnabledByDefault",
        "name",
        "naturalScroll",
        "naturalScrollEnabledByDefault",
        "numModes",
        "orientationDBus",
        "outputArea",
        "outputName",
        "pointer",
        "pointerAcceleration",
        "pointerAccelerationProfileAdaptive",
        "pointerAccelerationProfileFlat",
        "pressureCurve",
        "pressureRangeMax",
        "pressureRangeMin",
        "product",
        "scrollButton",
        "scrollEdge",
        "scrollEdgeEnabledByDefault",
        "scrollFactor",
        "scrollOnButtonDown",
        "scrollOnButtonDownEnabledByDefault",
        "scrollTwoFinger",
        "scrollTwoFingerEnabledByDefault",
        "size",
        "QSizeF",
        "supportedButtons",
        "supportsCalibrationMatrix",
        "supportsClickMethodAreas",
        "supportsClickMethodClickfinger",
        "supportsDisableEvents",
        "supportsDisableEventsOnExternalMouse",
        "supportsDisableWhileTyping",
        "supportsInputArea",
        "supportsLeftHanded",
        "supportsLmrTapButtonMap",
        "supportsMiddleEmulation",
        "supportsNaturalScroll",
        "supportsOutputArea",
        "supportsPointerAcceleration",
        "supportsPointerAccelerationProfileAdaptive",
        "supportsPointerAccelerationProfileFlat",
        "supportsPressureRange",
        "supportsRotation",
        "supportsScrollEdge",
        "supportsScrollOnButtonDown",
        "supportsScrollTwoFinger",
        "switchDevice",
        "sysName",
        "tabletModeSwitch",
        "tabletPad",
        "tabletPadButtonCount",
        "tabletPadDialCount",
        "tabletPadRingCount",
        "tabletPadStripCount",
        "tabletTool",
        "tabletToolIsRelative",
        "tapAndDrag",
        "tapAndDragEnabledByDefault",
        "tapDragLock",
        "tapDragLockEnabledByDefault",
        "tapFingerCount",
        "tapToClick",
        "tapToClickEnabledByDefault",
        "touch",
        "touchpad",
        "vendor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'calibrationMatrixChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clickMethodChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentModesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disableEventsOnExternalMouseChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disableWhileTypingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputAreaChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftHandedChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapToWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'middleEmulationChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'naturalScrollChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'orientationChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputAreaChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputNameChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationProfileChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressureCurveChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressureRangeMaxChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressureRangeMinChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rotationChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollButtonChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollFactorChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollMethodChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportsPressureRangeChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabletToolRelativeChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapAndDragChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapButtonMapChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapDragLockChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapToClickChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'alphaNumericKeyboard'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'calibrationMatrix'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'clickMethodAreas'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'clickMethodClickfinger'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'currentModes'
        QtMocHelpers::PropertyData<QList<uint>>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'defaultCalibrationMatrix'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'defaultClickMethodAreas'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'defaultClickMethodClickfinger'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'defaultInputArea'
        QtMocHelpers::PropertyData<QRectF>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'defaultMapToWorkspace'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'defaultOutputArea'
        QtMocHelpers::PropertyData<QRectF>(43, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'defaultPointerAcceleration'
        QtMocHelpers::PropertyData<double>(44, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'defaultPointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'defaultPointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'defaultPressureCurve'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'defaultPressureRangeMax'
        QtMocHelpers::PropertyData<double>(48, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'defaultPressureRangeMin'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'defaultScrollButton'
        QtMocHelpers::PropertyData<uint>(50, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'deviceGroupId'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'disableEventsOnExternalMouse'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'disableEventsOnExternalMouseEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'disableWhileTyping'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'disableWhileTypingEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'enabledByDefault'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'gestureSupport'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'inputArea'
        QtMocHelpers::PropertyData<QRectF>(59, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'isVirtual'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'keyboard'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'leftHanded'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'leftHandedEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'lidSwitch'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'lmrTapButtonMap'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'lmrTapButtonMapEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'mapToWorkspace'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'middleEmulation'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'middleEmulationEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(70, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'naturalScroll'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'naturalScrollEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'numModes'
        QtMocHelpers::PropertyData<QList<uint>>(73, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'orientationDBus'
        QtMocHelpers::PropertyData<int>(74, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'outputArea'
        QtMocHelpers::PropertyData<QRectF>(75, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'outputName'
        QtMocHelpers::PropertyData<QString>(76, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pointer'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'pointerAcceleration'
        QtMocHelpers::PropertyData<double>(78, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pressureCurve'
        QtMocHelpers::PropertyData<QString>(81, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pressureRangeMax'
        QtMocHelpers::PropertyData<double>(82, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pressureRangeMin'
        QtMocHelpers::PropertyData<double>(83, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'product'
        QtMocHelpers::PropertyData<uint>(84, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'scrollButton'
        QtMocHelpers::PropertyData<uint>(85, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'scrollEdge'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'scrollEdgeEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'scrollFactor'
        QtMocHelpers::PropertyData<double>(88, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'scrollOnButtonDown'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'scrollOnButtonDownEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'scrollTwoFinger'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'scrollTwoFingerEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'size'
        QtMocHelpers::PropertyData<QSizeF>(93, 0x80000000 | 94, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'supportedButtons'
        QtMocHelpers::PropertyData<int>(95, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'supportsCalibrationMatrix'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsClickMethodAreas'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsClickMethodClickfinger'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsDisableEvents'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsDisableEventsOnExternalMouse'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsDisableWhileTyping'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsInputArea'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsLeftHanded'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsLmrTapButtonMap'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsMiddleEmulation'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsNaturalScroll'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsOutputArea'
        QtMocHelpers::PropertyData<bool>(107, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsPointerAcceleration'
        QtMocHelpers::PropertyData<bool>(108, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsPointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsPointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsPressureRange'
        QtMocHelpers::PropertyData<bool>(111, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsRotation'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsScrollEdge'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsScrollOnButtonDown'
        QtMocHelpers::PropertyData<bool>(114, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'supportsScrollTwoFinger'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'switchDevice'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'sysName'
        QtMocHelpers::PropertyData<QString>(117, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'tabletModeSwitch'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'tabletPad'
        QtMocHelpers::PropertyData<bool>(119, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'tabletPadButtonCount'
        QtMocHelpers::PropertyData<uint>(120, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'tabletPadDialCount'
        QtMocHelpers::PropertyData<uint>(121, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'tabletPadRingCount'
        QtMocHelpers::PropertyData<uint>(122, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'tabletPadStripCount'
        QtMocHelpers::PropertyData<uint>(123, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'tabletTool'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'tabletToolIsRelative'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'tapAndDrag'
        QtMocHelpers::PropertyData<bool>(126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'tapAndDragEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(127, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'tapDragLock'
        QtMocHelpers::PropertyData<bool>(128, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'tapDragLockEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(129, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'tapFingerCount'
        QtMocHelpers::PropertyData<int>(130, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'tapToClick'
        QtMocHelpers::PropertyData<bool>(131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'tapToClickEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(132, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'touch'
        QtMocHelpers::PropertyData<bool>(133, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'touchpad'
        QtMocHelpers::PropertyData<bool>(134, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'vendor'
        QtMocHelpers::PropertyData<uint>(135, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKWinInputDeviceInterface, qt_meta_tag_ZN30OrgKdeKWinInputDeviceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKWinInputDeviceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30OrgKdeKWinInputDeviceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30OrgKdeKWinInputDeviceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30OrgKdeKWinInputDeviceInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKWinInputDeviceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKWinInputDeviceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->calibrationMatrixChanged(); break;
        case 1: _t->clickMethodChanged(); break;
        case 2: _t->currentModesChanged(); break;
        case 3: _t->disableEventsOnExternalMouseChanged(); break;
        case 4: _t->disableWhileTypingChanged(); break;
        case 5: _t->enabledChanged(); break;
        case 6: _t->inputAreaChanged(); break;
        case 7: _t->leftHandedChanged(); break;
        case 8: _t->mapToWorkspaceChanged(); break;
        case 9: _t->middleEmulationChanged(); break;
        case 10: _t->naturalScrollChanged(); break;
        case 11: _t->orientationChanged(); break;
        case 12: _t->outputAreaChanged(); break;
        case 13: _t->outputNameChanged(); break;
        case 14: _t->pointerAccelerationChanged(); break;
        case 15: _t->pointerAccelerationProfileChanged(); break;
        case 16: _t->pressureCurveChanged(); break;
        case 17: _t->pressureRangeMaxChanged(); break;
        case 18: _t->pressureRangeMinChanged(); break;
        case 19: _t->rotationChanged(); break;
        case 20: _t->scrollButtonChanged(); break;
        case 21: _t->scrollFactorChanged(); break;
        case 22: _t->scrollMethodChanged(); break;
        case 23: _t->supportsPressureRangeChanged(); break;
        case 24: _t->tabletToolRelativeChanged(); break;
        case 25: _t->tapAndDragChanged(); break;
        case 26: _t->tapButtonMapChanged(); break;
        case 27: _t->tapDragLockChanged(); break;
        case 28: _t->tapToClickChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::calibrationMatrixChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::clickMethodChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::currentModesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::disableEventsOnExternalMouseChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::disableWhileTypingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::inputAreaChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::leftHandedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::mapToWorkspaceChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::middleEmulationChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::naturalScrollChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::orientationChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::outputAreaChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::outputNameChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::pointerAccelerationChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::pointerAccelerationProfileChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::pressureCurveChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::pressureRangeMaxChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::pressureRangeMinChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::rotationChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::scrollButtonChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::scrollFactorChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::scrollMethodChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::supportsPressureRangeChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::tabletToolRelativeChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::tapAndDragChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::tapButtonMapChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::tapDragLockChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWinInputDeviceInterface::*)()>(_a, &OrgKdeKWinInputDeviceInterface::tapToClickChanged, 28))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 40:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<uint> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->alphaNumericKeyboard(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->calibrationMatrix(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->clickMethodAreas(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->clickMethodClickfinger(); break;
        case 4: *reinterpret_cast<QList<uint>*>(_v) = _t->currentModes(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->defaultCalibrationMatrix(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->defaultClickMethodAreas(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->defaultClickMethodClickfinger(); break;
        case 8: *reinterpret_cast<QRectF*>(_v) = _t->defaultInputArea(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->defaultMapToWorkspace(); break;
        case 10: *reinterpret_cast<QRectF*>(_v) = _t->defaultOutputArea(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultPointerAcceleration(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->defaultPointerAccelerationProfileAdaptive(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->defaultPointerAccelerationProfileFlat(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->defaultPressureCurve(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->defaultPressureRangeMax(); break;
        case 16: *reinterpret_cast<double*>(_v) = _t->defaultPressureRangeMin(); break;
        case 17: *reinterpret_cast<uint*>(_v) = _t->defaultScrollButton(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->deviceGroupId(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->disableEventsOnExternalMouse(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->disableEventsOnExternalMouseEnabledByDefault(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->disableWhileTyping(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->disableWhileTypingEnabledByDefault(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->enabledByDefault(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->gestureSupport(); break;
        case 26: *reinterpret_cast<QRectF*>(_v) = _t->inputArea(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isVirtual(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->keyboard(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->leftHanded(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->leftHandedEnabledByDefault(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->lidSwitch(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->lmrTapButtonMap(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->lmrTapButtonMapEnabledByDefault(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->mapToWorkspace(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->middleEmulation(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->middleEmulationEnabledByDefault(); break;
        case 37: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->naturalScroll(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->naturalScrollEnabledByDefault(); break;
        case 40: *reinterpret_cast<QList<uint>*>(_v) = _t->numModes(); break;
        case 41: *reinterpret_cast<int*>(_v) = _t->orientationDBus(); break;
        case 42: *reinterpret_cast<QRectF*>(_v) = _t->outputArea(); break;
        case 43: *reinterpret_cast<QString*>(_v) = _t->outputName(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->pointer(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->pointerAcceleration(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->pointerAccelerationProfileAdaptive(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->pointerAccelerationProfileFlat(); break;
        case 48: *reinterpret_cast<QString*>(_v) = _t->pressureCurve(); break;
        case 49: *reinterpret_cast<double*>(_v) = _t->pressureRangeMax(); break;
        case 50: *reinterpret_cast<double*>(_v) = _t->pressureRangeMin(); break;
        case 51: *reinterpret_cast<uint*>(_v) = _t->product(); break;
        case 52: *reinterpret_cast<uint*>(_v) = _t->scrollButton(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->scrollEdge(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->scrollEdgeEnabledByDefault(); break;
        case 55: *reinterpret_cast<double*>(_v) = _t->scrollFactor(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->scrollOnButtonDown(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->scrollOnButtonDownEnabledByDefault(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->scrollTwoFinger(); break;
        case 59: *reinterpret_cast<bool*>(_v) = _t->scrollTwoFingerEnabledByDefault(); break;
        case 60: *reinterpret_cast<QSizeF*>(_v) = _t->size(); break;
        case 61: *reinterpret_cast<int*>(_v) = _t->supportedButtons(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->supportsCalibrationMatrix(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->supportsClickMethodAreas(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->supportsClickMethodClickfinger(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->supportsDisableEvents(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->supportsDisableEventsOnExternalMouse(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->supportsDisableWhileTyping(); break;
        case 68: *reinterpret_cast<bool*>(_v) = _t->supportsInputArea(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->supportsLeftHanded(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->supportsLmrTapButtonMap(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->supportsMiddleEmulation(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->supportsNaturalScroll(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->supportsOutputArea(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAcceleration(); break;
        case 75: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAccelerationProfileAdaptive(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAccelerationProfileFlat(); break;
        case 77: *reinterpret_cast<bool*>(_v) = _t->supportsPressureRange(); break;
        case 78: *reinterpret_cast<bool*>(_v) = _t->supportsRotation(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->supportsScrollEdge(); break;
        case 80: *reinterpret_cast<bool*>(_v) = _t->supportsScrollOnButtonDown(); break;
        case 81: *reinterpret_cast<bool*>(_v) = _t->supportsScrollTwoFinger(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->switchDevice(); break;
        case 83: *reinterpret_cast<QString*>(_v) = _t->sysName(); break;
        case 84: *reinterpret_cast<bool*>(_v) = _t->tabletModeSwitch(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->tabletPad(); break;
        case 86: *reinterpret_cast<uint*>(_v) = _t->tabletPadButtonCount(); break;
        case 87: *reinterpret_cast<uint*>(_v) = _t->tabletPadDialCount(); break;
        case 88: *reinterpret_cast<uint*>(_v) = _t->tabletPadRingCount(); break;
        case 89: *reinterpret_cast<uint*>(_v) = _t->tabletPadStripCount(); break;
        case 90: *reinterpret_cast<bool*>(_v) = _t->tabletTool(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->tabletToolIsRelative(); break;
        case 92: *reinterpret_cast<bool*>(_v) = _t->tapAndDrag(); break;
        case 93: *reinterpret_cast<bool*>(_v) = _t->tapAndDragEnabledByDefault(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->tapDragLock(); break;
        case 95: *reinterpret_cast<bool*>(_v) = _t->tapDragLockEnabledByDefault(); break;
        case 96: *reinterpret_cast<int*>(_v) = _t->tapFingerCount(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->tapToClick(); break;
        case 98: *reinterpret_cast<bool*>(_v) = _t->tapToClickEnabledByDefault(); break;
        case 99: *reinterpret_cast<bool*>(_v) = _t->touch(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->touchpad(); break;
        case 101: *reinterpret_cast<uint*>(_v) = _t->vendor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCalibrationMatrix(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setClickMethodAreas(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setClickMethodClickfinger(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setDisableEventsOnExternalMouse(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setDisableWhileTyping(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setInputArea(*reinterpret_cast<QRectF*>(_v)); break;
        case 29: _t->setLeftHanded(*reinterpret_cast<bool*>(_v)); break;
        case 32: _t->setLmrTapButtonMap(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setMapToWorkspace(*reinterpret_cast<bool*>(_v)); break;
        case 35: _t->setMiddleEmulation(*reinterpret_cast<bool*>(_v)); break;
        case 38: _t->setNaturalScroll(*reinterpret_cast<bool*>(_v)); break;
        case 41: _t->setOrientationDBus(*reinterpret_cast<int*>(_v)); break;
        case 42: _t->setOutputArea(*reinterpret_cast<QRectF*>(_v)); break;
        case 43: _t->setOutputName(*reinterpret_cast<QString*>(_v)); break;
        case 45: _t->setPointerAcceleration(*reinterpret_cast<double*>(_v)); break;
        case 46: _t->setPointerAccelerationProfileAdaptive(*reinterpret_cast<bool*>(_v)); break;
        case 47: _t->setPointerAccelerationProfileFlat(*reinterpret_cast<bool*>(_v)); break;
        case 48: _t->setPressureCurve(*reinterpret_cast<QString*>(_v)); break;
        case 49: _t->setPressureRangeMax(*reinterpret_cast<double*>(_v)); break;
        case 50: _t->setPressureRangeMin(*reinterpret_cast<double*>(_v)); break;
        case 52: _t->setScrollButton(*reinterpret_cast<uint*>(_v)); break;
        case 53: _t->setScrollEdge(*reinterpret_cast<bool*>(_v)); break;
        case 55: _t->setScrollFactor(*reinterpret_cast<double*>(_v)); break;
        case 56: _t->setScrollOnButtonDown(*reinterpret_cast<bool*>(_v)); break;
        case 58: _t->setScrollTwoFinger(*reinterpret_cast<bool*>(_v)); break;
        case 91: _t->setTabletToolIsRelative(*reinterpret_cast<bool*>(_v)); break;
        case 92: _t->setTapAndDrag(*reinterpret_cast<bool*>(_v)); break;
        case 94: _t->setTapDragLock(*reinterpret_cast<bool*>(_v)); break;
        case 97: _t->setTapToClick(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgKdeKWinInputDeviceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKWinInputDeviceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30OrgKdeKWinInputDeviceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKWinInputDeviceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 102;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKWinInputDeviceInterface::calibrationMatrixChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OrgKdeKWinInputDeviceInterface::clickMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OrgKdeKWinInputDeviceInterface::currentModesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OrgKdeKWinInputDeviceInterface::disableEventsOnExternalMouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OrgKdeKWinInputDeviceInterface::disableWhileTypingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OrgKdeKWinInputDeviceInterface::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OrgKdeKWinInputDeviceInterface::inputAreaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void OrgKdeKWinInputDeviceInterface::leftHandedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void OrgKdeKWinInputDeviceInterface::mapToWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void OrgKdeKWinInputDeviceInterface::middleEmulationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void OrgKdeKWinInputDeviceInterface::naturalScrollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void OrgKdeKWinInputDeviceInterface::orientationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void OrgKdeKWinInputDeviceInterface::outputAreaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void OrgKdeKWinInputDeviceInterface::outputNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void OrgKdeKWinInputDeviceInterface::pointerAccelerationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void OrgKdeKWinInputDeviceInterface::pointerAccelerationProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void OrgKdeKWinInputDeviceInterface::pressureCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void OrgKdeKWinInputDeviceInterface::pressureRangeMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void OrgKdeKWinInputDeviceInterface::pressureRangeMinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void OrgKdeKWinInputDeviceInterface::rotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void OrgKdeKWinInputDeviceInterface::scrollButtonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void OrgKdeKWinInputDeviceInterface::scrollFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void OrgKdeKWinInputDeviceInterface::scrollMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void OrgKdeKWinInputDeviceInterface::supportsPressureRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void OrgKdeKWinInputDeviceInterface::tabletToolRelativeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void OrgKdeKWinInputDeviceInterface::tapAndDragChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void OrgKdeKWinInputDeviceInterface::tapButtonMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void OrgKdeKWinInputDeviceInterface::tapDragLockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void OrgKdeKWinInputDeviceInterface::tapToClickChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}
QT_WARNING_POP
