// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef DESKTOPPATHSDATA_H
#define DESKTOPPATHSDATA_H

#include <QObject>

#include "kcmoduledata.h"



class DesktopPathsSettings;


class DesktopPathsData : public KCModuleData
{
    Q_OBJECT

public:
    explicit DesktopPathsData(QObject *parent = nullptr);
    DesktopPathsSettings *settings() const;


private:
    DesktopPathsSettings *m_settings;

};



#endif
