// This file is generated by kconfig_compiler_kf6 from emojiersettings.kcfg.
// All changes you do to this file will be lost.

#include "emojiersettings.h"

EmojierSettings::EmojierSettings( )
  : KConfigSkeleton( KSharedConfig::openStateConfig(QStringLiteral( "") ) )
{
  setCurrentGroup( QStringLiteral( "Emojier" ) );

  KConfigSkeleton::ItemStringList  *itemRecent;
  itemRecent = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "recent" ), mRecent );
  addItem( itemRecent, QStringLiteral( "recent" ) );
  KConfigSkeleton::ItemStringList  *itemRecentDescriptions;
  itemRecentDescriptions = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "recentDescriptions" ), mRecentDescriptions );
  addItem( itemRecentDescriptions, QStringLiteral( "recentDescriptions" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesskinTone;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("HasNoVariants");
    valuesskinTone.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Neutral");
    valuesskinTone.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Light");
    valuesskinTone.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MediumLight");
    valuesskinTone.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Medium");
    valuesskinTone.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MediumDark");
    valuesskinTone.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Dark");
    valuesskinTone.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemSkinTone;
  itemSkinTone = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "skinTone" ), mSkinTone, valuesskinTone, Neutral );
  addItem( itemSkinTone, QStringLiteral( "skinTone" ) );
}

EmojierSettings::~EmojierSettings()
{
}

