/****************************************************************************
** Meta object code from reading C++ file 'inputsequence.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/kcms/tablet/inputsequence.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputsequence.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13InputSequenceE_t {};
} // unnamed namespace

template <> constexpr inline auto InputSequence::qt_create_metaobjectdata<qt_meta_tag_ZN13InputSequenceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputSequence",
        "toString",
        "",
        "keySequence",
        "QKeySequence",
        "setKeySequence",
        "sequence",
        "upKeySequence",
        "setUpKeySequence",
        "downKeySequence",
        "setDownKeySequence",
        "threshold",
        "setThreshold",
        "mouseButton",
        "Qt::MouseButton",
        "setMouseButton",
        "button",
        "keyboardModifiers",
        "Qt::KeyboardModifiers",
        "setKeyboardModifiers",
        "modifiers",
        "penButton",
        "setPenButton",
        "type",
        "InputSequence::Type",
        "Type",
        "Disabled",
        "Keyboard",
        "RelativeKeyboard",
        "Mouse",
        "Pen",
        "Scroll",
        "ApplicationDefined"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString() const>(1, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'keySequence'
        QtMocHelpers::MethodData<QKeySequence() const>(3, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'setKeySequence'
        QtMocHelpers::MethodData<void(const QKeySequence &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 6 },
        }}),
        // Method 'upKeySequence'
        QtMocHelpers::MethodData<QKeySequence() const>(7, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'setUpKeySequence'
        QtMocHelpers::MethodData<void(const QKeySequence &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 6 },
        }}),
        // Method 'downKeySequence'
        QtMocHelpers::MethodData<QKeySequence() const>(9, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'setDownKeySequence'
        QtMocHelpers::MethodData<void(const QKeySequence &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 6 },
        }}),
        // Method 'threshold'
        QtMocHelpers::MethodData<int() const>(11, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'setThreshold'
        QtMocHelpers::MethodData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'mouseButton'
        QtMocHelpers::MethodData<Qt::MouseButton() const>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Method 'setMouseButton'
        QtMocHelpers::MethodData<void(Qt::MouseButton)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 16 },
        }}),
        // Method 'keyboardModifiers'
        QtMocHelpers::MethodData<Qt::KeyboardModifiers() const>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'setKeyboardModifiers'
        QtMocHelpers::MethodData<void(Qt::KeyboardModifiers)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 20 },
        }}),
        // Method 'penButton'
        QtMocHelpers::MethodData<int() const>(21, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'setPenButton'
        QtMocHelpers::MethodData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<InputSequence::Type>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(25, 25, QMC::EnumIsScoped).add({
            {   26, Type::Disabled },
            {   27, Type::Keyboard },
            {   28, Type::RelativeKeyboard },
            {   29, Type::Mouse },
            {   30, Type::Pen },
            {   31, Type::Scroll },
            {   32, Type::ApplicationDefined },
        }),
    };
    return QtMocHelpers::metaObjectData<InputSequence, qt_meta_tag_ZN13InputSequenceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InputSequence::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13InputSequenceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13InputSequenceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13InputSequenceE_t>.metaTypes,
    nullptr
} };

void InputSequence::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<InputSequence *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QKeySequence _r = _t->keySequence();
            if (_a[0]) *reinterpret_cast<QKeySequence*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->setKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 3: { QKeySequence _r = _t->upKeySequence();
            if (_a[0]) *reinterpret_cast<QKeySequence*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setUpKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 5: { QKeySequence _r = _t->downKeySequence();
            if (_a[0]) *reinterpret_cast<QKeySequence*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setDownKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 7: { int _r = _t->threshold();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setThreshold((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: { Qt::MouseButton _r = _t->mouseButton();
            if (_a[0]) *reinterpret_cast<Qt::MouseButton*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setMouseButton((*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[1]))); break;
        case 11: { Qt::KeyboardModifiers _r = _t->keyboardModifiers();
            if (_a[0]) *reinterpret_cast<Qt::KeyboardModifiers*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setKeyboardModifiers((*reinterpret_cast<std::add_pointer_t<Qt::KeyboardModifiers>>(_a[1]))); break;
        case 13: { int _r = _t->penButton();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setPenButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<InputSequence::Type*>(_v) = _t->type(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setType(*reinterpret_cast<InputSequence::Type*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
