/****************************************************************************
** Meta object code from reading C++ file 'libinputcommon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/kcms/touchpad/backends/libinputcommon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'libinputcommon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14LibinputCommonE_t {};
} // unnamed namespace

template <> constexpr inline auto LibinputCommon::qt_create_metaobjectdata<qt_meta_tag_ZN14LibinputCommonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LibinputCommon",
        "enabledChanged",
        "",
        "tapToClickChanged",
        "lmrTapButtonMapChanged",
        "tapAndDragChanged",
        "tapDragLockChanged",
        "leftHandedChanged",
        "disableEventsOnExternalMouseChanged",
        "disableWhileTypingChanged",
        "middleEmulationChanged",
        "pointerAccelerationChanged",
        "pointerAccelerationProfileFlatChanged",
        "pointerAccelerationProfileAdaptiveChanged",
        "naturalScrollChanged",
        "horizontalScrollingChanged",
        "scrollTwoFingerChanged",
        "scrollEdgeChanged",
        "scrollOnButtonDownChanged",
        "scrollButtonChanged",
        "scrollFactorChanged",
        "clickMethodAreasChanged",
        "clickMethodClickfingerChanged",
        "name",
        "supportsDisableEvents",
        "enabled",
        "supportedButtons",
        "Qt::MouseButtons",
        "supportsLeftHanded",
        "leftHandedEnabledByDefault",
        "leftHanded",
        "supportsDisableEventsOnExternalMouse",
        "disableEventsOnExternalMouseEnabledByDefault",
        "disableEventsOnExternalMouse",
        "supportsDisableWhileTyping",
        "disableWhileTypingEnabledByDefault",
        "disableWhileTyping",
        "supportsMiddleEmulation",
        "middleEmulationEnabledByDefault",
        "middleEmulation",
        "supportsPointerAcceleration",
        "pointerAcceleration",
        "supportsPointerAccelerationProfileFlat",
        "defaultPointerAccelerationProfileFlat",
        "pointerAccelerationProfileFlat",
        "supportsPointerAccelerationProfileAdaptive",
        "defaultPointerAccelerationProfileAdaptive",
        "pointerAccelerationProfileAdaptive",
        "tapFingerCount",
        "tapToClickEnabledByDefault",
        "tapToClick",
        "supportsLmrTapButtonMap",
        "lmrTapButtonMapEnabledByDefault",
        "lmrTapButtonMap",
        "tapAndDragEnabledByDefault",
        "tapAndDrag",
        "tapDragLockEnabledByDefault",
        "tapDragLock",
        "supportsNaturalScroll",
        "naturalScrollEnabledByDefault",
        "naturalScroll",
        "supportsHorizontalScrolling",
        "horizontalScrollingByDefault",
        "horizontalScrolling",
        "supportsScrollTwoFinger",
        "scrollTwoFingerEnabledByDefault",
        "scrollTwoFinger",
        "supportsScrollEdge",
        "scrollEdgeEnabledByDefault",
        "scrollEdge",
        "supportsScrollOnButtonDown",
        "scrollOnButtonDownEnabledByDefault",
        "scrollOnButtonDown",
        "defaultScrollButton",
        "scrollButton",
        "supportsClickMethodAreas",
        "defaultClickMethodAreas",
        "clickMethodAreas",
        "supportsClickMethodClickfinger",
        "defaultClickMethodClickfinger",
        "clickMethodClickfinger",
        "supportsScrollFactor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapToClickChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lmrTapButtonMapChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapAndDragChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapDragLockChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftHandedChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disableEventsOnExternalMouseChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disableWhileTypingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'middleEmulationChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationProfileFlatChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationProfileAdaptiveChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'naturalScrollChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalScrollingChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollTwoFingerChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollEdgeChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollOnButtonDownChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollButtonChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollFactorChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clickMethodAreasChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clickMethodClickfingerChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supportsDisableEvents'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'supportedButtons'
        QtMocHelpers::PropertyData<Qt::MouseButtons>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'supportsLeftHanded'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'leftHandedEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'leftHanded'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'supportsDisableEventsOnExternalMouse'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disableEventsOnExternalMouseEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disableEventsOnExternalMouse'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'supportsDisableWhileTyping'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disableWhileTypingEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disableWhileTyping'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'supportsMiddleEmulation'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'middleEmulationEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'middleEmulation'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'supportsPointerAcceleration'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pointerAcceleration'
        QtMocHelpers::PropertyData<qreal>(41, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'supportsPointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'supportsPointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'tapFingerCount'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tapToClickEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tapToClick'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'supportsLmrTapButtonMap'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lmrTapButtonMapEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lmrTapButtonMap'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'tapAndDragEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tapAndDrag'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'tapDragLockEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tapDragLock'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'supportsNaturalScroll'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'naturalScrollEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'naturalScroll'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'supportsHorizontalScrolling'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'horizontalScrollingByDefault'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'horizontalScrolling'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'supportsScrollTwoFinger'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollTwoFingerEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollTwoFinger'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'supportsScrollEdge'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollEdgeEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollEdge'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'supportsScrollOnButtonDown'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollOnButtonDownEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollOnButtonDown'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'defaultScrollButton'
        QtMocHelpers::PropertyData<quint32>(73, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollButton'
        QtMocHelpers::PropertyData<quint32>(74, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'supportsClickMethodAreas'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClickMethodAreas'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clickMethodAreas'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'supportsClickMethodClickfinger'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClickMethodClickfinger'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clickMethodClickfinger'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'supportsScrollFactor'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LibinputCommon, qt_meta_tag_ZN14LibinputCommonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LibinputCommon::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LibinputCommonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LibinputCommonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14LibinputCommonE_t>.metaTypes,
    nullptr
} };

void LibinputCommon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LibinputCommon *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->tapToClickChanged(); break;
        case 2: _t->lmrTapButtonMapChanged(); break;
        case 3: _t->tapAndDragChanged(); break;
        case 4: _t->tapDragLockChanged(); break;
        case 5: _t->leftHandedChanged(); break;
        case 6: _t->disableEventsOnExternalMouseChanged(); break;
        case 7: _t->disableWhileTypingChanged(); break;
        case 8: _t->middleEmulationChanged(); break;
        case 9: _t->pointerAccelerationChanged(); break;
        case 10: _t->pointerAccelerationProfileFlatChanged(); break;
        case 11: _t->pointerAccelerationProfileAdaptiveChanged(); break;
        case 12: _t->naturalScrollChanged(); break;
        case 13: _t->horizontalScrollingChanged(); break;
        case 14: _t->scrollTwoFingerChanged(); break;
        case 15: _t->scrollEdgeChanged(); break;
        case 16: _t->scrollOnButtonDownChanged(); break;
        case 17: _t->scrollButtonChanged(); break;
        case 18: _t->scrollFactorChanged(); break;
        case 19: _t->clickMethodAreasChanged(); break;
        case 20: _t->clickMethodClickfingerChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::tapToClickChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::lmrTapButtonMapChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::tapAndDragChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::tapDragLockChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::leftHandedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::disableEventsOnExternalMouseChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::disableWhileTypingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::middleEmulationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::pointerAccelerationChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::pointerAccelerationProfileFlatChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::pointerAccelerationProfileAdaptiveChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::naturalScrollChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::horizontalScrollingChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::scrollTwoFingerChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::scrollEdgeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::scrollOnButtonDownChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::scrollButtonChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::scrollFactorChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::clickMethodAreasChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibinputCommon::*)()>(_a, &LibinputCommon::clickMethodClickfingerChanged, 20))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->supportsDisableEvents(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 3: *reinterpret_cast<Qt::MouseButtons*>(_v) = _t->supportedButtons(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->supportsLeftHanded(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->leftHandedEnabledByDefault(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isLeftHanded(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->supportsDisableEventsOnExternalMouse(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->disableEventsOnExternalMouseEnabledByDefault(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isDisableEventsOnExternalMouse(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->supportsDisableWhileTyping(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->disableWhileTypingEnabledByDefault(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isDisableWhileTyping(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->supportsMiddleEmulation(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->middleEmulationEnabledByDefault(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isMiddleEmulation(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAcceleration(); break;
        case 17: *reinterpret_cast<qreal*>(_v) = _t->pointerAcceleration(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAccelerationProfileFlat(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->defaultPointerAccelerationProfileFlat(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->pointerAccelerationProfileFlat(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAccelerationProfileAdaptive(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->defaultPointerAccelerationProfileAdaptive(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->pointerAccelerationProfileAdaptive(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->tapFingerCount(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->tapToClickEnabledByDefault(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isTapToClick(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->supportsLmrTapButtonMap(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->lmrTapButtonMapEnabledByDefault(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->lmrTapButtonMap(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->tapAndDragEnabledByDefault(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isTapAndDrag(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->tapDragLockEnabledByDefault(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isTapDragLock(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->supportsNaturalScroll(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->naturalScrollEnabledByDefault(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->isNaturalScroll(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->supportsHorizontalScrolling(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->horizontalScrollingByDefault(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->horizontalScrolling(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->supportsScrollTwoFinger(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->scrollTwoFingerEnabledByDefault(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->isScrollTwoFinger(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->supportsScrollEdge(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->scrollEdgeEnabledByDefault(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->isScrollEdge(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->supportsScrollOnButtonDown(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->scrollOnButtonDownEnabledByDefault(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->isScrollOnButtonDown(); break;
        case 49: *reinterpret_cast<quint32*>(_v) = _t->defaultScrollButton(); break;
        case 50: *reinterpret_cast<quint32*>(_v) = _t->scrollButton(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->supportsClickMethodAreas(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->defaultClickMethodAreas(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->isClickMethodAreas(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->supportsClickMethodClickfinger(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->defaultClickMethodClickfinger(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->isClickMethodClickfinger(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->supportsScrollFactor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setLeftHanded(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setDisableEventsOnExternalMouse(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setDisableWhileTyping(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setMiddleEmulation(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setPointerAcceleration(*reinterpret_cast<qreal*>(_v)); break;
        case 20: _t->setPointerAccelerationProfileFlat(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setPointerAccelerationProfileAdaptive(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setTapToClick(*reinterpret_cast<bool*>(_v)); break;
        case 29: _t->setLmrTapButtonMap(*reinterpret_cast<bool*>(_v)); break;
        case 31: _t->setTapAndDrag(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setTapDragLock(*reinterpret_cast<bool*>(_v)); break;
        case 36: _t->setNaturalScroll(*reinterpret_cast<bool*>(_v)); break;
        case 39: _t->setHorizontalScrolling(*reinterpret_cast<bool*>(_v)); break;
        case 42: _t->setScrollTwoFinger(*reinterpret_cast<bool*>(_v)); break;
        case 45: _t->setScrollEdge(*reinterpret_cast<bool*>(_v)); break;
        case 48: _t->setScrollOnButtonDown(*reinterpret_cast<bool*>(_v)); break;
        case 50: _t->setScrollButton(*reinterpret_cast<quint32*>(_v)); break;
        case 53: _t->setClickMethodAreas(*reinterpret_cast<bool*>(_v)); break;
        case 56: _t->setClickMethodClickfinger(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LibinputCommon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LibinputCommon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LibinputCommonE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LibinputCommon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 58;
    }
    return _id;
}

// SIGNAL 0
void LibinputCommon::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LibinputCommon::tapToClickChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LibinputCommon::lmrTapButtonMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LibinputCommon::tapAndDragChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LibinputCommon::tapDragLockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LibinputCommon::leftHandedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void LibinputCommon::disableEventsOnExternalMouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void LibinputCommon::disableWhileTypingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void LibinputCommon::middleEmulationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void LibinputCommon::pointerAccelerationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void LibinputCommon::pointerAccelerationProfileFlatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void LibinputCommon::pointerAccelerationProfileAdaptiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void LibinputCommon::naturalScrollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void LibinputCommon::horizontalScrollingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void LibinputCommon::scrollTwoFingerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void LibinputCommon::scrollEdgeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void LibinputCommon::scrollOnButtonDownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void LibinputCommon::scrollButtonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void LibinputCommon::scrollFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void LibinputCommon::clickMethodAreasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void LibinputCommon::clickMethodClickfingerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
