/****************************************************************************
** Meta object code from reading C++ file 'tabletevents.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/kcms/tablet/tabletevents.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabletevents.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12TabletEventsE_t {};
} // unnamed namespace

template <> constexpr inline auto TabletEvents::qt_create_metaobjectdata<qt_meta_tag_ZN12TabletEventsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabletEvents",
        "padButtonReceived",
        "",
        "path",
        "button",
        "pressed",
        "toolButtonReceived",
        "uint32_t",
        "hardware_serial_hi",
        "hardware_serial_lo",
        "toolDown",
        "x",
        "y",
        "toolMotion",
        "pressure",
        "tilt_x",
        "tilt_y",
        "toolUp",
        "dialDelta",
        "value120"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'padButtonReceived'
        QtMocHelpers::SignalData<void(const QString &, uint, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'toolButtonReceived'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, uint, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 }, { QMetaType::UInt, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'toolDown'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, double, double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 }, { QMetaType::Double, 11 }, { QMetaType::Double, 12 },
        }}),
        // Signal 'toolMotion'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, double, double, double, double, double)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 }, { QMetaType::Double, 11 }, { QMetaType::Double, 12 },
            { QMetaType::Double, 14 }, { QMetaType::Double, 15 }, { QMetaType::Double, 16 },
        }}),
        // Signal 'toolUp'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, double, double)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 }, { QMetaType::Double, 11 }, { QMetaType::Double, 12 },
        }}),
        // Signal 'dialDelta'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabletEvents, qt_meta_tag_ZN12TabletEventsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabletEvents::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TabletEventsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TabletEventsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12TabletEventsE_t>.metaTypes,
    nullptr
} };

void TabletEvents::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabletEvents *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->padButtonReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->toolButtonReceived((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 2: _t->toolDown((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 3: _t->toolMotion((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[7]))); break;
        case 4: _t->toolUp((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 5: _t->dialDelta((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabletEvents::*)(const QString & , uint , bool )>(_a, &TabletEvents::padButtonReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletEvents::*)(uint32_t , uint32_t , uint , bool )>(_a, &TabletEvents::toolButtonReceived, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletEvents::*)(uint32_t , uint32_t , double , double )>(_a, &TabletEvents::toolDown, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletEvents::*)(uint32_t , uint32_t , double , double , double , double , double )>(_a, &TabletEvents::toolMotion, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletEvents::*)(uint32_t , uint32_t , double , double )>(_a, &TabletEvents::toolUp, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletEvents::*)(int )>(_a, &TabletEvents::dialDelta, 5))
            return;
    }
}

const QMetaObject *TabletEvents::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabletEvents::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TabletEventsE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int TabletEvents::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void TabletEvents::padButtonReceived(const QString & _t1, uint _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void TabletEvents::toolButtonReceived(uint32_t _t1, uint32_t _t2, uint _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void TabletEvents::toolDown(uint32_t _t1, uint32_t _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void TabletEvents::toolMotion(uint32_t _t1, uint32_t _t2, double _t3, double _t4, double _t5, double _t6, double _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 4
void TabletEvents::toolUp(uint32_t _t1, uint32_t _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void TabletEvents::dialDelta(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
