// This file is generated by kconfig_compiler_kf6 from LayoutSettings.kcfg.
// All changes you do to this file will be lost.
#ifndef LAYOUTSETTINGS_H
#define LAYOUTSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class LayoutSettings : public KConfigSkeleton
{
  public:

    static LayoutSettings *self();
    ~LayoutSettings() override;

    /**
      Set HeaderWidths
    */
    static
    void setHeaderWidths( const QList<int> & v )
    {
      if (!self()->isHeaderWidthsImmutable())
        self()->mHeaderWidths = v;
    }

    /**
      Get HeaderWidths
    */
    static
    QList<int> headerWidths()
    {
      return self()->mHeaderWidths;
    }

    /**
      Is HeaderWidths Immutable
    */
    static
    bool isHeaderWidthsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "HeaderWidths" ) );
    }

    /**
      Set AttachedExpanded
    */
    static
    void setAttachedExpanded( bool v )
    {
      if (!self()->isAttachedExpandedImmutable())
        self()->mAttachedExpanded = v;
    }

    /**
      Get AttachedExpanded
    */
    static
    bool attachedExpanded()
    {
      return self()->mAttachedExpanded;
    }

    /**
      Is AttachedExpanded Immutable
    */
    static
    bool isAttachedExpandedImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AttachedExpanded" ) );
    }

    /**
      Set DetachedExpanded
    */
    static
    void setDetachedExpanded( bool v )
    {
      if (!self()->isDetachedExpandedImmutable())
        self()->mDetachedExpanded = v;
    }

    /**
      Get DetachedExpanded
    */
    static
    bool detachedExpanded()
    {
      return self()->mDetachedExpanded;
    }

    /**
      Is DetachedExpanded Immutable
    */
    static
    bool isDetachedExpandedImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DetachedExpanded" ) );
    }

  protected:
    LayoutSettings();
    friend class LayoutSettingsHelper;


    // Layout
    QList<int> mHeaderWidths;
    bool mAttachedExpanded;
    bool mDetachedExpanded;
};

#endif

