// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef KEYBOARDSETTINGSDATA_H
#define KEYBOARDSETTINGSDATA_H

#include <QObject>

#include "kcmoduledata.h"



class WorkspaceOptions;
class KeyboardMiscSettings;
class KeyboardSettings;


class KeyboardSettingsData : public KCModuleData
{
    Q_OBJECT

public:
    explicit KeyboardSettingsData(QObject *parent = nullptr);
    WorkspaceOptions *workspaceOptions() const;
KeyboardMiscSettings *keyboardMiscSettings() const;
KeyboardSettings *keyboardSettings() const;


private:
    WorkspaceOptions *m_workspaceOptions;
KeyboardMiscSettings *m_keyboardMiscSettings;
KeyboardSettings *m_keyboardSettings;

};



#endif
