/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<applauncher.h>)
#  include <applauncher.h>
#endif
#if __has_include(<desktopschemehelper.h>)
#  include <desktopschemehelper.h>
#endif
#if __has_include(<directorypicker.h>)
#  include <directorypicker.h>
#endif
#if __has_include(<eventgenerator.h>)
#  include <eventgenerator.h>
#endif
#if __has_include(<foldermodel.h>)
#  include <foldermodel.h>
#endif
#if __has_include(<itemviewadapter.h>)
#  include <itemviewadapter.h>
#endif
#if __has_include(<labelgenerator.h>)
#  include <labelgenerator.h>
#endif
#if __has_include(<menuhelper.h>)
#  include <menuhelper.h>
#endif
#if __has_include(<mimetypesmodel.h>)
#  include <mimetypesmodel.h>
#endif
#if __has_include(<placesmodel.h>)
#  include <placesmodel.h>
#endif
#if __has_include(<positioner.h>)
#  include <positioner.h>
#endif
#if __has_include(<previewpluginsmodel.h>)
#  include <previewpluginsmodel.h>
#endif
#if __has_include(<shortcut.h>)
#  include <shortcut.h>
#endif
#if __has_include(<subdialog.h>)
#  include <subdialog.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif
#if __has_include(<viewpropertiesmenu.h>)
#  include <viewpropertiesmenu.h>
#endif
#if __has_include(<wheelinterceptor.h>)
#  include <wheelinterceptor.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_private_desktopcontainment_folder()
{
    qmlRegisterModule("org.kde.private.desktopcontainment.folder", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AppLauncher>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<DesktopSchemeHelper>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<DirectoryPicker>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<DropJobForeign>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<EventGenerator>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterEnum<EventGenerator::MouseEvent>("EventGenerator::MouseEvent");
    qmlRegisterTypesAndRevisions<FolderModel>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterEnum<FolderModel::Status>("FolderModel::Status");
    qmlRegisterTypesAndRevisions<ItemViewAdapter>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<LabelGenerator>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<MenuHelper>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<MimeTypesModel>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<PlacesModel>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<Positioner>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<PreviewPluginsModel>("org.kde.private.desktopcontainment.folder", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<ShortCut>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<SubDialog>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<ViewPropertiesMenu>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterTypesAndRevisions<WheelInterceptor>("org.kde.private.desktopcontainment.folder", 254);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.private.desktopcontainment.folder", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.private.desktopcontainment.folder", 254, 254);
}

static const QQmlModuleRegistration orgkdeprivatedesktopcontainmentfolderRegistration("org.kde.private.desktopcontainment.folder", qml_register_types_org_kde_private_desktopcontainment_folder);
