/********************************************************************************
** Form generated from reading UI file 'ActionEditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ACTIONEDITOR_H
#define UI_ACTIONEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kiconbutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ActionEditor
{
public:
    QGridLayout *gridLayout_5;
    QGroupBox *GbParameter;
    QGridLayout *gridLayout_2;
    QGridLayout *GlParameterType;
    QLabel *LblParameterType;
    QComboBox *CbParameterType;
    QGridLayout *GlDeviceType;
    QLabel *LblDeviceType;
    QComboBox *CbDeviceType;
    QGridLayout *GlValueName;
    QLabel *LblValueName;
    QComboBox *CbValueName;
    QGridLayout *GlValueMatch;
    QComboBox *CbValueMatch;
    QLineEdit *LeValueMatch;
    QGridLayout *GlParameterControl;
    QSpacerItem *HsParameterControl;
    QPushButton *PbParameterReset;
    QPushButton *PbParameterSave;
    QGridLayout *GlActionIconName;
    KIconButton *IbActionIcon;
    QLineEdit *LeActionFriendlyName;
    QGridLayout *GlActionCommand;
    QLabel *TlActionCommand;
    KUrlRequester *LeActionCommand;
    QGridLayout *GlPredicateTree;
    QLabel *TlPredicateTree;
    QTreeView *TvPredicateTree;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *ActionEditor)
    {
        if (ActionEditor->objectName().isEmpty())
            ActionEditor->setObjectName("ActionEditor");
        ActionEditor->resize(602, 522);
        gridLayout_5 = new QGridLayout(ActionEditor);
        gridLayout_5->setObjectName("gridLayout_5");
        GbParameter = new QGroupBox(ActionEditor);
        GbParameter->setObjectName("GbParameter");
        gridLayout_2 = new QGridLayout(GbParameter);
        gridLayout_2->setObjectName("gridLayout_2");
        GlParameterType = new QGridLayout();
        GlParameterType->setObjectName("GlParameterType");
        LblParameterType = new QLabel(GbParameter);
        LblParameterType->setObjectName("LblParameterType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(LblParameterType->sizePolicy().hasHeightForWidth());
        LblParameterType->setSizePolicy(sizePolicy);
        LblParameterType->setMinimumSize(QSize(150, 0));
        LblParameterType->setMaximumSize(QSize(150, 16777215));

        GlParameterType->addWidget(LblParameterType, 0, 0, 1, 1);

        CbParameterType = new QComboBox(GbParameter);
        CbParameterType->addItem(QString());
        CbParameterType->addItem(QString());
        CbParameterType->addItem(QString());
        CbParameterType->addItem(QString());
        CbParameterType->setObjectName("CbParameterType");

        GlParameterType->addWidget(CbParameterType, 0, 1, 1, 1);


        gridLayout_2->addLayout(GlParameterType, 0, 0, 1, 1);

        GlDeviceType = new QGridLayout();
        GlDeviceType->setObjectName("GlDeviceType");
        LblDeviceType = new QLabel(GbParameter);
        LblDeviceType->setObjectName("LblDeviceType");
        sizePolicy.setHeightForWidth(LblDeviceType->sizePolicy().hasHeightForWidth());
        LblDeviceType->setSizePolicy(sizePolicy);
        LblDeviceType->setMinimumSize(QSize(150, 0));
        LblDeviceType->setMaximumSize(QSize(150, 16777215));

        GlDeviceType->addWidget(LblDeviceType, 0, 0, 1, 1);

        CbDeviceType = new QComboBox(GbParameter);
        CbDeviceType->setObjectName("CbDeviceType");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(CbDeviceType->sizePolicy().hasHeightForWidth());
        CbDeviceType->setSizePolicy(sizePolicy1);

        GlDeviceType->addWidget(CbDeviceType, 0, 1, 1, 1);


        gridLayout_2->addLayout(GlDeviceType, 1, 0, 1, 1);

        GlValueName = new QGridLayout();
        GlValueName->setObjectName("GlValueName");
        LblValueName = new QLabel(GbParameter);
        LblValueName->setObjectName("LblValueName");
        sizePolicy.setHeightForWidth(LblValueName->sizePolicy().hasHeightForWidth());
        LblValueName->setSizePolicy(sizePolicy);
        LblValueName->setMinimumSize(QSize(150, 0));
        LblValueName->setMaximumSize(QSize(150, 16777215));

        GlValueName->addWidget(LblValueName, 0, 0, 1, 1);

        CbValueName = new QComboBox(GbParameter);
        CbValueName->setObjectName("CbValueName");
        sizePolicy1.setHeightForWidth(CbValueName->sizePolicy().hasHeightForWidth());
        CbValueName->setSizePolicy(sizePolicy1);

        GlValueName->addWidget(CbValueName, 0, 1, 1, 1);


        gridLayout_2->addLayout(GlValueName, 2, 0, 1, 1);

        GlValueMatch = new QGridLayout();
        GlValueMatch->setObjectName("GlValueMatch");
        CbValueMatch = new QComboBox(GbParameter);
        CbValueMatch->addItem(QString());
        CbValueMatch->addItem(QString());
        CbValueMatch->setObjectName("CbValueMatch");
        sizePolicy.setHeightForWidth(CbValueMatch->sizePolicy().hasHeightForWidth());
        CbValueMatch->setSizePolicy(sizePolicy);
        CbValueMatch->setMinimumSize(QSize(150, 0));
        CbValueMatch->setMaximumSize(QSize(150, 16777215));

        GlValueMatch->addWidget(CbValueMatch, 0, 0, 1, 1);

        LeValueMatch = new QLineEdit(GbParameter);
        LeValueMatch->setObjectName("LeValueMatch");

        GlValueMatch->addWidget(LeValueMatch, 0, 1, 1, 1);


        gridLayout_2->addLayout(GlValueMatch, 3, 0, 1, 1);

        GlParameterControl = new QGridLayout();
        GlParameterControl->setObjectName("GlParameterControl");
        HsParameterControl = new QSpacerItem(227, 25, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        GlParameterControl->addItem(HsParameterControl, 0, 0, 1, 1);

        PbParameterReset = new QPushButton(GbParameter);
        PbParameterReset->setObjectName("PbParameterReset");

        GlParameterControl->addWidget(PbParameterReset, 0, 1, 1, 1);

        PbParameterSave = new QPushButton(GbParameter);
        PbParameterSave->setObjectName("PbParameterSave");

        GlParameterControl->addWidget(PbParameterSave, 0, 2, 1, 1);


        gridLayout_2->addLayout(GlParameterControl, 4, 0, 1, 1);


        gridLayout_5->addWidget(GbParameter, 3, 0, 1, 1);

        GlActionIconName = new QGridLayout();
        GlActionIconName->setObjectName("GlActionIconName");
        IbActionIcon = new KIconButton(ActionEditor);
        IbActionIcon->setObjectName("IbActionIcon");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(IbActionIcon->sizePolicy().hasHeightForWidth());
        IbActionIcon->setSizePolicy(sizePolicy2);
        IbActionIcon->setMinimumSize(QSize(80, 80));
        IbActionIcon->setMaximumSize(QSize(75, 75));

        GlActionIconName->addWidget(IbActionIcon, 0, 0, 1, 1);

        LeActionFriendlyName = new QLineEdit(ActionEditor);
        LeActionFriendlyName->setObjectName("LeActionFriendlyName");

        GlActionIconName->addWidget(LeActionFriendlyName, 0, 1, 1, 1);


        gridLayout_5->addLayout(GlActionIconName, 0, 0, 1, 1);

        GlActionCommand = new QGridLayout();
        GlActionCommand->setObjectName("GlActionCommand");
        TlActionCommand = new QLabel(ActionEditor);
        TlActionCommand->setObjectName("TlActionCommand");
        TlActionCommand->setMinimumSize(QSize(80, 0));

        GlActionCommand->addWidget(TlActionCommand, 0, 0, 1, 1);

        LeActionCommand = new KUrlRequester(ActionEditor);
        LeActionCommand->setObjectName("LeActionCommand");

        GlActionCommand->addWidget(LeActionCommand, 0, 1, 1, 1);


        gridLayout_5->addLayout(GlActionCommand, 1, 0, 1, 1);

        GlPredicateTree = new QGridLayout();
        GlPredicateTree->setObjectName("GlPredicateTree");
        TlPredicateTree = new QLabel(ActionEditor);
        TlPredicateTree->setObjectName("TlPredicateTree");
        TlPredicateTree->setMinimumSize(QSize(80, 0));

        GlPredicateTree->addWidget(TlPredicateTree, 0, 0, 1, 2);

        TvPredicateTree = new QTreeView(ActionEditor);
        TvPredicateTree->setObjectName("TvPredicateTree");

        GlPredicateTree->addWidget(TvPredicateTree, 1, 0, 1, 2);


        gridLayout_5->addLayout(GlPredicateTree, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(ActionEditor);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_5->addWidget(buttonBox, 4, 0, 1, 1);

        QWidget::setTabOrder(IbActionIcon, LeActionFriendlyName);
        QWidget::setTabOrder(LeActionFriendlyName, LeActionCommand);
        QWidget::setTabOrder(LeActionCommand, TvPredicateTree);
        QWidget::setTabOrder(TvPredicateTree, CbDeviceType);
        QWidget::setTabOrder(CbDeviceType, CbParameterType);
        QWidget::setTabOrder(CbParameterType, CbValueName);
        QWidget::setTabOrder(CbValueName, CbValueMatch);
        QWidget::setTabOrder(CbValueMatch, LeValueMatch);
        QWidget::setTabOrder(LeValueMatch, PbParameterReset);
        QWidget::setTabOrder(PbParameterReset, PbParameterSave);

        retranslateUi(ActionEditor);

        QMetaObject::connectSlotsByName(ActionEditor);
    } // setupUi

    void retranslateUi(QWidget *ActionEditor)
    {
        GbParameter->setTitle(tr2i18n("Edit Parameter", nullptr));
        LblParameterType->setText(tr2i18n("Parameter type:", nullptr));
        CbParameterType->setItemText(0, tr2i18n("Property Match", nullptr));
        CbParameterType->setItemText(1, tr2i18n("Content Conjunction", nullptr));
        CbParameterType->setItemText(2, tr2i18n("Content Disjunction", nullptr));
        CbParameterType->setItemText(3, tr2i18n("Device Interface Match", nullptr));

        LblDeviceType->setText(tr2i18n("Device type:", nullptr));
        LblValueName->setText(tr2i18n("Value name:", nullptr));
        CbValueMatch->setItemText(0, tr2i18n("Equals", nullptr));
        CbValueMatch->setItemText(1, tr2i18n("Contains", nullptr));

        PbParameterReset->setText(tr2i18n("Reset Parameter", nullptr));
        PbParameterSave->setText(tr2i18n("Save Parameter Changes", nullptr));
#if QT_CONFIG(tooltip)
        IbActionIcon->setToolTip(tr2i18n("Action icon, click to change it", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        LeActionFriendlyName->setToolTip(tr2i18n("Action name", nullptr));
#endif // QT_CONFIG(tooltip)
        TlActionCommand->setText(tr2i18n("Command: ", nullptr));
#if QT_CONFIG(tooltip)
        LeActionCommand->setToolTip(tr2i18n("Command that will trigger the action\n"
"This can include any or all of the following case insensitive expands:\n"
"\n"
"%f: The mountpoint for the device - Storage Access devices only\n"
"%d: Path to the device node - Block devices only\n"
"%i: The identifier of the device", nullptr));
#endif // QT_CONFIG(tooltip)
        TlPredicateTree->setText(tr2i18n("Devices must match the following parameters for this action:", nullptr));
        (void)ActionEditor;
    } // retranslateUi

};

namespace Ui {
    class ActionEditor: public Ui_ActionEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ACTIONEDITOR_H

