/****************************************************************************
** Meta object code from reading C++ file 'inputdevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/kcms/libkwindevices/inputdevice.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11InputDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto InputDevice::qt_create_metaobjectdata<qt_meta_tag_ZN11InputDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputDevice",
        "needsSaveChanged",
        "",
        "leftHandedChanged",
        "orientationChanged",
        "outputNameChanged",
        "outputAreaChanged",
        "enabledChanged",
        "mapToWorkspaceChanged",
        "pressureCurveChanged",
        "inputAreaChanged",
        "pressureRangeMinChanged",
        "pressureRangeMaxChanged",
        "calibrationMatrixChanged",
        "relativeChanged",
        "currentModesChanged",
        "resetCalibrationMatrix",
        "sysName",
        "name",
        "size",
        "QSizeF",
        "enabled",
        "supportsLeftHanded",
        "leftHanded",
        "supportsCalibrationMatrix",
        "calibrationMatrixIsDefault",
        "supportsOrientation",
        "orientation",
        "outputName",
        "outputArea",
        "QRectF",
        "inputArea",
        "supportsInputArea",
        "mapToWorkspace",
        "pressureCurve",
        "pressureCurveIsDefault",
        "tabletPadButtonCount",
        "pressureRangeMin",
        "pressureRangeMax",
        "supportsPressureRange",
        "relative",
        "tabletPadDialCount",
        "tabletPadRingCount",
        "numModes",
        "QList<uint>",
        "currentModes",
        "isVirtual"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needsSaveChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftHandedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'orientationChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputNameChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputAreaChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapToWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressureCurveChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputAreaChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressureRangeMinChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressureRangeMaxChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calibrationMatrixChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'relativeChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentModesChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'resetCalibrationMatrix'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sysName'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'size'
        QtMocHelpers::PropertyData<QSizeF>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'supportsLeftHanded'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'leftHanded'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'supportsCalibrationMatrix'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationMatrixIsDefault'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'supportsOrientation'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'orientation'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'outputName'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'outputArea'
        QtMocHelpers::PropertyData<QRectF>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'inputArea'
        QtMocHelpers::PropertyData<QRectF>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'supportsInputArea'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mapToWorkspace'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'pressureCurve'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'pressureCurveIsDefault'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'tabletPadButtonCount'
        QtMocHelpers::PropertyData<quint32>(36, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pressureRangeMin'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'pressureRangeMax'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'supportsPressureRange'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'relative'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'tabletPadDialCount'
        QtMocHelpers::PropertyData<quint32>(41, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tabletPadRingCount'
        QtMocHelpers::PropertyData<quint32>(42, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'numModes'
        QtMocHelpers::PropertyData<QList<uint>>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currentModes'
        QtMocHelpers::PropertyData<QList<uint>>(45, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'isVirtual'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InputDevice, qt_meta_tag_ZN11InputDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InputDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11InputDeviceE_t>.metaTypes,
    nullptr
} };

void InputDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needsSaveChanged(); break;
        case 1: _t->leftHandedChanged(); break;
        case 2: _t->orientationChanged(); break;
        case 3: _t->outputNameChanged(); break;
        case 4: _t->outputAreaChanged(); break;
        case 5: _t->enabledChanged(); break;
        case 6: _t->mapToWorkspaceChanged(); break;
        case 7: _t->pressureCurveChanged(); break;
        case 8: _t->inputAreaChanged(); break;
        case 9: _t->pressureRangeMinChanged(); break;
        case 10: _t->pressureRangeMaxChanged(); break;
        case 11: _t->calibrationMatrixChanged(); break;
        case 12: _t->relativeChanged(); break;
        case 13: _t->currentModesChanged(); break;
        case 14: _t->resetCalibrationMatrix(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::needsSaveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::leftHandedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::orientationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::outputNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::outputAreaChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::mapToWorkspaceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::pressureCurveChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::inputAreaChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::pressureRangeMinChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::pressureRangeMaxChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::calibrationMatrixChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::relativeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::currentModesChanged, 13))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 25:
        case 24:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<uint> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->sysName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QSizeF*>(_v) = _t->size(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->supportsLeftHanded(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isLeftHanded(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->supportsCalibrationMatrix(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->calibrationMatrixIsDefault(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->supportsOrientation(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->orientation(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->outputName(); break;
        case 11: *reinterpret_cast<QRectF*>(_v) = _t->outputArea(); break;
        case 12: *reinterpret_cast<QRectF*>(_v) = _t->inputArea(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->supportsInputArea(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isMapToWorkspace(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->pressureCurve(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->pressureCurveIsDefault(); break;
        case 17: *reinterpret_cast<quint32*>(_v) = _t->tabletPadButtonCount(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->pressureRangeMin(); break;
        case 19: *reinterpret_cast<double*>(_v) = _t->pressureRangeMax(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->supportsPressureRange(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isRelative(); break;
        case 22: *reinterpret_cast<quint32*>(_v) = _t->tabletPadDialCount(); break;
        case 23: *reinterpret_cast<quint32*>(_v) = _t->tabletPadRingCount(); break;
        case 24: *reinterpret_cast<QList<uint>*>(_v) = _t->numModes(); break;
        case 25: *reinterpret_cast<QList<uint>*>(_v) = _t->currentModes(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isVirtual(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setLeftHanded(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setOrientation(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setOutputName(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setOutputArea(*reinterpret_cast<QRectF*>(_v)); break;
        case 12: _t->setInputArea(*reinterpret_cast<QRectF*>(_v)); break;
        case 14: _t->setMapToWorkspace(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setPressureCurve(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setPressureRangeMin(*reinterpret_cast<double*>(_v)); break;
        case 19: _t->setPressureRangeMax(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setRelative(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InputDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InputDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void InputDevice::needsSaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InputDevice::leftHandedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void InputDevice::orientationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void InputDevice::outputNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void InputDevice::outputAreaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void InputDevice::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void InputDevice::mapToWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void InputDevice::pressureCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void InputDevice::inputAreaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void InputDevice::pressureRangeMinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void InputDevice::pressureRangeMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void InputDevice::calibrationMatrixChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void InputDevice::relativeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void InputDevice::currentModesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
