// This file is generated by kconfig_compiler_kf6 from kactivitymanagerd_plugins_settings.kcfg.
// All changes you do to this file will be lost.

#include "kactivitymanagerd_plugins_settings.h"

KActivityManagerdPluginsSettings::KActivityManagerdPluginsSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kactivitymanagerd-pluginsrc" ) )
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "Plugin-org.kde.ActivityManager.Resources.Scoring" ) );

  KConfigSkeleton::ItemInt  *itemKeepHistoryFor;
  itemKeepHistoryFor = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "keep-history-for" ), mKeepHistoryFor, 4 );
  itemKeepHistoryFor->setWriteFlags(KConfigBase::Notify);
  addItem( itemKeepHistoryFor, QStringLiteral( "keepHistoryFor" ) );
  KConfigSkeleton::ItemBool  *itemBlockedByDefault;
  itemBlockedByDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "blocked-by-default" ), mBlockedByDefault, false );
  itemBlockedByDefault->setWriteFlags(KConfigBase::Notify);
  addItem( itemBlockedByDefault, QStringLiteral( "blockedByDefault" ) );
  KConfigSkeleton::ItemInt  *itemWhatToRemember;
  itemWhatToRemember = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "what-to-remember" ), mWhatToRemember, 0 );
  itemWhatToRemember->setWriteFlags(KConfigBase::Notify);
  addItem( itemWhatToRemember, QStringLiteral( "whatToRemember" ) );
  KConfigSkeleton::ItemStringList  *itemAllowedApplications;
  itemAllowedApplications = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "allowed-applications" ), mAllowedApplications );
  itemAllowedApplications->setWriteFlags(KConfigBase::Notify);
  addItem( itemAllowedApplications, QStringLiteral( "allowedApplications" ) );
  KConfigSkeleton::ItemStringList  *itemBlockedApplications;
  itemBlockedApplications = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "blocked-applications" ), mBlockedApplications );
  itemBlockedApplications->setWriteFlags(KConfigBase::Notify);
  addItem( itemBlockedApplications, QStringLiteral( "blockedApplications" ) );
}

int KActivityManagerdPluginsSettings::defaultKeepHistoryForValue_helper() const
{

  return 4;
}

bool KActivityManagerdPluginsSettings::defaultBlockedByDefaultValue_helper() const
{

  return false;
}

int KActivityManagerdPluginsSettings::defaultWhatToRememberValue_helper() const
{

  return 0;
}

KActivityManagerdPluginsSettings::~KActivityManagerdPluginsSettings()
{
}

