/****************************************************************************
** Meta object code from reading C++ file 'foldermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../plasma-desktop-6.6.4/containments/desktop/plugins/folder/foldermodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'foldermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DirListerE_t {};
} // unnamed namespace

template <> constexpr inline auto DirLister::qt_create_metaobjectdata<qt_meta_tag_ZN9DirListerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DirLister",
        "error",
        "",
        "string"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DirLister, qt_meta_tag_ZN9DirListerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DirLister::staticMetaObject = { {
    QMetaObject::SuperData::link<KDirLister::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DirListerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DirListerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DirListerE_t>.metaTypes,
    nullptr
} };

void DirLister::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DirLister *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DirLister::*)(const QString & )>(_a, &DirLister::error, 0))
            return;
    }
}

const QMetaObject *DirLister::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirLister::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DirListerE_t>.strings))
        return static_cast<void*>(this);
    return KDirLister::qt_metacast(_clname);
}

int DirLister::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDirLister::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DirLister::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN11FolderModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FolderModel::qt_create_metaobjectdata<qt_meta_tag_ZN11FolderModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FolderModel",
        "QML.Element",
        "auto",
        "urlChanged",
        "",
        "listingCompleted",
        "listingCanceled",
        "iconNameChanged",
        "resolvedUrlChanged",
        "statusChanged",
        "errorStringChanged",
        "draggingChanged",
        "dragInProgressAnywhereChanged",
        "usedByContainmentChanged",
        "lockedChanged",
        "sortModeChanged",
        "sortDescChanged",
        "sortDirsFirstChanged",
        "parseDesktopFilesChanged",
        "viewAdapterChanged",
        "previewsChanged",
        "previewPluginsChanged",
        "filterModeChanged",
        "filterPatternChanged",
        "filterMimeTypesChanged",
        "screenChanged",
        "appletChanged",
        "requestRename",
        "move",
        "x",
        "y",
        "QList<QUrl>",
        "urls",
        "popupMenuAboutToShow",
        "KIO::DropJob*",
        "dropJob",
        "QMimeData*",
        "mimeData",
        "selectionChanged",
        "showHiddenFilesChanged",
        "itemAboutToRename",
        "filename",
        "itemRenamed",
        "newFilename",
        "screenGeometryChanged",
        "selectionDone",
        "creatingNewItemsChanged",
        "dragSelectedInternal",
        "dirListFailed",
        "error",
        "statResult",
        "KJob*",
        "job",
        "evictFromIsDirCache",
        "KFileItemList",
        "items",
        "changeSelection",
        "QItemSelection",
        "selected",
        "deselected",
        "pasteTo",
        "moveSelectedToTrash",
        "emptyTrashBin",
        "restoreSelectedFromTrash",
        "undoTextChanged",
        "text",
        "invalidateIfComplete",
        "invalidateFilterIfComplete",
        "newFileMenuItemCreationStarted",
        "QUrl",
        "url",
        "newFileMenuItemCreated",
        "newFileMenuItemRejected",
        "resolve",
        "up",
        "cd",
        "row",
        "run",
        "runSelected",
        "showTarget",
        "rename",
        "name",
        "fileExtensionBoundary",
        "hasSelection",
        "isSelected",
        "setSelected",
        "toggleSelected",
        "setRangeSelected",
        "anchor",
        "to",
        "updateSelection",
        "QVariantList",
        "rows",
        "toggle",
        "clearSelection",
        "pinSelection",
        "unpinSelection",
        "addItemDragImage",
        "width",
        "height",
        "QVariant",
        "image",
        "clearDragImages",
        "setDragHotSpotScrollOffset",
        "dragCursorOffset",
        "QPoint",
        "dragSelected",
        "drop",
        "QQuickItem*",
        "target",
        "dropEvent",
        "showMenuManually",
        "dropCwd",
        "isBlank",
        "action",
        "QAction*",
        "updateActions",
        "openContextMenu",
        "visualParent",
        "Qt::KeyboardModifiers",
        "modifiers",
        "linkHere",
        "sourceUrl",
        "openPropertiesDialog",
        "paste",
        "copy",
        "cut",
        "deleteSelected",
        "undo",
        "refresh",
        "createFolder",
        "iconName",
        "resolvedUrl",
        "status",
        "Status",
        "errorString",
        "dragging",
        "dragInProgressAnywhere",
        "usedByContainment",
        "locked",
        "sortMode",
        "sortDesc",
        "sortDirsFirst",
        "parseDesktopFiles",
        "viewAdapter",
        "previews",
        "previewPlugins",
        "filterMode",
        "filterPattern",
        "filterMimeTypes",
        "newMenu",
        "applet",
        "Plasma::Applet*",
        "showHiddenFiles",
        "creatingNewItems",
        "None",
        "Ready",
        "Listing",
        "Canceled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'listingCompleted'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'listingCanceled'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconNameChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resolvedUrlChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void() const>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorStringChanged'
        QtMocHelpers::SignalData<void() const>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'draggingChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragInProgressAnywhereChanged'
        QtMocHelpers::SignalData<void() const>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usedByContainmentChanged'
        QtMocHelpers::SignalData<void() const>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockedChanged'
        QtMocHelpers::SignalData<void() const>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortModeChanged'
        QtMocHelpers::SignalData<void() const>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortDescChanged'
        QtMocHelpers::SignalData<void() const>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortDirsFirstChanged'
        QtMocHelpers::SignalData<void() const>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parseDesktopFilesChanged'
        QtMocHelpers::SignalData<void() const>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewAdapterChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewsChanged'
        QtMocHelpers::SignalData<void() const>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewPluginsChanged'
        QtMocHelpers::SignalData<void() const>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterModeChanged'
        QtMocHelpers::SignalData<void() const>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterPatternChanged'
        QtMocHelpers::SignalData<void() const>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterMimeTypesChanged'
        QtMocHelpers::SignalData<void() const>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenChanged'
        QtMocHelpers::SignalData<void() const>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appletChanged'
        QtMocHelpers::SignalData<void() const>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestRename'
        QtMocHelpers::SignalData<void() const>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'move'
        QtMocHelpers::SignalData<void(int, int, QList<QUrl>)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Signal 'popupMenuAboutToShow'
        QtMocHelpers::SignalData<void(KIO::DropJob *, QMimeData *, int, int)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 36, 37 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void() const>(38, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showHiddenFilesChanged'
        QtMocHelpers::SignalData<void() const>(39, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemAboutToRename'
        QtMocHelpers::SignalData<void(const QString &) const>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Signal 'itemRenamed'
        QtMocHelpers::SignalData<void(const QString &, const QString &) const>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 43 },
        }}),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void() const>(44, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionDone'
        QtMocHelpers::SignalData<void()>(45, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'creatingNewItemsChanged'
        QtMocHelpers::SignalData<void() const>(46, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dragSelectedInternal'
        QtMocHelpers::SlotData<void(int, int)>(47, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'dirListFailed'
        QtMocHelpers::SlotData<void(const QString &)>(48, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'statResult'
        QtMocHelpers::SlotData<void(KJob *)>(50, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'evictFromIsDirCache'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(53, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'changeSelection'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(56, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 58 }, { 0x80000000 | 57, 59 },
        }}),
        // Slot 'pasteTo'
        QtMocHelpers::SlotData<void()>(60, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveSelectedToTrash'
        QtMocHelpers::SlotData<void()>(61, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emptyTrashBin'
        QtMocHelpers::SlotData<void()>(62, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'restoreSelectedFromTrash'
        QtMocHelpers::SlotData<void()>(63, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'undoTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(64, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 65 },
        }}),
        // Slot 'invalidateIfComplete'
        QtMocHelpers::SlotData<void()>(66, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'invalidateFilterIfComplete'
        QtMocHelpers::SlotData<void()>(67, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newFileMenuItemCreationStarted'
        QtMocHelpers::SlotData<void(const QUrl &)>(68, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 70 },
        }}),
        // Slot 'newFileMenuItemCreated'
        QtMocHelpers::SlotData<void(const QUrl &)>(71, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 70 },
        }}),
        // Slot 'newFileMenuItemRejected'
        QtMocHelpers::SlotData<void(const QUrl &)>(72, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 70 },
        }}),
        // Method 'resolve'
        QtMocHelpers::MethodData<QUrl(const QString &)>(73, 4, QMC::AccessPublic, 0x80000000 | 69, {{
            { QMetaType::QString, 70 },
        }}),
        // Method 'up'
        QtMocHelpers::MethodData<void()>(74, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'cd'
        QtMocHelpers::MethodData<void(int)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'run'
        QtMocHelpers::MethodData<void(int)>(77, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'runSelected'
        QtMocHelpers::MethodData<void()>(78, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'showTarget'
        QtMocHelpers::MethodData<void()>(79, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'rename'
        QtMocHelpers::MethodData<void(int, const QString &)>(80, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 76 }, { QMetaType::QString, 81 },
        }}),
        // Method 'fileExtensionBoundary'
        QtMocHelpers::MethodData<int(int)>(82, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'hasSelection'
        QtMocHelpers::MethodData<bool() const>(83, 4, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isSelected'
        QtMocHelpers::MethodData<bool(int)>(84, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'setSelected'
        QtMocHelpers::MethodData<void(int)>(85, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'toggleSelected'
        QtMocHelpers::MethodData<void(int)>(86, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'setRangeSelected'
        QtMocHelpers::MethodData<void(int, int)>(87, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 88 }, { QMetaType::Int, 89 },
        }}),
        // Method 'updateSelection'
        QtMocHelpers::MethodData<void(const QVariantList &, bool)>(90, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { QMetaType::Bool, 93 },
        }}),
        // Method 'clearSelection'
        QtMocHelpers::MethodData<void()>(94, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'pinSelection'
        QtMocHelpers::MethodData<void()>(95, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'unpinSelection'
        QtMocHelpers::MethodData<void()>(96, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'addItemDragImage'
        QtMocHelpers::MethodData<void(int, int, int, int, int, const QVariant &)>(97, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 76 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { QMetaType::Int, 98 },
            { QMetaType::Int, 99 }, { 0x80000000 | 100, 101 },
        }}),
        // Method 'clearDragImages'
        QtMocHelpers::MethodData<void()>(102, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setDragHotSpotScrollOffset'
        QtMocHelpers::MethodData<void(int, int)>(103, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 30 },
        }}),
        // Method 'dragCursorOffset'
        QtMocHelpers::MethodData<QPoint(int)>(104, 4, QMC::AccessPublic, 0x80000000 | 105, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'dragSelected'
        QtMocHelpers::MethodData<void(int, int)>(106, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 30 },
        }}),
        // Method 'drop'
        QtMocHelpers::MethodData<void(QQuickItem *, QObject *, int, bool)>(107, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 108, 109 }, { QMetaType::QObjectStar, 110 }, { QMetaType::Int, 76 }, { QMetaType::Bool, 111 },
        }}),
        // Method 'drop'
        QtMocHelpers::MethodData<void(QQuickItem *, QObject *, int)>(107, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 108, 109 }, { QMetaType::QObjectStar, 110 }, { QMetaType::Int, 76 },
        }}),
        // Method 'dropCwd'
        QtMocHelpers::MethodData<void(QObject *)>(112, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 110 },
        }}),
        // Method 'isBlank'
        QtMocHelpers::MethodData<bool(int) const>(113, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'action'
        QtMocHelpers::MethodData<QAction *(const QString &) const>(114, 4, QMC::AccessPublic, 0x80000000 | 115, {{
            { QMetaType::QString, 81 },
        }}),
        // Method 'updateActions'
        QtMocHelpers::MethodData<void()>(116, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'openContextMenu'
        QtMocHelpers::MethodData<void(QQuickItem *, Qt::KeyboardModifiers)>(117, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 108, 118 }, { 0x80000000 | 119, 120 },
        }}),
        // Method 'openContextMenu'
        QtMocHelpers::MethodData<void(QQuickItem *)>(117, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 108, 118 },
        }}),
        // Method 'openContextMenu'
        QtMocHelpers::MethodData<void()>(117, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'linkHere'
        QtMocHelpers::MethodData<void(const QUrl &)>(121, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 69, 122 },
        }}),
        // Method 'openPropertiesDialog'
        QtMocHelpers::MethodData<void()>(123, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'paste'
        QtMocHelpers::MethodData<void()>(124, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'copy'
        QtMocHelpers::MethodData<void()>(125, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'cut'
        QtMocHelpers::MethodData<void()>(126, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'deleteSelected'
        QtMocHelpers::MethodData<void()>(127, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'undo'
        QtMocHelpers::MethodData<void()>(128, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'refresh'
        QtMocHelpers::MethodData<void()>(129, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'createFolder'
        QtMocHelpers::MethodData<void()>(130, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'url'
        QtMocHelpers::PropertyData<QString>(70, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(131, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'resolvedUrl'
        QtMocHelpers::PropertyData<QUrl>(132, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(133, 0x80000000 | 134, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'errorString'
        QtMocHelpers::PropertyData<QString>(135, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'dragging'
        QtMocHelpers::PropertyData<bool>(136, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'dragInProgressAnywhere'
        QtMocHelpers::PropertyData<bool>(137, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'usedByContainment'
        QtMocHelpers::PropertyData<bool>(138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'sortMode'
        QtMocHelpers::PropertyData<int>(140, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'sortDesc'
        QtMocHelpers::PropertyData<bool>(141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'sortDirsFirst'
        QtMocHelpers::PropertyData<bool>(142, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'parseDesktopFiles'
        QtMocHelpers::PropertyData<bool>(143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'viewAdapter'
        QtMocHelpers::PropertyData<QObject*>(144, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'previews'
        QtMocHelpers::PropertyData<bool>(145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'previewPlugins'
        QtMocHelpers::PropertyData<QStringList>(146, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'filterMode'
        QtMocHelpers::PropertyData<int>(147, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'filterPattern'
        QtMocHelpers::PropertyData<QString>(148, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'filterMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(149, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'newMenu'
        QtMocHelpers::PropertyData<QObject*>(150, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'applet'
        QtMocHelpers::PropertyData<Plasma::Applet*>(151, 0x80000000 | 152, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 22),
        // property 'showHiddenFiles'
        QtMocHelpers::PropertyData<bool>(153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'creatingNewItems'
        QtMocHelpers::PropertyData<bool>(154, QMetaType::Bool, QMC::DefaultPropertyFlags, 32),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(134, 134, QMC::EnumFlags{}).add({
            {  155, Status::None },
            {  156, Status::Ready },
            {  157, Status::Listing },
            {  158, Status::Canceled },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FolderModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FolderModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FolderModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FolderModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11FolderModelE_t>.metaTypes,
    nullptr
} };

void FolderModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FolderModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->urlChanged(); break;
        case 1: _t->listingCompleted(); break;
        case 2: _t->listingCanceled(); break;
        case 3: _t->iconNameChanged(); break;
        case 4: _t->resolvedUrlChanged(); break;
        case 5: _t->statusChanged(); break;
        case 6: _t->errorStringChanged(); break;
        case 7: _t->draggingChanged(); break;
        case 8: _t->dragInProgressAnywhereChanged(); break;
        case 9: _t->usedByContainmentChanged(); break;
        case 10: _t->lockedChanged(); break;
        case 11: _t->sortModeChanged(); break;
        case 12: _t->sortDescChanged(); break;
        case 13: _t->sortDirsFirstChanged(); break;
        case 14: _t->parseDesktopFilesChanged(); break;
        case 15: _t->viewAdapterChanged(); break;
        case 16: _t->previewsChanged(); break;
        case 17: _t->previewPluginsChanged(); break;
        case 18: _t->filterModeChanged(); break;
        case 19: _t->filterPatternChanged(); break;
        case 20: _t->filterMimeTypesChanged(); break;
        case 21: _t->screenChanged(); break;
        case 22: _t->appletChanged(); break;
        case 23: _t->requestRename(); break;
        case 24: _t->move((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[3]))); break;
        case 25: _t->popupMenuAboutToShow((*reinterpret_cast<std::add_pointer_t<KIO::DropJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 26: _t->selectionChanged(); break;
        case 27: _t->showHiddenFilesChanged(); break;
        case 28: _t->itemAboutToRename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->itemRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->screenGeometryChanged(); break;
        case 31: _t->selectionDone(); break;
        case 32: _t->creatingNewItemsChanged(); break;
        case 33: _t->dragSelectedInternal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 34: _t->dirListFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->statResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 36: _t->evictFromIsDirCache((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 37: _t->changeSelection((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 38: _t->pasteTo(); break;
        case 39: _t->moveSelectedToTrash(); break;
        case 40: _t->emptyTrashBin(); break;
        case 41: _t->restoreSelectedFromTrash(); break;
        case 42: _t->undoTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: _t->invalidateIfComplete(); break;
        case 44: _t->invalidateFilterIfComplete(); break;
        case 45: _t->newFileMenuItemCreationStarted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 46: _t->newFileMenuItemCreated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 47: _t->newFileMenuItemRejected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 48: { QUrl _r = _t->resolve((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->up(); break;
        case 50: _t->cd((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->run((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->runSelected(); break;
        case 53: _t->showTarget(); break;
        case 54: _t->rename((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 55: { int _r = _t->fileExtensionBoundary((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: { bool _r = _t->hasSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 57: { bool _r = _t->isSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: _t->setSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 59: _t->toggleSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 60: _t->setRangeSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 61: _t->updateSelection((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 62: _t->clearSelection(); break;
        case 63: _t->pinSelection(); break;
        case 64: _t->unpinSelection(); break;
        case 65: _t->addItemDragImage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6]))); break;
        case 66: _t->clearDragImages(); break;
        case 67: _t->setDragHotSpotScrollOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 68: { QPoint _r = _t->dragCursorOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPoint*>(_a[0]) = std::move(_r); }  break;
        case 69: _t->dragSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 70: _t->drop((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 71: _t->drop((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 72: _t->dropCwd((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 73: { bool _r = _t->isBlank((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 74: { QAction* _r = _t->action((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAction**>(_a[0]) = std::move(_r); }  break;
        case 75: _t->updateActions(); break;
        case 76: _t->openContextMenu((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::KeyboardModifiers>>(_a[2]))); break;
        case 77: _t->openContextMenu((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 78: _t->openContextMenu(); break;
        case 79: _t->linkHere((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 80: _t->openPropertiesDialog(); break;
        case 81: _t->paste(); break;
        case 82: _t->copy(); break;
        case 83: _t->cut(); break;
        case 84: _t->deleteSelected(); break;
        case 85: _t->undo(); break;
        case 86: _t->refresh(); break;
        case 87: _t->createFolder(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::DropJob* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMimeData* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        case 70:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 76:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 77:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::urlChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::listingCompleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::listingCanceled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::iconNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::resolvedUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::statusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::errorStringChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::draggingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::dragInProgressAnywhereChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::usedByContainmentChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::lockedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::sortModeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::sortDescChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::sortDirsFirstChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::parseDesktopFilesChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)()>(_a, &FolderModel::viewAdapterChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::previewsChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::previewPluginsChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::filterModeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::filterPatternChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::filterMimeTypesChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::screenChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::appletChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::requestRename, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)(int , int , QList<QUrl> )>(_a, &FolderModel::move, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)(KIO::DropJob * , QMimeData * , int , int )>(_a, &FolderModel::popupMenuAboutToShow, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::selectionChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::showHiddenFilesChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)(const QString & ) const>(_a, &FolderModel::itemAboutToRename, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)(const QString & , const QString & ) const>(_a, &FolderModel::itemRenamed, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::screenGeometryChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)()>(_a, &FolderModel::selectionDone, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderModel::*)() const>(_a, &FolderModel::creatingNewItemsChanged, 32))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 20:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Plasma::Applet* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->url(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->resolvedUrl(); break;
        case 3: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->errorString(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->dragging(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isDragInProgressAnywhere(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->usedByContainment(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->sortMode(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->sortDesc(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->sortDirsFirst(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->parseDesktopFiles(); break;
        case 13: *reinterpret_cast<QObject**>(_v) = _t->viewAdapter(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->previews(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->previewPlugins(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->filterMode(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->filterPattern(); break;
        case 18: *reinterpret_cast<QStringList*>(_v) = _t->filterMimeTypes(); break;
        case 19: *reinterpret_cast<QObject**>(_v) = _t->newMenu(); break;
        case 20: *reinterpret_cast<Plasma::Applet**>(_v) = _t->applet(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->showHiddenFiles(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->creatingNewItems(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUrl(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setUsedByContainment(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setSortMode(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setSortDesc(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setSortDirsFirst(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setParseDesktopFiles(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setViewAdapter(*reinterpret_cast<QObject**>(_v)); break;
        case 14: _t->setPreviews(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setPreviewPlugins(*reinterpret_cast<QStringList*>(_v)); break;
        case 16: _t->setFilterMode(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setFilterPattern(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setFilterMimeTypes(*reinterpret_cast<QStringList*>(_v)); break;
        case 20: _t->setApplet(*reinterpret_cast<Plasma::Applet**>(_v)); break;
        case 21: _t->setShowHiddenFiles(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FolderModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FolderModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FolderModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int FolderModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 88)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 88;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 88)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 88;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void FolderModel::urlChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FolderModel::listingCompleted()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FolderModel::listingCanceled()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FolderModel::iconNameChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FolderModel::resolvedUrlChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FolderModel::statusChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void FolderModel::errorStringChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FolderModel::draggingChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FolderModel::dragInProgressAnywhereChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void FolderModel::usedByContainmentChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void FolderModel::lockedChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void FolderModel::sortModeChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void FolderModel::sortDescChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void FolderModel::sortDirsFirstChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void FolderModel::parseDesktopFilesChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void FolderModel::viewAdapterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void FolderModel::previewsChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void FolderModel::previewPluginsChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void FolderModel::filterModeChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void FolderModel::filterPatternChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void FolderModel::filterMimeTypesChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void FolderModel::screenChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void FolderModel::appletChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void FolderModel::requestRename()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void FolderModel::move(int _t1, int _t2, QList<QUrl> _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2, _t3);
}

// SIGNAL 25
void FolderModel::popupMenuAboutToShow(KIO::DropJob * _t1, QMimeData * _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 26
void FolderModel::selectionChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void FolderModel::showHiddenFilesChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void FolderModel::itemAboutToRename(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< FolderModel *>(this), &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void FolderModel::itemRenamed(const QString & _t1, const QString & _t2)const
{
    QMetaObject::activate<void>(const_cast< FolderModel *>(this), &staticMetaObject, 29, nullptr, _t1, _t2);
}

// SIGNAL 30
void FolderModel::screenGeometryChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void FolderModel::selectionDone()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void FolderModel::creatingNewItemsChanged()const
{
    QMetaObject::activate(const_cast< FolderModel *>(this), &staticMetaObject, 32, nullptr);
}
namespace {
struct qt_meta_tag_ZN11DragTrackerE_t {};
} // unnamed namespace

template <> constexpr inline auto DragTracker::qt_create_metaobjectdata<qt_meta_tag_ZN11DragTrackerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DragTracker",
        "dragInProgressChanged",
        "",
        "dragInProgress"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dragInProgressChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DragTracker, qt_meta_tag_ZN11DragTrackerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DragTracker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DragTrackerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DragTrackerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DragTrackerE_t>.metaTypes,
    nullptr
} };

void DragTracker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DragTracker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dragInProgressChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DragTracker::*)(bool )>(_a, &DragTracker::dragInProgressChanged, 0))
            return;
    }
}

const QMetaObject *DragTracker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DragTracker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DragTrackerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DragTracker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DragTracker::dragInProgressChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
