// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "splashscreendata.h"

#include "splashscreensettings.h"




SplashScreenData::SplashScreenData(QObject *parent)
: KCModuleData(parent)
, m_settings(new SplashScreenSettings(this))

{
autoRegisterSkeletons();
}

SplashScreenSettings *SplashScreenData::settings() const
{
    return m_settings;
}





#include "moc_splashscreendata.cpp"
