// This file is autogenerated. Changes will be overwritten.
#include "EJRQKI7XPS/moc_kcmaccessibilityactivationgestures.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilitybell.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilitycolorblindnesscorrection.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilityinvert.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilitykeyboard.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilitykeyboardfilters.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilitymouse.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilityscreenreader.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilityshakecursor.cpp"
#include "EJRQKI7XPS/moc_kcmaccessibilityzoommagnifier.cpp"
