// This file is generated by kconfig_compiler_kf6 from landingpage_kdeglobalssettings.kcfg.
// All changes you do to this file will be lost.

#include "landingpage_kdeglobalssettings.h"

LandingPageGlobalsSettings::LandingPageGlobalsSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&LandingPageGlobalsSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigCompilerSignallingItem  *itemColorScheme;
  KConfigSkeleton::ItemString  *innerItemColorScheme;
  innerItemColorScheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ColorScheme" ), mColorScheme, QStringLiteral( "BreezeLight" ) );
  itemColorScheme = new KConfigCompilerSignallingItem(innerItemColorScheme, this, notifyFunction, signalColorSchemeChanged);
  addItem( itemColorScheme, QStringLiteral( "colorScheme" ) );

  setCurrentGroup( QStringLiteral( "KDE" ) );

  KConfigCompilerSignallingItem  *itemSingleClick;
  KConfigSkeleton::ItemBool  *innerItemSingleClick;
  innerItemSingleClick = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SingleClick" ), mSingleClick, false );
  itemSingleClick = new KConfigCompilerSignallingItem(innerItemSingleClick, this, notifyFunction, signalSingleClickChanged);
  addItem( itemSingleClick, QStringLiteral( "singleClick" ) );
  KConfigCompilerSignallingItem  *itemAutomaticLookAndFeel;
  KConfigSkeleton::ItemBool  *innerItemAutomaticLookAndFeel;
  innerItemAutomaticLookAndFeel = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticLookAndFeel" ), mAutomaticLookAndFeel, false );
  itemAutomaticLookAndFeel = new KConfigCompilerSignallingItem(innerItemAutomaticLookAndFeel, this, notifyFunction, signalAutomaticLookAndFeelChanged);
  itemAutomaticLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutomaticLookAndFeel, QStringLiteral( "automaticLookAndFeel" ) );
  KConfigCompilerSignallingItem  *itemLookAndFeelPackage;
  KConfigSkeleton::ItemString  *innerItemLookAndFeelPackage;
  innerItemLookAndFeelPackage = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LookAndFeelPackage" ), mLookAndFeelPackage, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemLookAndFeelPackage = new KConfigCompilerSignallingItem(innerItemLookAndFeelPackage, this, notifyFunction, signalLookAndFeelPackageChanged);
  addItem( itemLookAndFeelPackage, QStringLiteral( "lookAndFeelPackage" ) );
  KConfigCompilerSignallingItem  *itemDefaultLightLookAndFeel;
  KConfigSkeleton::ItemString  *innerItemDefaultLightLookAndFeel;
  innerItemDefaultLightLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultLightLookAndFeel" ), mDefaultLightLookAndFeel, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemDefaultLightLookAndFeel = new KConfigCompilerSignallingItem(innerItemDefaultLightLookAndFeel, this, notifyFunction, signalDefaultLightLookAndFeelChanged);
  itemDefaultLightLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultLightLookAndFeel, QStringLiteral( "defaultLightLookAndFeel" ) );
  KConfigCompilerSignallingItem  *itemDefaultDarkLookAndFeel;
  KConfigSkeleton::ItemString  *innerItemDefaultDarkLookAndFeel;
  innerItemDefaultDarkLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultDarkLookAndFeel" ), mDefaultDarkLookAndFeel, QStringLiteral( "org.kde.breezedark.desktop" ) );
  itemDefaultDarkLookAndFeel = new KConfigCompilerSignallingItem(innerItemDefaultDarkLookAndFeel, this, notifyFunction, signalDefaultDarkLookAndFeelChanged);
  itemDefaultDarkLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultDarkLookAndFeel, QStringLiteral( "defaultDarkLookAndFeel" ) );
  KConfigCompilerSignallingItem  *itemAnimationDurationFactor;
  KConfigSkeleton::ItemDouble  *innerItemAnimationDurationFactor;
  innerItemAnimationDurationFactor = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AnimationDurationFactor" ), mAnimationDurationFactor, 1.0 );
  itemAnimationDurationFactor = new KConfigCompilerSignallingItem(innerItemAnimationDurationFactor, this, notifyFunction, signalAnimationDurationFactorChanged);
  itemAnimationDurationFactor->setWriteFlags(KConfigBase::Notify);
  addItem( itemAnimationDurationFactor, QStringLiteral( "animationDurationFactor" ) );
}

QString LandingPageGlobalsSettings::defaultColorSchemeValue_helper() const
{

  return QStringLiteral( "BreezeLight" );
}

bool LandingPageGlobalsSettings::defaultSingleClickValue_helper() const
{

  return false;
}

bool LandingPageGlobalsSettings::defaultAutomaticLookAndFeelValue_helper() const
{

  return false;
}

QString LandingPageGlobalsSettings::defaultLookAndFeelPackageValue_helper() const
{

  return QStringLiteral( "org.kde.breeze.desktop" );
}

QString LandingPageGlobalsSettings::defaultDefaultLightLookAndFeelValue_helper() const
{

  return QStringLiteral( "org.kde.breeze.desktop" );
}

QString LandingPageGlobalsSettings::defaultDefaultDarkLookAndFeelValue_helper() const
{

  return QStringLiteral( "org.kde.breezedark.desktop" );
}

double LandingPageGlobalsSettings::defaultAnimationDurationFactorValue_helper() const
{

  return 1.0;
}

LandingPageGlobalsSettings::~LandingPageGlobalsSettings()
{
}


void LandingPageGlobalsSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalColorSchemeChanged:
    Q_EMIT colorSchemeChanged();
    break;
  case signalSingleClickChanged:
    Q_EMIT singleClickChanged();
    break;
  case signalAutomaticLookAndFeelChanged:
    Q_EMIT automaticLookAndFeelChanged();
    break;
  case signalLookAndFeelPackageChanged:
    Q_EMIT lookAndFeelPackageChanged();
    break;
  case signalDefaultLightLookAndFeelChanged:
    Q_EMIT defaultLightLookAndFeelChanged();
    break;
  case signalDefaultDarkLookAndFeelChanged:
    Q_EMIT defaultDarkLookAndFeelChanged();
    break;
  case signalAnimationDurationFactorChanged:
    Q_EMIT animationDurationFactorChanged();
    break;
  }
}
