/********************************************************************************
** Form generated from reading UI file 'AddAction.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDACTION_H
#define UI_ADDACTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AddAction
{
public:
    QGridLayout *gridLayout;
    QGridLayout *GlActionAdd;
    QLabel *LblActionName;
    QLineEdit *LeActionName;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *AddAction)
    {
        if (AddAction->objectName().isEmpty())
            AddAction->setObjectName("AddAction");
        AddAction->resize(266, 65);
        gridLayout = new QGridLayout(AddAction);
        gridLayout->setObjectName("gridLayout");
        GlActionAdd = new QGridLayout();
        GlActionAdd->setObjectName("GlActionAdd");
        LblActionName = new QLabel(AddAction);
        LblActionName->setObjectName("LblActionName");

        GlActionAdd->addWidget(LblActionName, 0, 0, 1, 1);

        LeActionName = new QLineEdit(AddAction);
        LeActionName->setObjectName("LeActionName");

        GlActionAdd->addWidget(LeActionName, 0, 1, 1, 1);


        gridLayout->addLayout(GlActionAdd, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(AddAction);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 1);


        retranslateUi(AddAction);

        QMetaObject::connectSlotsByName(AddAction);
    } // setupUi

    void retranslateUi(QWidget *AddAction)
    {
        LblActionName->setText(tr2i18n("Action name:", nullptr));
#if QT_CONFIG(tooltip)
        LeActionName->setToolTip(tr2i18n("Enter the name for your new action", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)AddAction;
    } // retranslateUi

};

namespace Ui {
    class AddAction: public Ui_AddAction {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDACTION_H

