/****************************************************************************
** Meta object code from reading C++ file 'viewpropertiesmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../plasma-desktop-6.6.4/containments/desktop/plugins/folder/viewpropertiesmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewpropertiesmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ViewPropertiesMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto ViewPropertiesMenu::qt_create_metaobjectdata<qt_meta_tag_ZN18ViewPropertiesMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ViewPropertiesMenu",
        "QML.Element",
        "auto",
        "showLayoutActionsChanged",
        "",
        "showLockActionChanged",
        "showIconSizeActionsChanged",
        "arrangementChanged",
        "alignmentChanged",
        "previewsChanged",
        "lockedChanged",
        "lockedEnabledChanged",
        "sortModeChanged",
        "sortDescChanged",
        "sortDirsFirstChanged",
        "iconSizeChanged",
        "menu",
        "QMenu*",
        "showLayoutActions",
        "showLockAction",
        "showIconSizeActions",
        "arrangement",
        "alignment",
        "previews",
        "locked",
        "lockedEnabled",
        "sortMode",
        "sortDesc",
        "sortDirsFirst",
        "iconSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showLayoutActionsChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showLockActionChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showIconSizeActionsChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'arrangementChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignmentChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewsChanged'
        QtMocHelpers::SignalData<void() const>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockedChanged'
        QtMocHelpers::SignalData<void() const>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockedEnabledChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortModeChanged'
        QtMocHelpers::SignalData<void() const>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortDescChanged'
        QtMocHelpers::SignalData<void() const>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortDirsFirstChanged'
        QtMocHelpers::SignalData<void() const>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconSizeChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'menu'
        QtMocHelpers::PropertyData<QMenu*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'showLayoutActions'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'showLockAction'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'showIconSizeActions'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'arrangement'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'alignment'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'previews'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'lockedEnabled'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'sortMode'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'sortDesc'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'sortDirsFirst'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'iconSize'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ViewPropertiesMenu, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ViewPropertiesMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ViewPropertiesMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ViewPropertiesMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ViewPropertiesMenuE_t>.metaTypes,
    nullptr
} };

void ViewPropertiesMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewPropertiesMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showLayoutActionsChanged(); break;
        case 1: _t->showLockActionChanged(); break;
        case 2: _t->showIconSizeActionsChanged(); break;
        case 3: _t->arrangementChanged(); break;
        case 4: _t->alignmentChanged(); break;
        case 5: _t->previewsChanged(); break;
        case 6: _t->lockedChanged(); break;
        case 7: _t->lockedEnabledChanged(); break;
        case 8: _t->sortModeChanged(); break;
        case 9: _t->sortDescChanged(); break;
        case 10: _t->sortDirsFirstChanged(); break;
        case 11: _t->iconSizeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::showLayoutActionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::showLockActionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)()>(_a, &ViewPropertiesMenu::showIconSizeActionsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::arrangementChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::alignmentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::previewsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::lockedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::lockedEnabledChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::sortModeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::sortDescChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)() const>(_a, &ViewPropertiesMenu::sortDirsFirstChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPropertiesMenu::*)()>(_a, &ViewPropertiesMenu::iconSizeChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QMenu**>(_v) = _t->menu(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showLayoutActions(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showLockAction(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showIconSizeActions(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->arrangement(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->alignment(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->previews(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->lockedEnabled(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->sortMode(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->sortDesc(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->sortDirsFirst(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->iconSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setShowLayoutActions(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setShowLockAction(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowIconSizeActions(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setArrangement(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setAlignment(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setPreviews(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setLockedEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setSortMode(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setSortDesc(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setSortDirsFirst(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setIconSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ViewPropertiesMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewPropertiesMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ViewPropertiesMenuE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ViewPropertiesMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ViewPropertiesMenu::showLayoutActionsChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ViewPropertiesMenu::showLockActionChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ViewPropertiesMenu::showIconSizeActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ViewPropertiesMenu::arrangementChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ViewPropertiesMenu::alignmentChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ViewPropertiesMenu::previewsChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ViewPropertiesMenu::lockedChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ViewPropertiesMenu::lockedEnabledChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ViewPropertiesMenu::sortModeChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ViewPropertiesMenu::sortDescChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ViewPropertiesMenu::sortDirsFirstChanged()const
{
    QMetaObject::activate(const_cast< ViewPropertiesMenu *>(this), &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ViewPropertiesMenu::iconSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
