/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.login1.Manager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef LOGIN1_MANAGER_H
#define LOGIN1_MANAGER_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.login1.Manager
 */
class OrgFreedesktopLogin1ManagerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.login1.Manager"; }

public:
    OrgFreedesktopLogin1ManagerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopLogin1ManagerInterface();

    Q_PROPERTY(bool RebootToFirmwareSetup READ rebootToFirmwareSetup)
    inline bool rebootToFirmwareSetup() const
    { return qvariant_cast< bool >(property("RebootToFirmwareSetup")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> CanRebootToFirmwareSetup()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CanRebootToFirmwareSetup"), argumentList);
    }

    inline QDBusPendingReply<> SetRebootToFirmwareSetup(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetRebootToFirmwareSetup"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace freedesktop {
    namespace login1 {
      using Manager = ::OrgFreedesktopLogin1ManagerInterface;
    }
  }
}

#endif
