/********************************************************************************
** Form generated from reading UI file 'DeviceAutomounterKCM.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEVICEAUTOMOUNTERKCM_H
#define UI_DEVICEAUTOMOUNTERKCM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DeviceAutomounterKCM
{
public:
    QVBoxLayout *verticalLayout;
    QTreeView *deviceView;
    QPushButton *forgetDevice;
    QCheckBox *kcfg_AutomountUnknownDevices;

    void setupUi(QWidget *DeviceAutomounterKCM)
    {
        if (DeviceAutomounterKCM->objectName().isEmpty())
            DeviceAutomounterKCM->setObjectName("DeviceAutomounterKCM");
        DeviceAutomounterKCM->resize(615, 380);
        verticalLayout = new QVBoxLayout(DeviceAutomounterKCM);
        verticalLayout->setObjectName("verticalLayout");
        deviceView = new QTreeView(DeviceAutomounterKCM);
        deviceView->setObjectName("deviceView");
        deviceView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        deviceView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        deviceView->setRootIsDecorated(true);
        deviceView->setItemsExpandable(true);
        deviceView->setSortingEnabled(true);
        deviceView->setAnimated(true);
        deviceView->setAllColumnsShowFocus(true);
        deviceView->setExpandsOnDoubleClick(false);
        deviceView->header()->setProperty("showSortIndicator", QVariant(false));
        deviceView->header()->setStretchLastSection(false);

        verticalLayout->addWidget(deviceView);

        forgetDevice = new QPushButton(DeviceAutomounterKCM);
        forgetDevice->setObjectName("forgetDevice");
        forgetDevice->setEnabled(false);

        verticalLayout->addWidget(forgetDevice);

        kcfg_AutomountUnknownDevices = new QCheckBox(DeviceAutomounterKCM);
        kcfg_AutomountUnknownDevices->setObjectName("kcfg_AutomountUnknownDevices");

        verticalLayout->addWidget(kcfg_AutomountUnknownDevices);


        retranslateUi(DeviceAutomounterKCM);

        QMetaObject::connectSlotsByName(DeviceAutomounterKCM);
    } // setupUi

    void retranslateUi(QWidget *DeviceAutomounterKCM)
    {
#if QT_CONFIG(whatsthis)
        deviceView->setWhatsThis(tr2i18n("This list contains the storage devices known to the system. If \"Automount on Login\" is checked, the device will be automatically mounted even though \"Mount all removable media at login\" is unchecked. The same applies for \"Automount on Attach\".", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        forgetDevice->setWhatsThis(tr2i18n("Clicking this button causes the selected devices to be 'forgotten'. This is only useful if \"Only automatically mount removable media that has been manually mounted before\" is checked. Once a device is forgotten and the system is set to only automatically mount familiar devices, the device will not be automatically mounted.", nullptr));
#endif // QT_CONFIG(whatsthis)
        forgetDevice->setText(tr2i18n("Forget Device", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_AutomountUnknownDevices->setWhatsThis(tr2i18n("When this is not checked, only remembered devices will be automatically mounted. A device is 'remembered' if it has ever been mounted before. For instance, plugging in a USB media player to charge is not sufficient to 'remember' it - if the files are not accessed, it will not be automatically mounted the next time it is seen. Once they have been accessed, however, the device's contents will be automatically made available to the system.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutomountUnknownDevices->setText(tr2i18n("Automatically mount removable media that have never been mounted before", nullptr));
        (void)DeviceAutomounterKCM;
    } // retranslateUi

};

namespace Ui {
    class DeviceAutomounterKCM: public Ui_DeviceAutomounterKCM {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DEVICEAUTOMOUNTERKCM_H

