/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.impanel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef IMPANELADAPTOR_H
#define IMPANELADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kimpanelagent.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.impanel
 */
class ImpanelAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.impanel")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.impanel\">\n"
"    <signal name=\"MovePreeditCaret\">\n"
"      <arg type=\"i\" name=\"position\"/>\n"
"    </signal>\n"
"    <signal name=\"SelectCandidate\">\n"
"      <arg type=\"i\" name=\"index\"/>\n"
"    </signal>\n"
"    <signal name=\"LookupTablePageUp\"/>\n"
"    <signal name=\"LookupTablePageDown\"/>\n"
"    <signal name=\"TriggerProperty\">\n"
"      <arg type=\"s\" name=\"key\"/>\n"
"    </signal>\n"
"    <signal name=\"PanelCreated\"/>\n"
"    <signal name=\"Exit\"/>\n"
"    <signal name=\"ReloadConfig\"/>\n"
"    <signal name=\"Configure\"/>\n"
"  </interface>\n"
        "")
public:
    ImpanelAdaptor(PanelAgent *parent);
    ~ImpanelAdaptor() override;

    inline PanelAgent *parent() const
    { return static_cast<PanelAgent *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void Configure();
    void Exit();
    void LookupTablePageDown();
    void LookupTablePageUp();
    void MovePreeditCaret(int position);
    void PanelCreated();
    void ReloadConfig();
    void SelectCandidate(int index);
    void TriggerProperty(const QString &key);
};

/*
 * Adaptor class for interface org.kde.impanel2
 */
class Impanel2Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.impanel2")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.impanel2\">\n"
"    <signal name=\"PanelCreated2\"/>\n"
"    <method name=\"SetSpotRect\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"x\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"y\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"w\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"h\"/>\n"
"    </method>\n"
"    <method name=\"SetLookupTable\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"label\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"text\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attr\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"hasPrev\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"hasNext\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"cursor\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"layout\"/>\n"
"    </method>\n"
"    <signal name=\"PanelRegistered\"/>\n"
"  </interface>\n"
        "")
public:
    Impanel2Adaptor(PanelAgent *parent);
    ~Impanel2Adaptor() override;

    inline PanelAgent *parent() const
    { return static_cast<PanelAgent *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void SetLookupTable(const QStringList &label, const QStringList &text, const QStringList &attr, bool hasPrev, bool hasNext, int cursor, int layout);
    void SetSpotRect(int x, int y, int w, int h);
Q_SIGNALS: // SIGNALS
    void PanelCreated2();
    void PanelRegistered();
};

#endif
