// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "landingpagedata.h"

#include "landingpage_kdeglobalssettings.h"




LandingPageData::LandingPageData(QObject *parent)
: KCModuleData(parent)
, m_settings(new LandingPageGlobalsSettings(this))

{
autoRegisterSkeletons();
}

LandingPageGlobalsSettings *LandingPageData::settings() const
{
    return m_settings;
}





#include "moc_landingpagedata.cpp"
