// This file is generated by kconfig_compiler_kf6 from emojiersettings.kcfg.
// All changes you do to this file will be lost.
#ifndef EMOJIERSETTINGS_H
#define EMOJIERSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class EmojierSettings : public KConfigSkeleton
{
  public:
    enum SkinTone { HasNoVariants, Neutral, Light, MediumLight, Medium, MediumDark, Dark };

    EmojierSettings( );
    ~EmojierSettings() override;

    /**
      Set recent
    */
    void setRecent( const QStringList & v )
    {
      if (!isRecentImmutable())
        mRecent = v;
    }

    /**
      Get recent
    */
    QStringList recent() const
    {
      return mRecent;
    }

    /**
      Is recent Immutable
    */
    bool isRecentImmutable() const
    {
      return isImmutable( QStringLiteral( "recent" ) );
    }

    /**
      Set recentDescriptions
    */
    void setRecentDescriptions( const QStringList & v )
    {
      if (!isRecentDescriptionsImmutable())
        mRecentDescriptions = v;
    }

    /**
      Get recentDescriptions
    */
    QStringList recentDescriptions() const
    {
      return mRecentDescriptions;
    }

    /**
      Is recentDescriptions Immutable
    */
    bool isRecentDescriptionsImmutable() const
    {
      return isImmutable( QStringLiteral( "recentDescriptions" ) );
    }

    /**
      Set skinTone
    */
    void setSkinTone( int v )
    {
      if (!isSkinToneImmutable())
        mSkinTone = v;
    }

    /**
      Get skinTone
    */
    int skinTone() const
    {
      return mSkinTone;
    }

    /**
      Is skinTone Immutable
    */
    bool isSkinToneImmutable() const
    {
      return isImmutable( QStringLiteral( "skinTone" ) );
    }

  protected:

    // Emojier
    QStringList mRecent;
    QStringList mRecentDescriptions;
    int mSkinTone;
};

#endif

