// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef LANDINGPAGEDATA_H
#define LANDINGPAGEDATA_H

#include <QObject>

#include "kcmoduledata.h"



class LandingPageGlobalsSettings;


class LandingPageData : public KCModuleData
{
    Q_OBJECT

public:
    explicit LandingPageData(QObject *parent = nullptr);
    LandingPageGlobalsSettings *settings() const;


private:
    LandingPageGlobalsSettings *m_settings;

};



#endif
