// This file is generated by kconfig_compiler_kf6 from kcmaccessibilityscreenreader.kcfg.
// All changes you do to this file will be lost.

#include "kcmaccessibilityscreenreader.h"

ScreenReaderSettings::ScreenReaderSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kaccessrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&ScreenReaderSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "ScreenReader" ) );

  KConfigCompilerSignallingItem  *itemEnabled;
  KConfigSkeleton::ItemBool  *innerItemEnabled;
  innerItemEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Enabled" ), mEnabled, false );
  itemEnabled = new KConfigCompilerSignallingItem(innerItemEnabled, this, notifyFunction, signalEnabledChanged);
  itemEnabled->setWriteFlags(KConfigBase::Notify);
  addItem( itemEnabled, QStringLiteral( "Enabled" ) );
}

bool ScreenReaderSettings::defaultEnabledValue_helper() const
{

  return false;
}

ScreenReaderSettings::~ScreenReaderSettings()
{
}


void ScreenReaderSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalEnabledChanged:
    Q_EMIT EnabledChanged();
    break;
  }
}
