/****************************************************************************
** Meta object code from reading C++ file 'keyboardsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../keyboardsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KeyboardSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardSettings::qt_create_metaobjectdata<qt_meta_tag_ZN16KeyboardSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardSettings",
        "layoutListChanged",
        "",
        "layoutLoopCountChanged",
        "keyboardModelChanged",
        "xkbOptionsChanged",
        "resetOldXkbOptionsChanged",
        "switchModeChanged",
        "configureLayoutsChanged",
        "variantListChanged",
        "displayNamesChanged",
        "layoutList",
        "isLayoutListImmutable",
        "defaultLayoutListValue",
        "layoutLoopCount",
        "isLayoutLoopCountImmutable",
        "defaultLayoutLoopCountValue",
        "keyboardModel",
        "isKeyboardModelImmutable",
        "defaultKeyboardModelValue",
        "xkbOptions",
        "isXkbOptionsImmutable",
        "defaultXkbOptionsValue",
        "resetOldXkbOptions",
        "isResetOldXkbOptionsImmutable",
        "defaultResetOldXkbOptionsValue",
        "switchMode",
        "isSwitchModeImmutable",
        "defaultSwitchModeValue",
        "configureLayouts",
        "isConfigureLayoutsImmutable",
        "defaultConfigureLayoutsValue",
        "variantList",
        "isVariantListImmutable",
        "defaultVariantListValue",
        "displayNames",
        "isDisplayNamesImmutable",
        "defaultDisplayNamesValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'layoutListChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutLoopCountChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardModelChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xkbOptionsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetOldXkbOptionsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchModeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configureLayoutsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'variantListChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayNamesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'layoutList'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isLayoutListImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLayoutListValue'
        QtMocHelpers::PropertyData<QStringList>(13, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'layoutLoopCount'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isLayoutLoopCountImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLayoutLoopCountValue'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyboardModel'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isKeyboardModelImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeyboardModelValue'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xkbOptions'
        QtMocHelpers::PropertyData<QStringList>(20, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isXkbOptionsImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultXkbOptionsValue'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'resetOldXkbOptions'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isResetOldXkbOptionsImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultResetOldXkbOptionsValue'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'switchMode'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isSwitchModeImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSwitchModeValue'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'configureLayouts'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isConfigureLayoutsImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultConfigureLayoutsValue'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'variantList'
        QtMocHelpers::PropertyData<QStringList>(32, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isVariantListImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVariantListValue'
        QtMocHelpers::PropertyData<QStringList>(34, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayNames'
        QtMocHelpers::PropertyData<QStringList>(35, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isDisplayNamesImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayNamesValue'
        QtMocHelpers::PropertyData<QStringList>(37, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardSettings, qt_meta_tag_ZN16KeyboardSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.metaTypes,
    nullptr
} };

void KeyboardSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->layoutListChanged(); break;
        case 1: _t->layoutLoopCountChanged(); break;
        case 2: _t->keyboardModelChanged(); break;
        case 3: _t->xkbOptionsChanged(); break;
        case 4: _t->resetOldXkbOptionsChanged(); break;
        case 5: _t->switchModeChanged(); break;
        case 6: _t->configureLayoutsChanged(); break;
        case 7: _t->variantListChanged(); break;
        case 8: _t->displayNamesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::layoutListChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::layoutLoopCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::keyboardModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::xkbOptionsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::resetOldXkbOptionsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::switchModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::configureLayoutsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::variantListChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::displayNamesChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->layoutList(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isLayoutListImmutable(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->defaultLayoutListValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->layoutLoopCount(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isLayoutLoopCountImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultLayoutLoopCountValue(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->keyboardModel(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isKeyboardModelImmutable(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->defaultKeyboardModelValue(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->xkbOptions(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isXkbOptionsImmutable(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->defaultXkbOptionsValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->resetOldXkbOptions(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isResetOldXkbOptionsImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultResetOldXkbOptionsValue(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->switchMode(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isSwitchModeImmutable(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->defaultSwitchModeValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->configureLayouts(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isConfigureLayoutsImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultConfigureLayoutsValue(); break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->variantList(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isVariantListImmutable(); break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->defaultVariantListValue(); break;
        case 24: *reinterpret_cast<QStringList*>(_v) = _t->displayNames(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isDisplayNamesImmutable(); break;
        case 26: *reinterpret_cast<QStringList*>(_v) = _t->defaultDisplayNamesValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLayoutList(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setLayoutLoopCount(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setKeyboardModel(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setXkbOptions(*reinterpret_cast<QStringList*>(_v)); break;
        case 12: _t->setResetOldXkbOptions(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setSwitchMode(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setConfigureLayouts(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setVariantList(*reinterpret_cast<QStringList*>(_v)); break;
        case 24: _t->setDisplayNames(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int KeyboardSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void KeyboardSettings::layoutListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeyboardSettings::layoutLoopCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeyboardSettings::keyboardModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeyboardSettings::xkbOptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KeyboardSettings::resetOldXkbOptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KeyboardSettings::switchModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KeyboardSettings::configureLayoutsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KeyboardSettings::variantListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KeyboardSettings::displayNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
