// This file is generated by kconfig_compiler_kf6 from splashscreensettings.kcfg.
// All changes you do to this file will be lost.

#include "splashscreensettings.h"

SplashScreenSettings::SplashScreenSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "ksplashrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&SplashScreenSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "KSplash" ) );

  KConfigCompilerSignallingItem  *itemEngine;
  KConfigSkeleton::ItemString  *innerItemEngine;
  innerItemEngine = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Engine" ), mEngine, theme() == QStringLiteral("None") ? QStringLiteral("none") : QStringLiteral("KSplashQML") );
  itemEngine = new KConfigCompilerSignallingItem(innerItemEngine, this, notifyFunction, signalEngineChanged);
  addItem( itemEngine, QStringLiteral( "engine" ) );
  KConfigCompilerSignallingItem  *itemTheme;
  KConfigSkeleton::ItemString  *innerItemTheme;
  innerItemTheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Theme" ), mTheme, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemTheme = new KConfigCompilerSignallingItem(innerItemTheme, this, notifyFunction, signalThemeChanged);
  addItem( itemTheme, QStringLiteral( "theme" ) );
}

QString SplashScreenSettings::defaultEngineValue_helper() const
{

  return theme() == QStringLiteral("None") ? QStringLiteral("none") : QStringLiteral("KSplashQML");
}

QString SplashScreenSettings::defaultThemeValue_helper() const
{

  return QStringLiteral( "org.kde.breeze.desktop" );
}

SplashScreenSettings::~SplashScreenSettings()
{
}


void SplashScreenSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalEngineChanged:
    Q_EMIT engineChanged();
    break;
  case signalThemeChanged:
    Q_EMIT themeChanged();
    break;
  }
}
