// /qt/qml/plasma/applet/org/kde/plasma/showdesktop/Controller.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_plasma_applet_org_kde_plasma_showdesktop_Controller_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc8,0x4,0x0,0x0,0x5a,0x99,0xb5,0x71,
0xcd,0x66,0xc3,0xd1,0x6c,0x7b,0x72,0x25,
0xb0,0x97,0x79,0x12,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0xf0,0x1,0x0,0x0,
0x3,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc0,0x3,0x0,0x0,
0xf0,0x0,0x0,0x0,0x48,0x1,0x0,0x0,
0xa0,0x1,0x0,0x0,0x33,0x0,0x0,0x0,
0x43,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0x33,0x0,0x0,0x0,0x63,0x0,0x0,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x15,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x50,0x4,
0x2e,0x1,0x4c,0x2,0x2e,0x2,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x16,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x3,0x50,0x4,
0x2e,0x4,0x4c,0x2,0x2e,0x5,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x28,0x2,0x0,0x0,0x30,0x2,0x0,0x0,
0x40,0x2,0x0,0x0,0x58,0x2,0x0,0x0,
0x70,0x2,0x0,0x0,0x90,0x2,0x0,0x0,
0xb0,0x2,0x0,0x0,0xd8,0x2,0x0,0x0,
0x8,0x3,0x0,0x0,0x18,0x3,0x0,0x0,
0x48,0x3,0x0,0x0,0x68,0x3,0x0,0x0,
0xa8,0x3,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x6d,0x0,0x6c,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x4f,0x0,0x62,0x0,0x6a,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x61,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x76,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x74,0x0,0x69,0x0,
0x74,0x0,0x6c,0x0,0x65,0x0,0x41,0x0,
0x63,0x0,0x74,0x0,0x69,0x0,0x76,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x74,0x0,0x69,0x0,
0x74,0x0,0x6c,0x0,0x65,0x0,0x49,0x0,
0x6e,0x0,0x61,0x0,0x63,0x0,0x74,0x0,
0x69,0x0,0x76,0x0,0x65,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x73,0x0,0x63,0x0,0x72,0x0,0x69,0x0,
0x70,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x41,0x0,0x63,0x0,0x74,0x0,
0x69,0x0,0x76,0x0,0x65,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x73,0x0,0x63,0x0,0x72,0x0,0x69,0x0,
0x70,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x49,0x0,0x6e,0x0,0x61,0x0,
0x63,0x0,0x74,0x0,0x69,0x0,0x76,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x74,0x0,0x69,0x0,
0x74,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x69,0x0,0x74,0x0,
0x6c,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x73,0x0,0x63,0x0,0x72,0x0,0x69,0x0,
0x70,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x64,0x0,0x65,0x0,0x73,0x0,
0x63,0x0,0x72,0x0,0x69,0x0,0x70,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x67,0x0,0x67,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x28,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x1,0x0,0x7,0x0,0x54,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0xac,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xac,0x0,0x0,0x0,
0xac,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xac,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xdc,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0xd,0x0,0x50,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x20,0xf,0x0,0x50,0x0,
0x5,0x0,0x0,0x0,0x5,0x0,0x0,0x20,
0x10,0x0,0x50,0x0,0x6,0x0,0x0,0x0,
0x5,0x0,0x0,0x20,0x12,0x0,0x50,0x0,
0x7,0x0,0x0,0x0,0x5,0x0,0x0,0x20,
0x13,0x0,0x50,0x0,0x8,0x0,0x0,0x0,
0x5,0x0,0x0,0xa0,0x15,0x0,0x50,0x0,
0xa,0x0,0x0,0x0,0x5,0x0,0x0,0xa0,
0x16,0x0,0x50,0x0,0xa,0x0,0x0,0x0,
0x8,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0xe0,0x1,
0x16,0x0,0xb0,0x2,0x8,0x0,0x0,0x0,
0x8,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0xe0,0x1,
0x15,0x0,0x50,0x2,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for title at line 21, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QString c2_10;
QString v2_4;
QString v2_8;
bool v2_0;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(0, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_0) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(1, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_Jump
{
s.c2_10 = s.v2_4;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(2, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadScopeObjectPropertyLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
s.c2_10 = s.v2_8;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.c2_10);
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for description at line 22, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QString c2_10;
QString v2_4;
QString v2_8;
bool v2_0;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(3, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_0) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(4, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_Jump
{
s.c2_10 = s.v2_4;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(5, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadScopeObjectPropertyLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
s.c2_10 = s.v2_8;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.c2_10);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// toggle at line 25, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_Ret
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
