// This file is generated by kconfig_compiler_kf6 from kcmaccessibilitykeyboard.kcfg.
// All changes you do to this file will be lost.

#include "kcmaccessibilitykeyboard.h"

KeyboardSettings::KeyboardSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kaccessrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&KeyboardSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Keyboard" ) );

  KConfigCompilerSignallingItem  *itemStickyKeys;
  KConfigSkeleton::ItemBool  *innerItemStickyKeys;
  innerItemStickyKeys = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "StickyKeys" ), mStickyKeys, false );
  itemStickyKeys = new KConfigCompilerSignallingItem(innerItemStickyKeys, this, notifyFunction, signalStickyKeysChanged);
  itemStickyKeys->setWriteFlags(KConfigBase::Notify);
  addItem( itemStickyKeys, QStringLiteral( "StickyKeys" ) );
  KConfigCompilerSignallingItem  *itemStickyKeysLatch;
  KConfigSkeleton::ItemBool  *innerItemStickyKeysLatch;
  innerItemStickyKeysLatch = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "StickyKeysLatch" ), mStickyKeysLatch, true );
  itemStickyKeysLatch = new KConfigCompilerSignallingItem(innerItemStickyKeysLatch, this, notifyFunction, signalStickyKeysLatchChanged);
  itemStickyKeysLatch->setWriteFlags(KConfigBase::Notify);
  addItem( itemStickyKeysLatch, QStringLiteral( "StickyKeysLatch" ) );
  KConfigCompilerSignallingItem  *itemStickyKeysAutoOff;
  KConfigSkeleton::ItemBool  *innerItemStickyKeysAutoOff;
  innerItemStickyKeysAutoOff = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "StickyKeysAutoOff" ), mStickyKeysAutoOff, false );
  itemStickyKeysAutoOff = new KConfigCompilerSignallingItem(innerItemStickyKeysAutoOff, this, notifyFunction, signalStickyKeysAutoOffChanged);
  itemStickyKeysAutoOff->setWriteFlags(KConfigBase::Notify);
  addItem( itemStickyKeysAutoOff, QStringLiteral( "StickyKeysAutoOff" ) );
  KConfigCompilerSignallingItem  *itemStickyKeysBeep;
  KConfigSkeleton::ItemBool  *innerItemStickyKeysBeep;
  innerItemStickyKeysBeep = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "StickyKeysBeep" ), mStickyKeysBeep, false );
  itemStickyKeysBeep = new KConfigCompilerSignallingItem(innerItemStickyKeysBeep, this, notifyFunction, signalStickyKeysBeepChanged);
  itemStickyKeysBeep->setWriteFlags(KConfigBase::Notify);
  addItem( itemStickyKeysBeep, QStringLiteral( "StickyKeysBeep" ) );
  KConfigCompilerSignallingItem  *itemToggleKeysBeep;
  KConfigSkeleton::ItemBool  *innerItemToggleKeysBeep;
  innerItemToggleKeysBeep = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ToggleKeysBeep" ), mToggleKeysBeep, false );
  itemToggleKeysBeep = new KConfigCompilerSignallingItem(innerItemToggleKeysBeep, this, notifyFunction, signalToggleKeysBeepChanged);
  itemToggleKeysBeep->setWriteFlags(KConfigBase::Notify);
  addItem( itemToggleKeysBeep, QStringLiteral( "ToggleKeysBeep" ) );
  KConfigCompilerSignallingItem  *itemKeyboardNotifyModifiers;
  KConfigSkeleton::ItemBool  *innerItemKeyboardNotifyModifiers;
  innerItemKeyboardNotifyModifiers = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "kNotifyModifiers" ), mKeyboardNotifyModifiers, false );
  itemKeyboardNotifyModifiers = new KConfigCompilerSignallingItem(innerItemKeyboardNotifyModifiers, this, notifyFunction, signalKeyboardNotifyModifiersChanged);
  itemKeyboardNotifyModifiers->setWriteFlags(KConfigBase::Notify);
  addItem( itemKeyboardNotifyModifiers, QStringLiteral( "KeyboardNotifyModifiers" ) );
}

bool KeyboardSettings::defaultStickyKeysValue_helper() const
{

  return false;
}

bool KeyboardSettings::defaultStickyKeysLatchValue_helper() const
{

  return true;
}

bool KeyboardSettings::defaultStickyKeysAutoOffValue_helper() const
{

  return false;
}

bool KeyboardSettings::defaultStickyKeysBeepValue_helper() const
{

  return false;
}

bool KeyboardSettings::defaultToggleKeysBeepValue_helper() const
{

  return false;
}

bool KeyboardSettings::defaultKeyboardNotifyModifiersValue_helper() const
{

  return false;
}

KeyboardSettings::~KeyboardSettings()
{
}


void KeyboardSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalStickyKeysChanged:
    Q_EMIT StickyKeysChanged();
    break;
  case signalStickyKeysLatchChanged:
    Q_EMIT StickyKeysLatchChanged();
    break;
  case signalStickyKeysAutoOffChanged:
    Q_EMIT StickyKeysAutoOffChanged();
    break;
  case signalStickyKeysBeepChanged:
    Q_EMIT StickyKeysBeepChanged();
    break;
  case signalToggleKeysBeepChanged:
    Q_EMIT ToggleKeysBeepChanged();
    break;
  case signalKeyboardNotifyModifiersChanged:
    Q_EMIT KeyboardNotifyModifiersChanged();
    break;
  }
}
