#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_config_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_AbstractKickoffItemDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_ActionMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_ApplicationsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_BasePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_Badge_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_ConfigGeneral_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_DropAreaGridView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_DropAreaListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_EmptyPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_Footer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_FullRepresentation_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_Header_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_HorizontalStackView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffDropArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffGridDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffGridView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffListDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffSingleton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_LeaveButtons_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_ListOfGridsView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_ListOfGridsViewDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_NormalPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_PlacesPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_SectionView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_VerticalStackView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_code_tools_js { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/config.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_config_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/AbstractKickoffItemDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_AbstractKickoffItemDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/ActionMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_ActionMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/ApplicationsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_ApplicationsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/BasePage.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_BasePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/Badge.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_Badge_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/ConfigGeneral.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_ConfigGeneral_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/DropAreaGridView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_DropAreaGridView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/DropAreaListView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_DropAreaListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/EmptyPage.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_EmptyPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/Footer.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_Footer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/FullRepresentation.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_FullRepresentation_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/Header.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_Header_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/HorizontalStackView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_HorizontalStackView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/KickoffDropArea.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffDropArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/KickoffGridDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffGridDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/KickoffGridView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffGridView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/KickoffListDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffListDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/KickoffListView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/KickoffSingleton.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_KickoffSingleton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/LeaveButtons.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_LeaveButtons_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/ListOfGridsView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_ListOfGridsView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/ListOfGridsViewDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_ListOfGridsViewDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/NormalPage.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_NormalPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/PlacesPage.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_PlacesPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/SectionView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_SectionView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/VerticalStackView.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_VerticalStackView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/main.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/kickoff/code/tools.js"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_kickoff_code_tools_js::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasma)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasma))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_org_kde_plasma)() {
    return 1;
}
