/****************************************************************************
** Meta object code from reading C++ file 'doodad.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-desktop-6.6.4/kcms/keyboard/tastenbrett/doodad.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'doodad.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6DoodadE_t {};
} // unnamed namespace

template <> constexpr inline auto Doodad::qt_create_metaobjectdata<qt_meta_tag_ZN6DoodadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Doodad",
        "priority"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'priority'
        QtMocHelpers::PropertyData<uchar>(1, QMetaType::UChar, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Doodad, qt_meta_tag_ZN6DoodadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Doodad::staticMetaObject = { {
    QMetaObject::SuperData::link<XkbObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DoodadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DoodadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6DoodadE_t>.metaTypes,
    nullptr
} };

void Doodad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Doodad *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uchar*>(_v) = _t->auto_prop_priority(); break;
        default: break;
        }
    }
}

const QMetaObject *Doodad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Doodad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DoodadE_t>.strings))
        return static_cast<void*>(this);
    return XkbObject::qt_metacast(_clname);
}

int Doodad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XkbObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN11ShapeDoodadE_t {};
} // unnamed namespace

template <> constexpr inline auto ShapeDoodad::qt_create_metaobjectdata<qt_meta_tag_ZN11ShapeDoodadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShapeDoodad",
        "top",
        "left",
        "angle",
        "shape",
        "Shape*",
        "color",
        "QColor",
        "outlineOnly"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'top'
        QtMocHelpers::PropertyData<short>(1, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'left'
        QtMocHelpers::PropertyData<short>(2, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'angle'
        QtMocHelpers::PropertyData<short>(3, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shape'
        QtMocHelpers::PropertyData<Shape*>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'outlineOnly'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShapeDoodad, qt_meta_tag_ZN11ShapeDoodadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ShapeDoodad::staticMetaObject = { {
    QMetaObject::SuperData::link<Doodad::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ShapeDoodadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ShapeDoodadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ShapeDoodadE_t>.metaTypes,
    nullptr
} };

void ShapeDoodad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShapeDoodad *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<short*>(_v) = _t->auto_prop_top(); break;
        case 1: *reinterpret_cast<short*>(_v) = _t->auto_prop_left(); break;
        case 2: *reinterpret_cast<short*>(_v) = _t->auto_prop_angle(); break;
        case 3: *reinterpret_cast<Shape**>(_v) = _t->shape; break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->color; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->outlineOnly; break;
        default: break;
        }
    }
}

const QMetaObject *ShapeDoodad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShapeDoodad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ShapeDoodadE_t>.strings))
        return static_cast<void*>(this);
    return Doodad::qt_metacast(_clname);
}

int ShapeDoodad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Doodad::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10TextDoodadE_t {};
} // unnamed namespace

template <> constexpr inline auto TextDoodad::qt_create_metaobjectdata<qt_meta_tag_ZN10TextDoodadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextDoodad",
        "top",
        "left",
        "angle",
        "width",
        "height",
        "text",
        "font",
        "color",
        "QColor"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'top'
        QtMocHelpers::PropertyData<short>(1, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'left'
        QtMocHelpers::PropertyData<short>(2, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'angle'
        QtMocHelpers::PropertyData<short>(3, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'width'
        QtMocHelpers::PropertyData<short>(4, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'height'
        QtMocHelpers::PropertyData<short>(5, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'font'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TextDoodad, qt_meta_tag_ZN10TextDoodadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TextDoodad::staticMetaObject = { {
    QMetaObject::SuperData::link<Doodad::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10TextDoodadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10TextDoodadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10TextDoodadE_t>.metaTypes,
    nullptr
} };

void TextDoodad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextDoodad *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<short*>(_v) = _t->auto_prop_top(); break;
        case 1: *reinterpret_cast<short*>(_v) = _t->auto_prop_left(); break;
        case 2: *reinterpret_cast<short*>(_v) = _t->auto_prop_angle(); break;
        case 3: *reinterpret_cast<short*>(_v) = _t->auto_prop_width(); break;
        case 4: *reinterpret_cast<short*>(_v) = _t->auto_prop_height(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->auto_prop_text(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->auto_prop_font(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->color; break;
        default: break;
        }
    }
}

const QMetaObject *TextDoodad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextDoodad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10TextDoodadE_t>.strings))
        return static_cast<void*>(this);
    return Doodad::qt_metacast(_clname);
}

int TextDoodad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Doodad::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN15IndicatorDoodadE_t {};
} // unnamed namespace

template <> constexpr inline auto IndicatorDoodad::qt_create_metaobjectdata<qt_meta_tag_ZN15IndicatorDoodadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IndicatorDoodad",
        "onChanged",
        "",
        "refreshState",
        "top",
        "left",
        "angle",
        "shape",
        "Shape*",
        "onColor",
        "QColor",
        "offColor",
        "on"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'onChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshState'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'top'
        QtMocHelpers::PropertyData<short>(4, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'left'
        QtMocHelpers::PropertyData<short>(5, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'angle'
        QtMocHelpers::PropertyData<short>(6, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shape'
        QtMocHelpers::PropertyData<Shape*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'onColor'
        QtMocHelpers::PropertyData<QColor>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'offColor'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'on'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IndicatorDoodad, qt_meta_tag_ZN15IndicatorDoodadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IndicatorDoodad::staticMetaObject = { {
    QMetaObject::SuperData::link<Doodad::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15IndicatorDoodadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15IndicatorDoodadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15IndicatorDoodadE_t>.metaTypes,
    nullptr
} };

void IndicatorDoodad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IndicatorDoodad *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onChanged(); break;
        case 1: _t->refreshState(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IndicatorDoodad::*)()>(_a, &IndicatorDoodad::onChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<short*>(_v) = _t->auto_prop_top(); break;
        case 1: *reinterpret_cast<short*>(_v) = _t->auto_prop_left(); break;
        case 2: *reinterpret_cast<short*>(_v) = _t->auto_prop_angle(); break;
        case 3: *reinterpret_cast<Shape**>(_v) = _t->shape; break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->onColor; break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->offColor; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->on; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6:
            if (QtMocHelpers::setProperty(_t->on, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->onChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *IndicatorDoodad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IndicatorDoodad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15IndicatorDoodadE_t>.strings))
        return static_cast<void*>(this);
    return Doodad::qt_metacast(_clname);
}

int IndicatorDoodad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Doodad::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void IndicatorDoodad::onChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN10LogoDoodadE_t {};
} // unnamed namespace

template <> constexpr inline auto LogoDoodad::qt_create_metaobjectdata<qt_meta_tag_ZN10LogoDoodadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LogoDoodad",
        "top",
        "left",
        "angle",
        "logo_name"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'top'
        QtMocHelpers::PropertyData<short>(1, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'left'
        QtMocHelpers::PropertyData<short>(2, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'angle'
        QtMocHelpers::PropertyData<short>(3, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'logo_name'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LogoDoodad, qt_meta_tag_ZN10LogoDoodadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LogoDoodad::staticMetaObject = { {
    QMetaObject::SuperData::link<ShapeDoodad::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LogoDoodadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LogoDoodadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10LogoDoodadE_t>.metaTypes,
    nullptr
} };

void LogoDoodad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LogoDoodad *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<short*>(_v) = _t->auto_prop_top(); break;
        case 1: *reinterpret_cast<short*>(_v) = _t->auto_prop_left(); break;
        case 2: *reinterpret_cast<short*>(_v) = _t->auto_prop_angle(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->auto_prop_logo_name(); break;
        default: break;
        }
    }
}

const QMetaObject *LogoDoodad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LogoDoodad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LogoDoodadE_t>.strings))
        return static_cast<void*>(this);
    return ShapeDoodad::qt_metacast(_clname);
}

int LogoDoodad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ShapeDoodad::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
