/****************************************************************************
** Meta object code from reading C++ file 'pagermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/applets/pager/pagermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pagermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PagerModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PagerModel::qt_create_metaobjectdata<qt_meta_tag_ZN10PagerModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PagerModel",
        "QML.Element",
        "auto",
        "countChanged",
        "",
        "pagerTypeChanged",
        "enabledChanged",
        "shouldShowPagerChanged",
        "showDesktopChanged",
        "showOnlyCurrentScreenChanged",
        "screenGeometryChanged",
        "currentPageChanged",
        "layoutRowsChanged",
        "pagerItemSizeChanged",
        "computePagerItemSize",
        "refresh",
        "moveWindow",
        "QModelIndex",
        "window",
        "x",
        "y",
        "QVariant",
        "targetItemId",
        "sourceItemId",
        "widthScaleFactor",
        "heightScaleFactor",
        "changePage",
        "page",
        "drop",
        "QMimeData*",
        "mimeData",
        "modifiers",
        "itemId",
        "addDesktop",
        "removeDesktop",
        "count",
        "pagerType",
        "PagerType",
        "enabled",
        "shouldShowPager",
        "showDesktop",
        "showOnlyCurrentScreen",
        "screenGeometry",
        "QRect",
        "currentPage",
        "layoutRows",
        "pagerItemSize",
        "QSize",
        "VirtualDesktops",
        "Activities",
        "AdditionalRoles",
        "TasksModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pagerTypeChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shouldShowPagerChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showDesktopChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showOnlyCurrentScreenChanged'
        QtMocHelpers::SignalData<void() const>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void() const>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentPageChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutRowsChanged'
        QtMocHelpers::SignalData<void() const>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pagerItemSizeChanged'
        QtMocHelpers::SignalData<void() const>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'computePagerItemSize'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'refresh'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'moveWindow'
        QtMocHelpers::MethodData<void(const QModelIndex &, double, double, const QVariant &, const QVariant &, qreal, qreal)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Double, 19 }, { QMetaType::Double, 20 }, { 0x80000000 | 21, 22 },
            { 0x80000000 | 21, 23 }, { QMetaType::QReal, 24 }, { QMetaType::QReal, 25 },
        }}),
        // Method 'changePage'
        QtMocHelpers::MethodData<void(int)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Method 'drop'
        QtMocHelpers::MethodData<void(QMimeData *, int, const QVariant &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 }, { QMetaType::Int, 31 }, { 0x80000000 | 21, 32 },
        }}),
        // Method 'addDesktop'
        QtMocHelpers::MethodData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'removeDesktop'
        QtMocHelpers::MethodData<void()>(34, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'pagerType'
        QtMocHelpers::PropertyData<enum PagerType>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'shouldShowPager'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'showDesktop'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'showOnlyCurrentScreen'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'screenGeometry'
        QtMocHelpers::PropertyData<QRect>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'currentPage'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags, 7),
        // property 'layoutRows'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
        // property 'pagerItemSize'
        QtMocHelpers::PropertyData<QSize>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PagerType'
        QtMocHelpers::EnumData<enum PagerType>(37, 37, QMC::EnumFlags{}).add({
            {   48, PagerType::VirtualDesktops },
            {   49, PagerType::Activities },
        }),
        // enum 'AdditionalRoles'
        QtMocHelpers::EnumData<enum AdditionalRoles>(50, 50, QMC::EnumFlags{}).add({
            {   51, AdditionalRoles::TasksModel },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PagerModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PagerModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PagerModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PagerModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PagerModelE_t>.metaTypes,
    nullptr
} };

void PagerModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PagerModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->pagerTypeChanged(); break;
        case 2: _t->enabledChanged(); break;
        case 3: _t->shouldShowPagerChanged(); break;
        case 4: _t->showDesktopChanged(); break;
        case 5: _t->showOnlyCurrentScreenChanged(); break;
        case 6: _t->screenGeometryChanged(); break;
        case 7: _t->currentPageChanged(); break;
        case 8: _t->layoutRowsChanged(); break;
        case 9: _t->pagerItemSizeChanged(); break;
        case 10: _t->computePagerItemSize(); break;
        case 11: _t->refresh(); break;
        case 12: _t->moveWindow((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[7]))); break;
        case 13: _t->changePage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->drop((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 15: _t->addDesktop(); break;
        case 16: _t->removeDesktop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::pagerTypeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::enabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::shouldShowPagerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::showDesktopChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::showOnlyCurrentScreenChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::screenGeometryChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::currentPageChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::layoutRowsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagerModel::*)() const>(_a, &PagerModel::pagerItemSizeChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        case 1: *reinterpret_cast<enum PagerType*>(_v) = _t->pagerType(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->shouldShowPager(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->showDesktop(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showOnlyCurrentScreen(); break;
        case 6: *reinterpret_cast<QRect*>(_v) = _t->screenGeometry(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->currentPage(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->layoutRows(); break;
        case 9: *reinterpret_cast<QSize*>(_v) = _t->pagerItemSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setPagerType(*reinterpret_cast<enum PagerType*>(_v)); break;
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setShowDesktop(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setShowOnlyCurrentScreen(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setScreenGeometry(*reinterpret_cast<QRect*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PagerModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PagerModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PagerModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int PagerModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void PagerModel::countChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PagerModel::pagerTypeChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PagerModel::enabledChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PagerModel::shouldShowPagerChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PagerModel::showDesktopChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PagerModel::showOnlyCurrentScreenChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PagerModel::screenGeometryChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PagerModel::currentPageChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PagerModel::layoutRowsChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PagerModel::pagerItemSizeChanged()const
{
    QMetaObject::activate(const_cast< PagerModel *>(this), &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
