/****************************************************************************
** Meta object code from reading C++ file 'kcmkded.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/kcms/kded/kcmkded.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmkded.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KDEDConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto KDEDConfig::qt_create_metaobjectdata<qt_meta_tag_ZN10KDEDConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDEDConfig",
        "kdedRunningChanged",
        "",
        "errorMessage",
        "errorString",
        "showSelfDisablingModulesHint",
        "showRunningModulesChangedAfterSaveHint",
        "startModule",
        "moduleName",
        "stopModule",
        "model",
        "ModulesModel*",
        "filteredModel",
        "FilterProxyModel*",
        "kdedRunning",
        "ModuleType",
        "UnknownType",
        "AutostartType",
        "OnDemandType",
        "ManualType",
        "ModuleStatus",
        "UnknownStatus",
        "NotRunning",
        "Running"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'kdedRunningChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'showSelfDisablingModulesHint'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRunningModulesChangedAfterSaveHint'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'startModule'
        QtMocHelpers::MethodData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'stopModule'
        QtMocHelpers::MethodData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'model'
        QtMocHelpers::PropertyData<ModulesModel*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'filteredModel'
        QtMocHelpers::PropertyData<FilterProxyModel*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'kdedRunning'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ModuleType'
        QtMocHelpers::EnumData<enum ModuleType>(15, 15, QMC::EnumFlags{}).add({
            {   16, ModuleType::UnknownType },
            {   17, ModuleType::AutostartType },
            {   18, ModuleType::OnDemandType },
            {   19, ModuleType::ManualType },
        }),
        // enum 'ModuleStatus'
        QtMocHelpers::EnumData<enum ModuleStatus>(20, 20, QMC::EnumFlags{}).add({
            {   21, ModuleStatus::UnknownStatus },
            {   22, ModuleStatus::NotRunning },
            {   23, ModuleStatus::Running },
        }),
    };
    return QtMocHelpers::metaObjectData<KDEDConfig, qt_meta_tag_ZN10KDEDConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDEDConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KDEDConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KDEDConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KDEDConfigE_t>.metaTypes,
    nullptr
} };

void KDEDConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KDEDConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->kdedRunningChanged(); break;
        case 1: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->showSelfDisablingModulesHint(); break;
        case 3: _t->showRunningModulesChangedAfterSaveHint(); break;
        case 4: _t->startModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->stopModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KDEDConfig::*)()>(_a, &KDEDConfig::kdedRunningChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEDConfig::*)(const QString & )>(_a, &KDEDConfig::errorMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEDConfig::*)()>(_a, &KDEDConfig::showSelfDisablingModulesHint, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEDConfig::*)()>(_a, &KDEDConfig::showRunningModulesChangedAfterSaveHint, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ModulesModel**>(_v) = _t->model(); break;
        case 1: *reinterpret_cast<FilterProxyModel**>(_v) = _t->filteredModel(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->kdedRunning(); break;
        default: break;
        }
    }
}

const QMetaObject *KDEDConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDEDConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KDEDConfigE_t>.strings))
        return static_cast<void*>(this);
    return KQuickConfigModule::qt_metacast(_clname);
}

int KDEDConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KDEDConfig::kdedRunningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDEDConfig::errorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDEDConfig::showSelfDisablingModulesHint()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KDEDConfig::showRunningModulesChangedAfterSaveHint()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
