/****************************************************************************
** Meta object code from reading C++ file 'workspaceoptions_kdeglobalssettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../workspaceoptions_kdeglobalssettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'workspaceoptions_kdeglobalssettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31WorkspaceOptionsGlobalsSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto WorkspaceOptionsGlobalsSettings::qt_create_metaobjectdata<qt_meta_tag_ZN31WorkspaceOptionsGlobalsSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorkspaceOptionsGlobalsSettings",
        "singleClickChanged",
        "",
        "dndBehaviorChanged",
        "smoothScrollChanged",
        "scrollbarLeftClickNavigatesByPageChanged",
        "doubleClickIntervalChanged",
        "singleClick",
        "isSingleClickImmutable",
        "defaultSingleClickValue",
        "dndBehavior",
        "isDndBehaviorImmutable",
        "defaultDndBehaviorValue",
        "smoothScroll",
        "isSmoothScrollImmutable",
        "defaultSmoothScrollValue",
        "scrollbarLeftClickNavigatesByPage",
        "isScrollbarLeftClickNavigatesByPageImmutable",
        "defaultScrollbarLeftClickNavigatesByPageValue",
        "doubleClickInterval",
        "isDoubleClickIntervalImmutable",
        "defaultDoubleClickIntervalValue",
        "DndBehaviorChoices",
        "AlwaysAsk",
        "MoveIfSameDevice"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'singleClickChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dndBehaviorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'smoothScrollChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollbarLeftClickNavigatesByPageChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClickIntervalChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'singleClick'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isSingleClickImmutable'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSingleClickValue'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dndBehavior'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isDndBehaviorImmutable'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDndBehaviorValue'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'smoothScroll'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isSmoothScrollImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSmoothScrollValue'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollbarLeftClickNavigatesByPage'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isScrollbarLeftClickNavigatesByPageImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScrollbarLeftClickNavigatesByPageValue'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'doubleClickInterval'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isDoubleClickIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDoubleClickIntervalValue'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DndBehaviorChoices'
        QtMocHelpers::EnumData<enum DndBehaviorChoices>(22, 22, QMC::EnumFlags{}).add({
            {   23, DndBehaviorChoices::AlwaysAsk },
            {   24, DndBehaviorChoices::MoveIfSameDevice },
        }),
    };
    return QtMocHelpers::metaObjectData<WorkspaceOptionsGlobalsSettings, qt_meta_tag_ZN31WorkspaceOptionsGlobalsSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorkspaceOptionsGlobalsSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31WorkspaceOptionsGlobalsSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31WorkspaceOptionsGlobalsSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31WorkspaceOptionsGlobalsSettingsE_t>.metaTypes,
    nullptr
} };

void WorkspaceOptionsGlobalsSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorkspaceOptionsGlobalsSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->singleClickChanged(); break;
        case 1: _t->dndBehaviorChanged(); break;
        case 2: _t->smoothScrollChanged(); break;
        case 3: _t->scrollbarLeftClickNavigatesByPageChanged(); break;
        case 4: _t->doubleClickIntervalChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsGlobalsSettings::*)()>(_a, &WorkspaceOptionsGlobalsSettings::singleClickChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsGlobalsSettings::*)()>(_a, &WorkspaceOptionsGlobalsSettings::dndBehaviorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsGlobalsSettings::*)()>(_a, &WorkspaceOptionsGlobalsSettings::smoothScrollChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsGlobalsSettings::*)()>(_a, &WorkspaceOptionsGlobalsSettings::scrollbarLeftClickNavigatesByPageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceOptionsGlobalsSettings::*)()>(_a, &WorkspaceOptionsGlobalsSettings::doubleClickIntervalChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->singleClick(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSingleClickImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultSingleClickValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->dndBehavior(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isDndBehaviorImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultDndBehaviorValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->smoothScroll(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSmoothScrollImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultSmoothScrollValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->scrollbarLeftClickNavigatesByPage(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isScrollbarLeftClickNavigatesByPageImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultScrollbarLeftClickNavigatesByPageValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->doubleClickInterval(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isDoubleClickIntervalImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultDoubleClickIntervalValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSingleClick(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDndBehavior(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setSmoothScroll(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setScrollbarLeftClickNavigatesByPage(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setDoubleClickInterval(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WorkspaceOptionsGlobalsSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorkspaceOptionsGlobalsSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31WorkspaceOptionsGlobalsSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int WorkspaceOptionsGlobalsSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void WorkspaceOptionsGlobalsSettings::singleClickChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WorkspaceOptionsGlobalsSettings::dndBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WorkspaceOptionsGlobalsSettings::smoothScrollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void WorkspaceOptionsGlobalsSettings::scrollbarLeftClickNavigatesByPageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void WorkspaceOptionsGlobalsSettings::doubleClickIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
