/****************************************************************************
** Meta object code from reading C++ file 'kcm_keys.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/kcms/keys/kcm_keys.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm_keys.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KCMKeysE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMKeys::qt_create_metaobjectdata<qt_meta_tag_ZN7KCMKeysE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMKeys",
        "showComponent",
        "",
        "row",
        "errorOccured",
        "requestKeySequence",
        "QQuickItem*",
        "context",
        "QModelIndex",
        "index",
        "QKeySequence",
        "newSequence",
        "oldSequence",
        "writeScheme",
        "QUrl",
        "url",
        "loadScheme",
        "defaultSchemes",
        "QVariantList",
        "addApplication",
        "ctx",
        "findBaseName",
        "filePath",
        "getCommand",
        "component",
        "addCommand",
        "exec",
        "name",
        "editCommand",
        "componentName",
        "newExec",
        "quoteUrl",
        "keySequenceToString",
        "keySequence",
        "urlFilename",
        "filteredModel",
        "FilteredShortcutsModel*",
        "shortcutsModel",
        "ShortcutsModel*",
        "lastError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showComponent'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'errorOccured'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'requestKeySequence'
        QtMocHelpers::MethodData<void(QQuickItem *, const QModelIndex &, const QKeySequence &, const QKeySequence &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 10, 12 },
        }}),
        // Method 'requestKeySequence'
        QtMocHelpers::MethodData<void(QQuickItem *, const QModelIndex &, const QKeySequence &)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'writeScheme'
        QtMocHelpers::MethodData<void(const QUrl &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Method 'loadScheme'
        QtMocHelpers::MethodData<void(const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Method 'defaultSchemes'
        QtMocHelpers::MethodData<QVariantList() const>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'addApplication'
        QtMocHelpers::MethodData<void(QQuickItem *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 20 },
        }}),
        // Method 'findBaseName'
        QtMocHelpers::MethodData<QString(const QString &) const>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'getCommand'
        QtMocHelpers::MethodData<QString(const QString) const>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'addCommand'
        QtMocHelpers::MethodData<QString(const QString &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 },
        }}),
        // Method 'editCommand'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 27 }, { QMetaType::QString, 30 },
        }}),
        // Method 'quoteUrl'
        QtMocHelpers::MethodData<QString(const QUrl &)>(31, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Method 'keySequenceToString'
        QtMocHelpers::MethodData<QString(const QKeySequence &) const>(32, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 10, 33 },
        }}),
        // Method 'urlFilename'
        QtMocHelpers::MethodData<QString(const QUrl &)>(34, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filteredModel'
        QtMocHelpers::PropertyData<FilteredShortcutsModel*>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'shortcutsModel'
        QtMocHelpers::PropertyData<ShortcutsModel*>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'lastError'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCMKeys, qt_meta_tag_ZN7KCMKeysE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMKeys::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KCMKeysE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KCMKeysE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KCMKeysE_t>.metaTypes,
    nullptr
} };

void KCMKeys::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMKeys *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showComponent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->errorOccured(); break;
        case 2: _t->requestKeySequence((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[4]))); break;
        case 3: _t->requestKeySequence((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[3]))); break;
        case 4: _t->writeScheme((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->loadScheme((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: { QVariantList _r = _t->defaultSchemes();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->addApplication((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 8: { QString _r = _t->findBaseName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->getCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->addCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->editCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: { QString _r = _t->quoteUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->keySequenceToString((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->urlFilename((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMKeys::*)(int )>(_a, &KCMKeys::showComponent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKeys::*)()>(_a, &KCMKeys::errorOccured, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<FilteredShortcutsModel**>(_v) = _t->filteredModel(); break;
        case 1: *reinterpret_cast<ShortcutsModel**>(_v) = _t->shortcutsModel(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->lastError(); break;
        default: break;
        }
    }
}

const QMetaObject *KCMKeys::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMKeys::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KCMKeysE_t>.strings))
        return static_cast<void*>(this);
    return KQuickConfigModule::qt_metacast(_clname);
}

int KCMKeys::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KCMKeys::showComponent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KCMKeys::errorOccured()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
