// /qt/qml/plasma/applet/org/kde/plasma/kickoff/Badge.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qalgorithms.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qrandom.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <cmath>
#include <limits>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_plasma_applet_org_kde_plasma_kickoff_Badge_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x20,0x11,0x0,0x0,0x26,0x13,0xfd,0x70,
0x68,0x13,0x6d,0x5e,0x61,0xa9,0x11,0x56,
0xeb,0xbf,0x5b,0xf6,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x31,0x0,0x0,0x0,0x60,0x6,0x0,0x0,
0xc,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x35,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xcc,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xd0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0xd,0x0,0x0,
0xd8,0x1,0x0,0x0,0x30,0x2,0x0,0x0,
0x98,0x2,0x0,0x0,0x0,0x3,0x0,0x0,
0x78,0x3,0x0,0x0,0xe0,0x3,0x0,0x0,
0x48,0x4,0x0,0x0,0xa8,0x4,0x0,0x0,
0x8,0x5,0x0,0x0,0x58,0x5,0x0,0x0,
0xb0,0x5,0x0,0x0,0x8,0x6,0x0,0x0,
0x43,0x0,0x0,0x0,0x40,0x2,0x0,0x0,
0x50,0x2,0x0,0x0,0x83,0x0,0x0,0x0,
0x43,0x0,0x0,0x0,0x40,0x2,0x0,0x0,
0x60,0x2,0x0,0x0,0x73,0x2,0x0,0x0,
0x83,0x0,0x0,0x0,0x43,0x0,0x0,0x0,
0x40,0x2,0x0,0x0,0x60,0x2,0x0,0x0,
0x73,0x2,0x0,0x0,0x73,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x83,0x2,0x0,0x0,
0x43,0x0,0x0,0x0,0x40,0x2,0x0,0x0,
0xa0,0x2,0x0,0x0,0xb0,0x2,0x0,0x0,
0x94,0x2,0x0,0x0,0x73,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x43,0x0,0x0,0x0,
0x40,0x2,0x0,0x0,0x60,0x2,0x0,0x0,
0x73,0x2,0x0,0x0,0x73,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x43,0x0,0x0,0x0,
0xc0,0x2,0x0,0x0,0xd0,0x2,0x0,0x0,
0x43,0x0,0x0,0x0,0xc0,0x2,0x0,0x0,
0xe0,0x2,0x0,0x0,0x93,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x93,0x0,0x0,0x0,
0x90,0x1,0x0,0x0,0x93,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x93,0x0,0x0,0x0,
0x10,0x1,0x0,0x0,0x73,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x43,0x0,0x0,0x0,
0xc0,0x2,0x0,0x0,0xf0,0x2,0x0,0x0,
0x83,0x0,0x0,0x0,0x43,0x0,0x0,0x0,
0xc0,0x2,0x0,0x0,0x0,0x3,0x0,0x0,
0xf0,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0xcd,0xcc,0xcc,0xcc,0xcc,0x8c,0x1,0x40,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x3c,0x2,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x11,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x3,0x18,0x7,
0x12,0x0,0x6e,0x7,0x50,0x8,0x2e,0x4,
0x3c,0x5,0x3c,0x6,0x4c,0x8,0x2e,0x7,
0x18,0x8,0x10,0x2,0x9e,0x8,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x8,0x18,0x7,
0x12,0x0,0x6e,0x7,0x50,0x8,0x2e,0x9,
0x3c,0xa,0x3c,0xb,0x4c,0x8,0x2e,0xc,
0x18,0x8,0x10,0x2,0x9e,0x8,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x2b,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x15,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xd,0x3c,0xe,
0x18,0x7,0x12,0x0,0x6e,0x7,0x50,0x1b,
0x2e,0xf,0x18,0x8,0x2e,0x10,0x3c,0x11,
0x3c,0x12,0x3c,0x13,0x18,0xc,0x4,0x0,
0x9c,0xc,0x18,0xb,0xac,0x14,0x8,0x1,
0xb,0x4c,0x1,0x6,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1f,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x16,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x15,0x3c,0x16,
0x18,0x7,0x12,0x0,0x6e,0x7,0x50,0x8,
0x2e,0x17,0x3c,0x18,0x3c,0x19,0x4c,0x8,
0x2e,0x1a,0x18,0x8,0x10,0x2,0x9e,0x8,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x17,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1b,0x3c,0x1c,
0x18,0x7,0x12,0x0,0x6e,0x7,0x50,0x8,
0x2e,0x1d,0x3c,0x1e,0x3c,0x1f,0x4c,0x6,
0x2e,0x20,0x3c,0x21,0x3c,0x22,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x1b,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x23,0x3c,0x24,
0x18,0x7,0x12,0x0,0x6e,0x7,0x50,0x6,
0x2e,0x25,0x3c,0x26,0x4c,0x1,0x6,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x1c,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x27,0x3c,0x28,
0x18,0x7,0x12,0x0,0x6e,0x7,0x50,0x6,
0x2e,0x29,0x3c,0x2a,0x4c,0x1,0x6,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x20,0x0,0xd0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2b,0x3c,0x2c,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x21,0x0,0xd0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x21,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2d,0x3c,0x2e,
0x3c,0x2f,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x22,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x24,0x0,0xd0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x30,0x18,0x7,
0x12,0x0,0x6e,0x7,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x23,0x0,0xd0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x31,0x3c,0x32,
0x3c,0x33,0x3c,0x34,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x28,0x7,0x0,0x0,0x30,0x7,0x0,0x0,
0x48,0x7,0x0,0x0,0x58,0x7,0x0,0x0,
0x90,0x7,0x0,0x0,0xa8,0x7,0x0,0x0,
0xd0,0x7,0x0,0x0,0xf0,0x7,0x0,0x0,
0x0,0x8,0x0,0x0,0x10,0x8,0x0,0x0,
0x30,0x8,0x0,0x0,0x48,0x8,0x0,0x0,
0x80,0x8,0x0,0x0,0xa0,0x8,0x0,0x0,
0xe0,0x8,0x0,0x0,0x0,0x9,0x0,0x0,
0x40,0x9,0x0,0x0,0x58,0x9,0x0,0x0,
0x80,0x9,0x0,0x0,0xc0,0x9,0x0,0x0,
0xd8,0x9,0x0,0x0,0x8,0xa,0x0,0x0,
0x18,0xa,0x0,0x0,0x48,0xa,0x0,0x0,
0x68,0xa,0x0,0x0,0x78,0xa,0x0,0x0,
0x98,0xa,0x0,0x0,0xd8,0xa,0x0,0x0,
0xf0,0xa,0x0,0x0,0x20,0xb,0x0,0x0,
0x30,0xb,0x0,0x0,0x40,0xb,0x0,0x0,
0x58,0xb,0x0,0x0,0x90,0xb,0x0,0x0,
0xa8,0xb,0x0,0x0,0xe0,0xb,0x0,0x0,
0x0,0xc,0x0,0x0,0x10,0xc,0x0,0x0,
0x30,0xc,0x0,0x0,0x50,0xc,0x0,0x0,
0x68,0xc,0x0,0x0,0x78,0xc,0x0,0x0,
0x88,0xc,0x0,0x0,0xa0,0xc,0x0,0x0,
0xc0,0xc,0x0,0x0,0xd0,0xc,0x0,0x0,
0x8,0xd,0x0,0x0,0x30,0xd,0x0,0x0,
0x48,0xd,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x50,0x0,0x43,0x0,
0x33,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x61,0x0,
0x2e,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,
0x70,0x0,0x6f,0x0,0x6e,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x50,0x0,0x43,0x0,
0x33,0x0,0x2e,0x0,0x43,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x64,0x0,0x67,0x0,0x65,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x74,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x64,0x0,0x67,0x0,0x65,0x0,0x4c,0x0,
0x61,0x0,0x62,0x0,0x65,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x64,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x70,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x50,0x0,0x61,0x0,
0x64,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6c,0x0,0x65,0x0,0x66,0x0,
0x74,0x0,0x50,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x50,0x0,
0x61,0x0,0x64,0x0,0x64,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x72,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x50,0x0,0x61,0x0,
0x64,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x52,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x72,0x0,0x61,0x0,
0x64,0x0,0x69,0x0,0x75,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x72,0x0,0x61,0x0,0x64,0x0,
0x69,0x0,0x75,0x0,0x73,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x63,0x0,0x6f,0x0,0x6c,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x57,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x50,0x0,0x43,0x0,
0x33,0x0,0x2e,0x0,0x4c,0x0,0x61,0x0,
0x62,0x0,0x65,0x0,0x6c,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x65,0x0,0x78,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x6c,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x70,0x0,0x69,0x0,
0x78,0x0,0x65,0x0,0x6c,0x0,0x53,0x0,
0x69,0x0,0x7a,0x0,0x65,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x70,0x0,0x69,0x0,0x78,0x0,
0x65,0x0,0x6c,0x0,0x53,0x0,0x69,0x0,
0x7a,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x73,0x0,0x69,0x0,0x62,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x76,0x0,0x69,0x0,0x73,0x0,
0x69,0x0,0x62,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x49,0x0,0x74,0x0,0x65,0x0,
0x6d,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x55,0x0,0x6e,0x0,
0x69,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x73,0x0,0x6d,0x0,
0x61,0x0,0x6c,0x0,0x6c,0x0,0x53,0x0,
0x70,0x0,0x61,0x0,0x63,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x72,0x0,0x6e,0x0,0x65,0x0,0x72,0x0,
0x52,0x0,0x61,0x0,0x64,0x0,0x69,0x0,
0x75,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4d,0x0,0x61,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x75,0x0,0x6e,0x0,0x64,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x69,0x0,0x63,0x0,
0x6f,0x0,0x6e,0x0,0x53,0x0,0x69,0x0,
0x7a,0x0,0x65,0x0,0x73,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x73,0x0,0x69,0x0,
0x7a,0x0,0x65,0x0,0x46,0x0,0x6f,0x0,
0x72,0x0,0x4c,0x0,0x61,0x0,0x62,0x0,
0x65,0x0,0x6c,0x0,0x73,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x54,0x0,0x68,0x0,
0x65,0x0,0x6d,0x0,0x65,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x70,0x0,0x6f,0x0,
0x73,0x0,0x69,0x0,0x74,0x0,0x69,0x0,
0x76,0x0,0x65,0x0,0x42,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x70,0x0,0x6f,0x0,
0x73,0x0,0x69,0x0,0x74,0x0,0x69,0x0,
0x76,0x0,0x65,0x0,0x54,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x74,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x73,0x0,0x6d,0x0,
0x61,0x0,0x6c,0x0,0x6c,0x0,0x46,0x0,
0x6f,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x60,0x0,0x0,0x0,
0x40,0x1,0x0,0x0,0xe0,0x1,0x0,0x0,
0x80,0x2,0x0,0x0,0x38,0x3,0x0,0x0,
0x6,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x68,0x0,0x0,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe0,0x0,0x0,0x0,0xb,0x0,0x10,0x0,
0xc,0x0,0x50,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0xe,0x0,0xa0,0x1,
0x23,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x50,0x0,0x1a,0x0,0x20,0x1,
0x17,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x14,0x0,0x10,0x1,
0xe,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x12,0x0,0x30,0x1,
0xc,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x50,0x0,0x11,0x0,0x20,0x1,
0xa,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x10,0x0,0xe0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9c,0x0,0x0,0x0,0x14,0x0,0x10,0x1,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x17,0x0,0x90,0x0,
0x17,0x0,0x0,0x1,0x13,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x90,0x0,
0x16,0x0,0x10,0x1,0x11,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x90,0x0,
0x15,0x0,0x90,0x1,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9c,0x0,0x0,0x0,0x1a,0x0,0x20,0x1,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x90,0x0,
0x1c,0x0,0x90,0x1,0x19,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x90,0x0,
0x1b,0x0,0x80,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x90,0x0,
0x1e,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0x1e,0x0,0x90,0x0,
0x1f,0x0,0xd0,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x21,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0xa,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x0,0xd0,0x0,
0x24,0x0,0x60,0x1,0x15,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x9,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x21,0x0,0xd0,0x0,
0x21,0x0,0x40,0x1,0x8,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0xd0,0x0,
0x20,0x0,0x30,0x1,0x1d,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x22,0x0,0xd0,0x0,
0x22,0x0,0x20,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x22,0x0,0xd0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1f,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0xb,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x20,0x1,
0x23,0x0,0xd0,0x1,0x1e,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x22,0x0,0x20,0x1,
0x22,0x0,0x80,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for padding at line 16, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(1, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(1, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(2, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(2, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_4 = double(std::move(retrieved));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_4;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for leftPadding at line 17, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_12, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QString v2_0;
QString v2_4;
bool v2_6;
double c2_26;
double v2_14;
double v2_18;
double v2_22;
double v2_24;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(3, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_6 = s.v2_0 != s.v2_4;
{
}
// generate_JumpFalse
if (!s.v2_6) {
    goto label_0;
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadSingletonLookup(5, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadSingletonLookup(5, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->getObjectLookup(6, s.v2_12, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(6, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Jump
{
s.c2_26 = s.v2_14;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(7, &s.v2_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initLoadScopeObjectPropertyLookup(7);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_22 = double(2);
{
}
// generate_Div
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4723) // potential divide by 0
s.v2_24 = (s.v2_18 / s.v2_22);
QT_WARNING_POP
{
s.c2_26 = s.v2_24;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.c2_26;
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for rightPadding at line 18, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_12, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QString v2_0;
QString v2_4;
bool v2_6;
double c2_26;
double v2_14;
double v2_18;
double v2_22;
double v2_24;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(8, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_6 = s.v2_0 != s.v2_4;
{
}
// generate_JumpFalse
if (!s.v2_6) {
    goto label_0;
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadSingletonLookup(10, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadSingletonLookup(10, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->getObjectLookup(11, s.v2_12, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(11, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Jump
{
s.c2_26 = s.v2_14;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(12, &s.v2_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initLoadScopeObjectPropertyLookup(12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_22 = double(2);
{
}
// generate_Div
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4723) // potential divide by 0
s.v2_24 = (s.v2_18 / s.v2_22);
QT_WARNING_POP
{
s.c2_26 = s.v2_24;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.c2_26;
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitHeight at line 21, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_18, markStack);
    aotContext->mark(v2_20, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_18 = nullptr;
QObject *v2_20 = nullptr;
QString v2_2;
QString v2_6;
bool v2_8;
double c2_40;
double v2_22;
double v2_26;
double v2_28;
double v2_32;
double v2_39;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(13, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(13);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(14, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(14, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_6 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_8 = s.v2_2 != s.v2_6;
{
}
// generate_JumpFalse
if (!s.v2_8) {
    goto label_0;
}
{
}
{
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->loadSingletonLookup(17, &s.v2_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initLoadSingletonLookup(17, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
while (!aotContext->getObjectLookup(18, s.v2_18, &s.v2_20)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
aotContext->initGetObjectLookup(18, s.v2_18);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
while (!aotContext->getObjectLookup(19, s.v2_20, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
aotContext->initGetObjectLookup(19, s.v2_20);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_22 = double(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadConst
s.v2_26 = 1.30000000000000004;
{
}
// generate_Mul
s.v2_28 = (s.v2_22 * s.v2_26);
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_28;
s.v2_32 = std::isfinite(arg1) ? ((arg1 < 0.5 && arg1 >= -0.5) ? std::copysign(0.0, arg1) : std::floor(arg1 + 0.5)) : arg1;
}
{
}
// generate_Jump
{
s.c2_40 = s.v2_32;
    goto label_1;
}
label_0:;
// generate_LoadZero
s.v2_39 = double(0);
{
s.c2_40 = s.v2_39;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.c2_40;
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for radius at line 22, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_14, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_14 = nullptr;
QString v2_2;
QString v2_6;
bool v2_8;
double c2_28;
double v2_16;
double v2_20;
double v2_24;
double v2_26;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(21, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(21);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(22, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(22, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_6 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_8 = s.v2_2 != s.v2_6;
{
}
// generate_JumpFalse
if (!s.v2_8) {
    goto label_0;
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadSingletonLookup(24, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadSingletonLookup(24, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getObjectLookup(25, s.v2_14, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetObjectLookup(25, s.v2_14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Jump
{
s.c2_28 = s.v2_16;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(26, &s.v2_20)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
aotContext->initLoadScopeObjectPropertyLookup(26);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_24 = double(2);
{
}
// generate_Div
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4723) // potential divide by 0
s.v2_26 = (s.v2_20 / s.v2_24);
QT_WARNING_POP
{
s.c2_28 = s.v2_26;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.c2_28;
}
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for color at line 23, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(c2_26, markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_16, markStack);
    aotContext->mark(v2_22, markStack);
    aotContext->mark(v2_24, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_14 = nullptr;
QObject *v2_22 = nullptr;
QString v2_2;
QString v2_6;
QVariant c2_26;
QVariant v2_16;
QVariant v2_24;
bool v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(27, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(27);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(28, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(28, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_6 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_8 = s.v2_2 != s.v2_6;
{
}
// generate_JumpFalse
if (!s.v2_8) {
    goto label_0;
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadAttachedLookup(30, aotContext->qmlScopeObject, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadAttachedLookup(30, 4, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
s.v2_16 = QVariant(aotContext->lookupResultMetaType(31));
while (!aotContext->getObjectLookup(31, s.v2_14, s.v2_16.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetObjectLookup(31, s.v2_14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_16 = QVariant(aotContext->lookupResultMetaType(31));
}
{
}
// generate_Jump
{
s.c2_26 = s.v2_16;
    goto label_1;
}
label_0:;
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
while (!aotContext->loadAttachedLookup(33, aotContext->qmlScopeObject, &s.v2_22)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
aotContext->initLoadAttachedLookup(33, 4, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
s.v2_24 = QVariant(aotContext->lookupResultMetaType(34));
while (!aotContext->getObjectLookup(34, s.v2_22, s.v2_24.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
aotContext->initGetObjectLookup(34, s.v2_22);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_24 = QVariant(aotContext->lookupResultMetaType(34));
}
{
s.c2_26 = s.v2_24;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    if (!s.c2_26.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.c2_26.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.c2_26.data());
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitWidth at line 27, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_12, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_12 = nullptr;
QString v2_2;
QString v2_6;
bool v2_8;
double c2_19;
double v2_14;
double v2_18;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(35, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(35);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(36, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(36, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_6 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_8 = s.v2_2 != s.v2_6;
{
}
// generate_JumpFalse
if (!s.v2_8) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadContextIdLookup(37, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadContextIdLookup(37);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->getObjectLookup(38, s.v2_12, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(38, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Jump
{
s.c2_19 = s.v2_14;
    goto label_1;
}
label_0:;
// generate_LoadZero
s.v2_18 = double(0);
{
s.c2_19 = s.v2_18;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.c2_19;
}
return;
}
 },{ 7, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitHeight at line 28, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_12, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_12 = nullptr;
QString v2_2;
QString v2_6;
bool v2_8;
double c2_19;
double v2_14;
double v2_18;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(39, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(39);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(40, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(40, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_6 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_8 = s.v2_2 != s.v2_6;
{
}
// generate_JumpFalse
if (!s.v2_8) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadContextIdLookup(41, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadContextIdLookup(41);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->getObjectLookup(42, s.v2_12, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(42, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Jump
{
s.c2_19 = s.v2_14;
    goto label_1;
}
label_0:;
// generate_LoadZero
s.v2_18 = double(0);
{
s.c2_19 = s.v2_18;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.c2_19;
}
return;
}
 },{ 8, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for text at line 32, column 13
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(43, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(43);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(44, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(44, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_2);
}
return;
}
 },{ 9, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for color at line 33, column 13
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
QVariant v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadAttachedLookup(46, aotContext->qmlScopeObject, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadAttachedLookup(46, 4, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
s.v2_4 = QVariant(aotContext->lookupResultMetaType(47));
while (!aotContext->getObjectLookup(47, s.v2_2, s.v2_4.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(47, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_4 = QVariant(aotContext->lookupResultMetaType(47));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_4.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_4.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_4.data());
}
return;
}
 },{ 10, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for visible at line 36, column 13
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QString v2_0;
QString v2_4;
bool v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(48, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(48);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_6 = s.v2_0 != s.v2_4;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_6;
}
return;
}
 },{ 11, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<int>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for pixelSize at line 35, column 13
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
QVariant v2_4;
int v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadAttachedLookup(50, aotContext->qmlScopeObject, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadAttachedLookup(50, 4, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
s.v2_4 = QVariant(aotContext->lookupResultMetaType(51));
while (!aotContext->getObjectLookup(51, s.v2_2, s.v2_4.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(51, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
s.v2_4 = QVariant(aotContext->lookupResultMetaType(51));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->getValueLookup(52, s.v2_4.data(), &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetValueLookup(52, []() { static const auto t = QMetaType::fromName("QQuickFontValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<int *>(argv[0]) = s.v2_6;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
