/****************************************************************************
** Meta object code from reading C++ file 'kimpanel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/applets/kimpanel/kimpanel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kimpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KimpanelE_t {};
} // unnamed namespace

template <> constexpr inline auto Kimpanel::qt_create_metaobjectdata<qt_meta_tag_ZN8KimpanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kimpanel",
        "QML.Element",
        "auto",
        "auxTextChanged",
        "",
        "preeditTextChanged",
        "lookupTableChanged",
        "spotRectChanged",
        "propertiesChanged",
        "menuTriggered",
        "QVariantList",
        "props",
        "updatePreeditText",
        "text",
        "QList<TextAttribute>",
        "attrList",
        "updateAux",
        "updatePreeditCaret",
        "pos",
        "updateLookupTable",
        "KimpanelLookupTable",
        "lookupTable",
        "updateLookupTableFull",
        "cursor",
        "layout",
        "updateSpotLocation",
        "x",
        "y",
        "updateSpotRect",
        "w",
        "h",
        "showAux",
        "visible",
        "showPreedit",
        "showLookupTable",
        "updateLookupTableCursor",
        "updateProperty",
        "KimpanelProperty",
        "property",
        "registerProperties",
        "QList<KimpanelProperty>",
        "execDialog",
        "prop",
        "execMenu",
        "prop_list",
        "lookupTablePageUp",
        "lookupTablePageDown",
        "movePreeditCaret",
        "position",
        "selectCandidate",
        "candidate",
        "triggerProperty",
        "key",
        "reloadConfig",
        "configure",
        "exit",
        "auxText",
        "auxVisible",
        "preeditText",
        "caretPos",
        "preeditVisible",
        "spotRect",
        "QRect",
        "lookupTableVisible",
        "lookupTableCursor",
        "lookupTableLayout",
        "hasPrev",
        "hasNext",
        "labels",
        "texts",
        "properties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'auxTextChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preeditTextChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lookupTableChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spotRectChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertiesChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'menuTriggered'
        QtMocHelpers::SignalData<void(const QVariantList &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'updatePreeditText'
        QtMocHelpers::SlotData<void(const QString &, const QList<TextAttribute> &)>(12, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'updateAux'
        QtMocHelpers::SlotData<void(const QString &, const QList<TextAttribute> &)>(16, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'updatePreeditCaret'
        QtMocHelpers::SlotData<void(int)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'updateLookupTable'
        QtMocHelpers::SlotData<void(const KimpanelLookupTable &)>(19, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'updateLookupTableFull'
        QtMocHelpers::SlotData<void(const KimpanelLookupTable &, int, int)>(22, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'updateSpotLocation'
        QtMocHelpers::SlotData<void(int, int)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'updateSpotRect'
        QtMocHelpers::SlotData<void(int, int, int, int)>(28, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 }, { QMetaType::Int, 27 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'showAux'
        QtMocHelpers::SlotData<void(bool)>(31, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'showPreedit'
        QtMocHelpers::SlotData<void(bool)>(33, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'showLookupTable'
        QtMocHelpers::SlotData<void(bool)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'updateLookupTableCursor'
        QtMocHelpers::SlotData<void(int)>(35, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'updateProperty'
        QtMocHelpers::SlotData<void(const KimpanelProperty &)>(36, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'registerProperties'
        QtMocHelpers::SlotData<void(const QList<KimpanelProperty> &)>(39, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 11 },
        }}),
        // Slot 'execDialog'
        QtMocHelpers::SlotData<void(const KimpanelProperty &)>(41, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 42 },
        }}),
        // Slot 'execMenu'
        QtMocHelpers::SlotData<void(const QList<KimpanelProperty> &)>(43, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 44 },
        }}),
        // Method 'lookupTablePageUp'
        QtMocHelpers::MethodData<void()>(45, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'lookupTablePageDown'
        QtMocHelpers::MethodData<void()>(46, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'movePreeditCaret'
        QtMocHelpers::MethodData<void(int)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Method 'selectCandidate'
        QtMocHelpers::MethodData<void(int)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 50 },
        }}),
        // Method 'triggerProperty'
        QtMocHelpers::MethodData<void(const QString &)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 52 },
        }}),
        // Method 'reloadConfig'
        QtMocHelpers::MethodData<void()>(53, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'configure'
        QtMocHelpers::MethodData<void()>(54, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'exit'
        QtMocHelpers::MethodData<void()>(55, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'auxText'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'auxVisible'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'preeditText'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'caretPos'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'preeditVisible'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'spotRect'
        QtMocHelpers::PropertyData<QRect>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 3),
        // property 'lookupTableVisible'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'lookupTableCursor'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'lookupTableLayout'
        QtMocHelpers::PropertyData<int>(65, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'hasPrev'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'hasNext'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'labels'
        QtMocHelpers::PropertyData<QStringList>(68, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'texts'
        QtMocHelpers::PropertyData<QStringList>(69, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'properties'
        QtMocHelpers::PropertyData<QVariantList>(70, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Kimpanel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Kimpanel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KimpanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KimpanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KimpanelE_t>.metaTypes,
    nullptr
} };

void Kimpanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Kimpanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->auxTextChanged(); break;
        case 1: _t->preeditTextChanged(); break;
        case 2: _t->lookupTableChanged(); break;
        case 3: _t->spotRectChanged(); break;
        case 4: _t->propertiesChanged(); break;
        case 5: _t->menuTriggered((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 6: _t->updatePreeditText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<TextAttribute>>>(_a[2]))); break;
        case 7: _t->updateAux((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<TextAttribute>>>(_a[2]))); break;
        case 8: _t->updatePreeditCaret((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->updateLookupTable((*reinterpret_cast<std::add_pointer_t<KimpanelLookupTable>>(_a[1]))); break;
        case 10: _t->updateLookupTableFull((*reinterpret_cast<std::add_pointer_t<KimpanelLookupTable>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->updateSpotLocation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->updateSpotRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 13: _t->showAux((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->showPreedit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->showLookupTable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->updateLookupTableCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->updateProperty((*reinterpret_cast<std::add_pointer_t<KimpanelProperty>>(_a[1]))); break;
        case 18: _t->registerProperties((*reinterpret_cast<std::add_pointer_t<QList<KimpanelProperty>>>(_a[1]))); break;
        case 19: _t->execDialog((*reinterpret_cast<std::add_pointer_t<KimpanelProperty>>(_a[1]))); break;
        case 20: _t->execMenu((*reinterpret_cast<std::add_pointer_t<QList<KimpanelProperty>>>(_a[1]))); break;
        case 21: _t->lookupTablePageUp(); break;
        case 22: _t->lookupTablePageDown(); break;
        case 23: _t->movePreeditCaret((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->selectCandidate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->triggerProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->reloadConfig(); break;
        case 27: _t->configure(); break;
        case 28: _t->exit(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Kimpanel::*)()>(_a, &Kimpanel::auxTextChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Kimpanel::*)()>(_a, &Kimpanel::preeditTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Kimpanel::*)()>(_a, &Kimpanel::lookupTableChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Kimpanel::*)()>(_a, &Kimpanel::spotRectChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Kimpanel::*)()>(_a, &Kimpanel::propertiesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Kimpanel::*)(const QVariantList & )>(_a, &Kimpanel::menuTriggered, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_auxText; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->m_auxVisible; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_preeditText; break;
        case 3: *reinterpret_cast<int*>(_v) = _t->m_caretPos; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_preeditVisible; break;
        case 5: *reinterpret_cast<QRect*>(_v) = _t->m_spotRect; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_lookupTableVisible; break;
        case 7: *reinterpret_cast<int*>(_v) = _t->m_lookupTableCursor; break;
        case 8: *reinterpret_cast<int*>(_v) = _t->m_lookupTableLayout; break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->m_hasPrev; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->m_hasNext; break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->m_labels; break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->m_texts; break;
        case 13: *reinterpret_cast<QVariantList*>(_v) = _t->m_props; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_auxText, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->auxTextChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_auxVisible, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->auxTextChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_preeditText, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->preeditTextChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_caretPos, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->preeditTextChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_preeditVisible, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->preeditTextChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_spotRect, *reinterpret_cast<QRect*>(_v)))
                Q_EMIT _t->spotRectChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_lookupTableVisible, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->lookupTableChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_lookupTableCursor, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->lookupTableChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_lookupTableLayout, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->lookupTableChanged();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_hasPrev, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->lookupTableChanged();
            break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_hasNext, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->lookupTableChanged();
            break;
        case 11:
            if (QtMocHelpers::setProperty(_t->m_labels, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->lookupTableChanged();
            break;
        case 12:
            if (QtMocHelpers::setProperty(_t->m_texts, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->lookupTableChanged();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->m_props, *reinterpret_cast<QVariantList*>(_v)))
                Q_EMIT _t->propertiesChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *Kimpanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kimpanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KimpanelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kimpanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Kimpanel::auxTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kimpanel::preeditTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kimpanel::lookupTableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kimpanel::spotRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Kimpanel::propertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Kimpanel::menuTriggered(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
