/****************************************************************************
** Meta object code from reading C++ file 'touchpadbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.6.4/kcms/touchpad/touchpadbackend.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'touchpadbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15TouchpadBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto TouchpadBackend::qt_create_metaobjectdata<qt_meta_tag_ZN15TouchpadBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TouchpadBackend",
        "touchpadStateChanged",
        "",
        "touchpadReset",
        "keyboardActivityStarted",
        "keyboardActivityFinished",
        "inputDevicesChanged",
        "deviceAdded",
        "success",
        "deviceRemoved",
        "index",
        "inputDevices",
        "QList<LibinputCommon*>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'touchpadStateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'touchpadReset'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardActivityStarted'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardActivityFinished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputDevicesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'inputDevices'
        QtMocHelpers::PropertyData<QList<LibinputCommon*>>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TouchpadBackend, qt_meta_tag_ZN15TouchpadBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TouchpadBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TouchpadBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TouchpadBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15TouchpadBackendE_t>.metaTypes,
    nullptr
} };

void TouchpadBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TouchpadBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->touchpadStateChanged(); break;
        case 1: _t->touchpadReset(); break;
        case 2: _t->keyboardActivityStarted(); break;
        case 3: _t->keyboardActivityFinished(); break;
        case 4: _t->inputDevicesChanged(); break;
        case 5: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TouchpadBackend::*)()>(_a, &TouchpadBackend::touchpadStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchpadBackend::*)()>(_a, &TouchpadBackend::touchpadReset, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchpadBackend::*)()>(_a, &TouchpadBackend::keyboardActivityStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchpadBackend::*)()>(_a, &TouchpadBackend::keyboardActivityFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchpadBackend::*)()>(_a, &TouchpadBackend::inputDevicesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchpadBackend::*)(bool )>(_a, &TouchpadBackend::deviceAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchpadBackend::*)(int )>(_a, &TouchpadBackend::deviceRemoved, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<LibinputCommon*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<LibinputCommon*>*>(_v) = _t->inputDevices(); break;
        default: break;
        }
    }
}

const QMetaObject *TouchpadBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TouchpadBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TouchpadBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TouchpadBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TouchpadBackend::touchpadStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TouchpadBackend::touchpadReset()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TouchpadBackend::keyboardActivityStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TouchpadBackend::keyboardActivityFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TouchpadBackend::inputDevicesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TouchpadBackend::deviceAdded(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TouchpadBackend::deviceRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
