/****************************************************************************
** Meta object code from reading C++ file 'kcmaccessibilitybell.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kcmaccessibilitybell.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccessibilitybell.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12BellSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto BellSettings::qt_create_metaobjectdata<qt_meta_tag_ZN12BellSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BellSettings",
        "SystemBellChanged",
        "",
        "CustomBellChanged",
        "CustomBellFileChanged",
        "VisibleBellChanged",
        "InvertScreenChanged",
        "VisibleBellColorChanged",
        "VisibleBellPauseChanged",
        "systemBell",
        "isSystemBellImmutable",
        "defaultSystemBellValue",
        "customBell",
        "isCustomBellImmutable",
        "defaultCustomBellValue",
        "customBellFile",
        "isCustomBellFileImmutable",
        "visibleBell",
        "isVisibleBellImmutable",
        "defaultVisibleBellValue",
        "invertScreen",
        "isInvertScreenImmutable",
        "defaultInvertScreenValue",
        "visibleBellColor",
        "QColor",
        "isVisibleBellColorImmutable",
        "defaultVisibleBellColorValue",
        "visibleBellPause",
        "isVisibleBellPauseImmutable",
        "defaultVisibleBellPauseValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'SystemBellChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CustomBellChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CustomBellFileChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VisibleBellChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InvertScreenChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VisibleBellColorChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VisibleBellPauseChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'systemBell'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isSystemBellImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSystemBellValue'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'customBell'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isCustomBellImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCustomBellValue'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'customBellFile'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isCustomBellFileImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visibleBell'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isVisibleBellImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisibleBellValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'invertScreen'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isInvertScreenImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInvertScreenValue'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visibleBellColor'
        QtMocHelpers::PropertyData<QColor>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'isVisibleBellColorImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisibleBellColorValue'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'visibleBellPause'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isVisibleBellPauseImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisibleBellPauseValue'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BellSettings, qt_meta_tag_ZN12BellSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BellSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12BellSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12BellSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12BellSettingsE_t>.metaTypes,
    nullptr
} };

void BellSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BellSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->SystemBellChanged(); break;
        case 1: _t->CustomBellChanged(); break;
        case 2: _t->CustomBellFileChanged(); break;
        case 3: _t->VisibleBellChanged(); break;
        case 4: _t->InvertScreenChanged(); break;
        case 5: _t->VisibleBellColorChanged(); break;
        case 6: _t->VisibleBellPauseChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BellSettings::*)()>(_a, &BellSettings::SystemBellChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BellSettings::*)()>(_a, &BellSettings::CustomBellChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BellSettings::*)()>(_a, &BellSettings::CustomBellFileChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BellSettings::*)()>(_a, &BellSettings::VisibleBellChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BellSettings::*)()>(_a, &BellSettings::InvertScreenChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BellSettings::*)()>(_a, &BellSettings::VisibleBellColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BellSettings::*)()>(_a, &BellSettings::VisibleBellPauseChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->systemBell(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSystemBellImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultSystemBellValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->customBell(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isCustomBellImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultCustomBellValue(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->customBellFile(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isCustomBellFileImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->visibleBell(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isVisibleBellImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->defaultVisibleBellValue(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->invertScreen(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isInvertScreenImmutable(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->defaultInvertScreenValue(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->visibleBellColor(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isVisibleBellColorImmutable(); break;
        case 16: *reinterpret_cast<QColor*>(_v) = _t->defaultVisibleBellColorValue(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->visibleBellPause(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isVisibleBellPauseImmutable(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->defaultVisibleBellPauseValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSystemBell(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setCustomBell(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setCustomBellFile(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setVisibleBell(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setInvertScreen(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setVisibleBellColor(*reinterpret_cast<QColor*>(_v)); break;
        case 17: _t->setVisibleBellPause(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BellSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BellSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12BellSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int BellSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void BellSettings::SystemBellChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BellSettings::CustomBellChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BellSettings::CustomBellFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BellSettings::VisibleBellChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BellSettings::InvertScreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BellSettings::VisibleBellColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void BellSettings::VisibleBellPauseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
